
data {
  int<lower=1> I;              // number of forecasters
  int<lower=1> J;              // number of questions
  int<lower=1> N;              // number of observations
  int<lower=1,upper=I> ii[N];  // forecaster for observation n
  int<lower=1,upper=J> jj[N];  // question for observation n
  real<upper=0> time_rem[N];   // time remaining for observation n
  real y[N];   // correctness for observation n
}

parameters {
  vector[J] b0j;   // lower asymptote of time
  vector[J] b1j;  // upper asymptote of time
  real b2;       // change in difficulty over time
  vector<lower=0>[J] lambda_star;  //unidentified lambda
  vector[I] theta;  //theta
  vector<lower=0>[J] psi;         //inverse error variance
  real<lower=0> lambdasd;  //SD of lambda disribution for identification
}

transformed parameters{
  vector[J] lambda;  //transformed/identified lambda
  lambda = lambda_star*sqrt(lambdasd);
}


model {
  b0j ~ normal(0, 5);
  b1j ~ normal(0, 5);
  lambda_star ~ normal(0, 1);
  psi ~ normal(0, 1);
  b2 ~ normal(0, 5);
  lambdasd ~ inv_gamma(.01, .01);
  theta ~ normal(0, 1);
  {
  vector[N] mu;
  for (n in 1:N){
    mu[n] = b0j[jj[n]] + (b1j[jj[n]] - b0j[jj[n]])*exp(b2*time_rem[n]) + 
    lambda[jj[n]]*theta[ii[n]];
    y[n] ~ normal(mu[n], psi[jj[n]]);
  }
  }
}

generated quantities {
  vector[J] delta0; // these are transformations to IRT-like item parameters
  vector[J] delta1;  //see Merkle et al (2016)
  vector[J] alpha;
  for (j2 in 1:J){
    delta0[j2] = b0j[j2]/psi[j2];
    delta1[j2] = b1j[j2]/psi[j2];
    alpha[j2] = lambda[j2]/psi[j2];
    }
}
