rm(list=ls())
setwd("~/S1") # Set Working Directory Path
library(reshape2)
library(plyr)
library(dplyr)
library(stringr)
library(ggplot2)
library(standardize)
library(zoo)
library(tidyr)
library(dominanceanalysis)
library(data.table)
library(RColorBrewer)
library(papaja)
library(rstan)
library(lme4)

## Load data
br_ifps_s <- read.csv("season 1 forecasts.csv")

## Convert Brier Scores to Accuracy Scores (eq 6)
br_ifps_s$correct <- 1-(sqrt(br_ifps_s$brier/2))

br_ifps_s$correct_trim <- ifelse(br_ifps_s$correct == 1, .999,
                                 ifelse(br_ifps_s$correct == 0, .001, br_ifps_s$correct))


## Obtain normalized accuracy via probit link
br_ifps_s$correct_prob <- VGAM::probitlink(br_ifps_s$correct_trim)

# Compute time remaining for each forecast
br_ifps_s$time_rem <- as.numeric(as.Date(br_ifps_s$end_date) - as.Date(br_ifps_s$date))
br_ifps_s$time_rem <- ifelse(br_ifps_s$time_rem < 0, 0, br_ifps_s$time_rem) + 1

br_ifps_s$time_rem_log <- log(br_ifps_s$time_rem)

br_ifps_s$resolved_date <- as.Date(br_ifps_s$resolved_date)

## Separate time partitions

## Load quesiton information 
## Then Separate and order forecasting questions by date resolved
ifps <- read.csv("season 1 questions.csv")

## Merge question partition info with forecast file
ifps$resolved_date <- as.Date(ifps$resolved_date)
br_ifps_s <- left_join(br_ifps_s, ifps)

## Obtain hierarchical accuracy estimates for all partitions
lmer_e0 <- lmer(correct_prob ~ time_rem_log + (time_rem_log | discover_id) + 
                             (1 | user_id), br_ifps_s[br_ifps_s$e_l0 == "e",],
                           control = lmerControl(optimizer = "Nelder_Mead"))

lmer_e1 <- lmer(correct_prob ~ time_rem_log + (time_rem_log | discover_id) + 
                             (1 | user_id), br_ifps_s[br_ifps_s$e_l1 == "e",],
                           control = lmerControl(optimizer = "Nelder_Mead"))

lmer_e2 <- lmer(correct_prob ~ time_rem_log + (time_rem_log | discover_id) + 
                             (1 | user_id), br_ifps_s[br_ifps_s$e_l2 == "e",],
                           control = lmerControl(optimizer = "Nelder_Mead"))

lmer_e3 <- lmer(correct_prob ~ time_rem_log + (time_rem_log | discover_id) + 
                             (1 | user_id), br_ifps_s[br_ifps_s$e_l3 == "e",],
                           control = lmerControl(optimizer = "Nelder_Mead"))

lmer_e4 <- lmer(correct_prob ~ time_rem_log + (time_rem_log | discover_id) + 
                             (1 | user_id), br_ifps_s[br_ifps_s$e_l4 == "e",],
                           control = lmerControl(optimizer = "Nelder_Mead"))

lmer_e5 <- lmer(correct_prob ~ time_rem_log + (time_rem_log | discover_id) + 
                             (1 | user_id), br_ifps_s[br_ifps_s$e_l5 == "e",],
                           control = lmerControl(optimizer = "Nelder_Mead"))

lmer_e6 <- lmer(correct_prob ~ time_rem_log + (time_rem_log | discover_id) + 
                             (1 | user_id), br_ifps_s[br_ifps_s$e_l6 == "e",],
                           control = lmerControl(optimizer = "Nelder_Mead"))

lmer_e7 <- lmer(correct_prob ~ time_rem_log + (time_rem_log | discover_id) + 
                             (1 | user_id), br_ifps_s[br_ifps_s$e_l7 == "e",],
                           control = lmerControl(optimizer = "Nelder_Mead"))

lmer_e8 <- lmer(correct_prob ~ time_rem_log + (time_rem_log | discover_id) + 
                             (1 | user_id), br_ifps_s[br_ifps_s$e_l8 == "e",],
                           control = lmerControl(optimizer = "Nelder_Mead"))

lmer_e_f <- lmer(correct_prob ~ time_rem_log + (time_rem_log | discover_id) + 
                              (1 | user_id), br_ifps_s[br_ifps_s$e_l_f == "e",],
                            control = lmerControl(optimizer = "Nelder_Mead"))


lmer_l0 <- lmer(correct_prob ~ time_rem_log + (time_rem_log | discover_id) + 
                             (1 | user_id), br_ifps_s[br_ifps_s$e_l0 == "l",],
                           control = lmerControl(optimizer = "Nelder_Mead"))

lmer_l_f <- lmer(correct_prob ~ time_rem_log + (time_rem_log | discover_id) + 
                              (1 | user_id), br_ifps_s[br_ifps_s$e_l_f == "l",],
                            control = lmerControl(optimizer = "Nelder_Mead"))


lmer_l1 <- lmer(correct_prob ~ time_rem_log + (time_rem_log | discover_id) + 
                             (1 | user_id), br_ifps_s[br_ifps_s$e_l1 == "l",],
                           control = lmerControl(optimizer = "Nelder_Mead"))


lmer_all <- lmer(correct_prob ~ time_rem_log + (time_rem_log | discover_id) + 
                              (1 | user_id), br_ifps_s,
                            control = lmerControl(optimizer = "Nelder_Mead"))


lmer_all <-lmer(correct_prob ~ time_rem_log + (time_rem_log | discover_id) + 
                  (1 | user_id), br_ifps_s,
                control = lmerControl(optimizer = "Nelder_Mead"))

lmer_e8 <- lmer(correct_prob ~ time_rem_log + (time_rem_log | discover_id) + 
       (1 | user_id), br_ifps_s[br_ifps_s$e_l8 == "e",],
     control = lmerControl(optimizer = "Nelder_Mead"))

lmer_e0 <- lmer(correct_prob ~ time_rem_log + (time_rem_log | discover_id) + 
                  (1 | user_id), br_ifps_s[br_ifps_s$e_l0 == "e",],
                control = lmerControl(optimizer = "Nelder_Mead"))

lmer_l0 <- lmer(correct_prob ~ time_rem_log + (time_rem_log | discover_id) + 
                  (1 | user_id), br_ifps_s[br_ifps_s$e_l0 == "l",],
                control = lmerControl(optimizer = "Nelder_Mead"))


lmer_e8dat <- data.frame(user_id = rownames(ranef(lmer_e8)$user_id),
                       hier_e8 = ranef(lmer_e8)$user_id$`(Intercept)`)

lmer_e7dat <- data.frame(user_id = rownames(ranef(lmer_e7)$user_id),
                         hier_e7 = ranef(lmer_e7)$user_id$`(Intercept)`)

lmer_e6dat <- data.frame(user_id = rownames(ranef(lmer_e6)$user_id),
                         hier_e6 = ranef(lmer_e6)$user_id$`(Intercept)`)

lmer_e5dat <- data.frame(user_id = rownames(ranef(lmer_e5)$user_id),
                         hier_e5 = ranef(lmer_e5)$user_id$`(Intercept)`)

lmer_e4dat <- data.frame(user_id = rownames(ranef(lmer_e4)$user_id),
                         hier_e4 = ranef(lmer_e4)$user_id$`(Intercept)`)

lmer_e3dat <- data.frame(user_id = rownames(ranef(lmer_e3)$user_id),
                         hier_e3 = ranef(lmer_e3)$user_id$`(Intercept)`)

lmer_e2dat <- data.frame(user_id = rownames(ranef(lmer_e2)$user_id),
                         hier_e2 = ranef(lmer_e2)$user_id$`(Intercept)`)

lmer_e1dat <- data.frame(user_id = rownames(ranef(lmer_e1)$user_id),
                         hier_e1 = ranef(lmer_e1)$user_id$`(Intercept)`)

lmer_e_fdat <- data.frame(user_id = rownames(ranef(lmer_e_f)$user_id),
                         hier_e_f = ranef(lmer_e_f)$user_id$`(Intercept)`)

lmer_l_fdat <- data.frame(user_id = rownames(ranef(lmer_l_f)$user_id),
                          hier_l_f = ranef(lmer_l_f)$user_id$`(Intercept)`)


lmer_alldat<- data.frame(user_id = rownames(ranef(lmer_all)$user_id),
                       hier_all = ranef(lmer_all)$user_id$`(Intercept)`)

lmer_e0dat<- data.frame(user_id = rownames(ranef(lmer_e0)$user_id),
                        hier_e0 = ranef(lmer_e0)$user_id$`(Intercept)`)

lmerl_0dat<- data.frame(user_id = rownames(ranef(lmer_l0)$user_id),
                       hier_l0 = ranef(lmer_l0)$user_id$`(Intercept)`)


## Obtain simple standardized ability estimates for eac partition (no time penalty)

acc_std0_e <- br_ifps_s %>% filter(e_l0 == "e") %>% group_by(user_id, discover_id) %>% 
  summarize(correct_prob = mean(correct_prob)) %>% ungroup() %>% 
  group_by(discover_id) %>%
  mutate(std_brier = scale(correct_prob)) %>% ungroup() %>%
  group_by(user_id) %>% summarize(acc_std0_e = mean(std_brier))


acc_std1_e <- br_ifps_s %>% filter(e_l1 == "e") %>% group_by(user_id, discover_id) %>% 
  summarize(correct_prob = mean(correct_prob)) %>% ungroup() %>% 
  group_by(discover_id) %>%
  mutate(std_brier = scale(correct_prob)) %>% ungroup() %>%
  group_by(user_id) %>% summarize(acc_std1_e = mean(std_brier))


acc_std2_e <- br_ifps_s %>% filter(e_l2 == "e") %>% group_by(user_id, discover_id) %>% 
  summarize(correct_prob = mean(correct_prob)) %>% ungroup() %>% 
  group_by(discover_id) %>%
  mutate(std_brier = scale(correct_prob)) %>% ungroup() %>%
  group_by(user_id) %>% summarize(acc_std2_e = mean(std_brier))


acc_std3_e <- br_ifps_s %>% filter(e_l3 == "e") %>% group_by(user_id, discover_id) %>% 
  summarize(correct_prob = mean(correct_prob)) %>% ungroup() %>% 
  group_by(discover_id) %>%
  mutate(std_brier = scale(correct_prob)) %>% ungroup() %>%
  group_by(user_id) %>% summarize(acc_std3_e = mean(std_brier))


acc_std4_e <- br_ifps_s %>% filter(e_l4 == "e") %>% group_by(user_id, discover_id) %>% 
  summarize(correct_prob = mean(correct_prob)) %>% ungroup() %>% 
  group_by(discover_id) %>%
  mutate(std_brier = scale(correct_prob)) %>% ungroup() %>%
  group_by(user_id) %>% summarize(acc_std4_e = mean(std_brier))


acc_std5_e <- br_ifps_s %>% filter(e_l5 == "e") %>% group_by(user_id, discover_id) %>% 
  summarize(correct_prob = mean(correct_prob)) %>% ungroup() %>% 
  group_by(discover_id) %>%
  mutate(std_brier = scale(correct_prob)) %>% ungroup() %>%
  group_by(user_id) %>% summarize(acc_std5_e = mean(std_brier))


acc_std6_e <- br_ifps_s %>% filter(e_l6 == "e") %>% group_by(user_id, discover_id) %>% 
  summarize(correct_prob = mean(correct_prob)) %>% ungroup() %>% 
  group_by(discover_id) %>%
  mutate(std_brier = scale(correct_prob)) %>% ungroup() %>%
  group_by(user_id) %>% summarize(acc_std6_e = mean(std_brier))


acc_std7_e <- br_ifps_s %>% filter(e_l7 == "e") %>% group_by(user_id, discover_id) %>% 
  summarize(correct_prob = mean(correct_prob)) %>% ungroup() %>% 
  group_by(discover_id) %>%
  mutate(std_brier = scale(correct_prob)) %>% ungroup() %>%
  group_by(user_id) %>% summarize(acc_std7_e = mean(std_brier))


acc_std8_e <- br_ifps_s %>% filter(e_l8 == "e") %>% group_by(user_id, discover_id) %>% 
  summarize(correct_prob = mean(correct_prob)) %>% ungroup() %>% 
  group_by(discover_id) %>%
  mutate(std_brier = scale(correct_prob)) %>% ungroup() %>%
  group_by(user_id) %>% summarize(acc_std8_e = mean(std_brier))

acc_std0_l <- br_ifps_s %>% filter(e_l0 == "l") %>% group_by(user_id, discover_id) %>% 
  summarize(correct_prob = mean(correct_prob)) %>% ungroup() %>% 
  group_by(discover_id) %>%
  mutate(std_brier = scale(correct_prob)) %>% ungroup() %>%
  group_by(user_id) %>% summarize(acc_std0_l = mean(std_brier))


acc_std_f_e <- br_ifps_s %>% filter(e_l_f == "e") %>% group_by(user_id, discover_id) %>% 
  summarize(correct_prob = mean(correct_prob)) %>% ungroup() %>% 
  group_by(discover_id) %>%
  mutate(std_brier = scale(correct_prob)) %>% ungroup() %>%
  group_by(user_id) %>% summarize(acc_std_f_e = mean(std_brier))


acc_std_f_l <- br_ifps_s %>% filter(e_l_f == "l") %>% group_by(user_id, discover_id) %>% 
  summarize(correct_prob = mean(correct_prob)) %>% ungroup() %>% 
  group_by(discover_id) %>%
  mutate(std_brier = scale(correct_prob)) %>% ungroup() %>%
  group_by(user_id) %>% summarize(acc_std_f_l = mean(std_brier))

acc_std1_l <- br_ifps_s %>% filter(e_l1 == "l") %>% group_by(user_id, discover_id) %>% 
  summarize(correct_prob = mean(correct_prob)) %>% ungroup() %>% 
  group_by(discover_id) %>%
  mutate(std_brier = scale(correct_prob)) %>% ungroup() %>%
  group_by(user_id) %>% summarize(acc_std1_l = mean(std_brier))


acc_std_all <- br_ifps_s %>% group_by(user_id, discover_id) %>% 
  summarize(correct_prob = mean(correct_prob)) %>% ungroup() %>% 
  group_by(discover_id) %>%
  mutate(std_brier = scale(correct_prob)) %>% ungroup() %>%
  group_by(user_id) %>% summarize(acc_std_all = mean(std_brier))


## Count forecasts made by each forecaster in each partition

fcasts0_e <- br_ifps_s %>% filter(e_l0 == "e") %>% group_by(user_id) %>% 
  summarize(fcasts0_e = length(user_id))

fcasts1_e <- br_ifps_s %>% filter(e_l1 == "e") %>% group_by(user_id) %>% 
  summarize(fcasts1_e = length(user_id))

fcasts2_e <- br_ifps_s %>% filter(e_l2 == "e") %>% group_by(user_id) %>% 
  summarize(fcasts2_e = length(user_id))

fcasts3_e <- br_ifps_s %>% filter(e_l3 == "e") %>% group_by(user_id) %>% 
  summarize(fcasts3_e = length(user_id))

fcasts4_e <- br_ifps_s %>% filter(e_l4 == "e") %>% group_by(user_id) %>% 
  summarize(fcasts4_e = length(user_id))

fcasts5_e <- br_ifps_s %>% filter(e_l5 == "e") %>% group_by(user_id) %>% 
  summarize(fcasts5_e = length(user_id))

fcasts6_e <- br_ifps_s %>% filter(e_l6 == "e") %>% group_by(user_id) %>% 
  summarize(fcasts6_e = length(user_id))

fcasts7_e <- br_ifps_s %>% filter(e_l7 == "e") %>% group_by(user_id) %>% 
  summarize(fcasts7_e = length(user_id))

fcasts8_e <- br_ifps_s %>% filter(e_l8 == "e") %>% group_by(user_id) %>% 
  summarize(fcasts8_e = length(user_id))

fcasts0_l <- br_ifps_s %>% filter(e_l0 == "l") %>% group_by(user_id) %>% 
  summarize(fcasts0_l = length(user_id))

fcasts1_l <- br_ifps_s %>% filter(e_l1 == "l") %>% group_by(user_id) %>% 
  summarize(fcasts1_l = length(user_id))

fcasts_f_e <- br_ifps_s %>% filter(e_l_f == "e") %>% group_by(user_id) %>% 
  summarize(fcasts_f_e = length(user_id))

fcasts_f_l <- br_ifps_s %>% filter(e_l_f == "l") %>% group_by(user_id) %>% 
  summarize(fcasts_f_l = length(user_id))

fcasts_all <- br_ifps_s %>% group_by(user_id) %>% 
  summarize(fcasts = length(user_id))


## Coutn unique questions forecasted by each participantin each partition

ifp_ct0_e <- br_ifps_s %>% filter(e_l0 == "e") %>% group_by(user_id) %>% 
  summarize(ifp_ct0_e = length(unique(discover_id)))

ifp_ct1_e <- br_ifps_s %>% filter(e_l1 == "e") %>% group_by(user_id) %>% 
  summarize(ifp_ct1_e = length(unique(discover_id)))

ifp_ct2_e <- br_ifps_s %>% filter(e_l2 == "e") %>% group_by(user_id) %>% 
  summarize(ifp_ct2_e = length(unique(discover_id)))

ifp_ct3_e <- br_ifps_s %>% filter(e_l3 == "e") %>% group_by(user_id) %>% 
  summarize(ifp_ct3_e = length(unique(discover_id)))

ifp_ct4_e <- br_ifps_s %>% filter(e_l4 == "e") %>% group_by(user_id) %>% 
  summarize(ifp_ct4_e = length(unique(discover_id)))

ifp_ct5_e <- br_ifps_s %>% filter(e_l5 == "e") %>% group_by(user_id) %>% 
  summarize(ifp_ct5_e = length(unique(discover_id)))

ifp_ct6_e <- br_ifps_s %>% filter(e_l6 == "e") %>% group_by(user_id) %>% 
  summarize(ifp_ct6_e = length(unique(discover_id)))

ifp_ct7_e <- br_ifps_s %>% filter(e_l7 == "e") %>% group_by(user_id) %>% 
  summarize(ifp_ct7_e = length(unique(discover_id)))

ifp_ct8_e <- br_ifps_s %>% filter(e_l8 == "e") %>% group_by(user_id) %>% 
  summarize(ifp_ct8_e = length(unique(discover_id)))

ifp_ct0_l <- br_ifps_s %>% filter(e_l0 == "l") %>% group_by(user_id) %>% 
  summarize(ifp_ct0_l = length(unique(discover_id)))

ifp_ct1_l <- br_ifps_s %>% filter(e_l1 == "l") %>% group_by(user_id) %>% 
  summarize(ifp_ct1_l = length(unique(discover_id)))

ifp_ct_f_e <- br_ifps_s %>% filter(e_l_f == "e") %>% group_by(user_id) %>% 
  summarize(ifp_ct_f_e = length(unique(discover_id)))

ifp_ct_f_l <- br_ifps_s %>% filter(e_l_f == "l") %>% group_by(user_id) %>% 
  summarize(ifp_ct_f_l = length(unique(discover_id)))

ifp_ct_all <- br_ifps_s  %>% group_by(user_id) %>% 
  summarize(ifp_ct = length(unique(discover_id)))


## Merge all estimates and counts from each partition

allscores <- join_all(list(acc_std_all,
                           fcasts_all, ifp_ct_all,
                           fcasts0_e,fcasts0_l,
                           fcasts1_e,fcasts2_e,
                           fcasts3_e,fcasts4_e,
                           fcasts5_e,fcasts6_e,
                           fcasts7_e,fcasts8_e,
                           fcasts1_l,fcasts_f_e,
                           fcasts_f_l,
                           acc_std0_e,acc_std0_l,
                           acc_std1_e,acc_std2_e,
                           acc_std3_e,acc_std4_e,
                           acc_std5_e,acc_std6_e,
                           acc_std7_e,acc_std8_e,
                           acc_std1_l,acc_std_f_e,
                           acc_std_f_l,
                           ifp_ct0_e,ifp_ct0_l,
                           ifp_ct1_e,ifp_ct2_e,
                           ifp_ct3_e,ifp_ct4_e,
                           ifp_ct5_e,ifp_ct6_e,
                           ifp_ct7_e,ifp_ct8_e,
                           ifp_ct1_l,ifp_ct_f_e,
                           ifp_ct_f_l,
                           lmer_e8dat, lmer_e7dat, 
                           lmer_e6dat, lmer_e5dat, 
                           lmer_e4dat, lmer_e3dat, 
                           lmer_e2dat, lmer_e1dat,
                           lmerl_0dat, lmer_e0dat,
                           lmer_alldat, lmer_e_fdat, 
                           lmer_l_fdat), type = "left")

## Load in and merge IRT results (computed separately)

stn <- read.csv("Stan RCTA Results.csv")
allscores <- left_join(allscores, stn)

## Note the following conventions in the data
## acc = simple accuracy, hier = hierarchical accuracy, theta = IRT
## e = early (first partition), l = late (second partition)
## e.g. e1 = the first 10 questions, e2 = first 20 questions, etc.

## Scatterplot Matrix (Figure 3)

library(GGally)

## Define correlation without stars
ggally_cor2 <- function(data, stars = FALSE, mapping = mapping){
  ggally_cor(data, stars = stars, mapping = mapping, family = "Helvetica")
}

score_cor_dat <- allscores[allscores$fcasts >=5 ,
                           c("acc_std_all","hier_all",
            "theta_alll1")]

names(score_cor_dat) <- c("Simple","Hierarchical","IRT")

f3 <- ggpairs(score_cor_dat, upper = list(continuous = ggally_cor2)) + theme_bw() + 
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())


## Output figure as .png and .eps (done for all figures)
png("splom.png", width = 6, height = 4, units = "in", res = 300)
f3
dev.off()

postscript("f3.eps", width = 6, height = 4, horizontal = FALSE)
f3
dev.off()


## Table 2  
all_hlf_crs <- round(cor(allscores[allscores$fcasts >= 5, c("acc_std0_e",
                                     "hier_e0","theta_half1",
                                     "acc_std0_l",
                                     "hier_l0","theta_half2")],
                         use = "pairwise.complete.obs"), 2)


write.csv(all_hlf_crs, "split correlations.csv")

## Read in and merge individual difference data

indvs <-read.csv("s1 core user data.csv")

## Convert education to three-level ordered factor
indvs$ed_ord <- ifelse(indvs$education == levels(factor(indvs$education))[2],"bac",
                       ifelse(indvs$education == levels(factor(indvs$education))[1] | 
                                indvs$education == levels(factor(indvs$education))[3] |
                                indvs$education == levels(factor(indvs$education))[5],
                              "no_bac","grad"))

indvs$ed_ord <- factor(indvs$ed_ord, levels = c("no_bac","bac","grad"),
                            ordered = TRUE)

## Convert gender and education to numeric variables for correlation
indvs$gen_num <- as.numeric(factor(indvs$gender))

indvs$ed_num <- as.numeric(indvs$ed_ord)

allscr_ind <- left_join(allscores, indvs)

## Subset forecasters who made at least 5 forecasts

allscr_ind <- allscr_ind[allscr_ind$fcasts >= 5,]






## Table 3
allscr_cor <- round(cor(allscr_ind[c("acc_std_all","hier_all",
                                     "theta_alll1",
                                     "g_int","nsScore","bnScore",
                                     "crtScore","mtxScore",
                                     "cog_style","aotScore","nfcScore",
                                     "pkScore","pk_conf_gap", "age",
                                     "gen_num","ed_num")],
                    use = "pairwise.complete.obs"), 2)

write.csv(allscr_cor, "indv cors.csv")


## Merge user level scores and individual differences into forecast file
## and subset to > 5 forecasts
br_ifps_s <- left_join(br_ifps_s, allscores)

br_ifps_s <- left_join(br_ifps_s, indvs)

br_ifps_s5 <- br_ifps_s[br_ifps_s$fcasts >= 5,]

## Define R^2 as reduction in forecaster random intercept variance
psuedr2 <- function(mod1, mod2){
  mfr1 <- as.data.frame(VarCorr(mod1))
  mfr2 <- as.data.frame(VarCorr(mod2))
  oupt <- 1 - mfr1$vcov[1]/mfr2$vcov[1]
  return(oupt)
}

## Subset complete cases on relevant variables
br_ifps_comp <- br_ifps_s5[c("g_int","cog_style","age","gender","ed_num",
                             "pkScore","pk_conf_gap","time_rem_log",
                             "correct_prob","discover_id","user_id","brier")]

br_ifps_comp <- br_ifps_comp[complete.cases(br_ifps_comp),]

## Full hierarchical model and reduced hierarchical model for results in Table 4
lmer_full <- lmer(correct_prob ~ g_int + 
                    cog_style + pkScore + pk_conf_gap + 
                    age + gender + ed_num + time_rem_log + 
                    (1 | discover_id) + (1 | user_id),
                  br_ifps_comp)

lmer_red <- lmer(correct_prob ~ time_rem_log + 
                   (1 | discover_id) + (1 | user_id),
                 br_ifps_comp)


lmer_unc_all <- lmer(correct_prob ~ (1 | discover_id) + (1 | user_id),
                     br_ifps_comp)

r2_all <- psuedr2(lmer_full, lmer_red)

## WARNING: Dominance analysis on hierarchical models are very slow

system.time(dom_all <- dominanceAnalysis(lmer_full, null.model = lmer_unc_all))


da_all <- dom_all$contribution.average$rb.r2.2/sum(dom_all$contribution.average$rb.r2.2[-length(dom_all$contribution.average$rb.r2.2)])*r2_all

anova(lmer_full, lmer_red)



## Subset forecasts on questions 81-188 for analyses in figures 4-6
## and forecaters who made at least 5 forecasts
irt_dat <- br_ifps_s[br_ifps_s$e_l1 == "l" & !is.na(br_ifps_s$acc_std1_e) & br_ifps_s$fcasts >= 5,]

## Save full file separately
irt_dat_all <- irt_dat


## Fit models

lmer_a8 <- lmer(correct_prob ~ g_int + 
                  cog_style + pkScore + pk_conf_gap +
                  age + gender + ed_num + acc_std8_e + fcasts8_e + ifp_ct8_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_a7 <- lmer(correct_prob ~ g_int + 
                  cog_style + pkScore + pk_conf_gap +
                  age + gender + ed_num + acc_std7_e + fcasts7_e + ifp_ct7_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_a6 <- lmer(correct_prob ~ g_int + 
                  cog_style + pkScore + pk_conf_gap +
                  age + gender + ed_num + acc_std6_e + fcasts6_e + ifp_ct6_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_a5 <- lmer(correct_prob ~ g_int + 
                  cog_style + pkScore + pk_conf_gap +
                  age + gender + ed_num + acc_std5_e + fcasts5_e + ifp_ct5_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_a4 <- lmer(correct_prob ~ g_int + 
                  cog_style + pkScore + pk_conf_gap +
                  age + gender + ed_num + acc_std4_e + fcasts4_e + ifp_ct4_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_a3 <- lmer(correct_prob ~ g_int + 
                  cog_style + pkScore + pk_conf_gap +
                  age + gender + ed_num + acc_std3_e + fcasts3_e + ifp_ct3_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_a2 <- lmer(correct_prob ~ g_int + 
                  cog_style + pkScore + pk_conf_gap +
                  age + gender + ed_num + acc_std2_e + fcasts2_e + ifp_ct2_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_a1 <- lmer(correct_prob ~ g_int + 
                  cog_style + pkScore + pk_conf_gap +
                  age + gender + ed_num + acc_std1_e + fcasts1_e + ifp_ct1_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)



lmer_t8o <- lmer(correct_prob ~ theta_e8 + fcasts8_e + ifp_ct8_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_t8 <- lmer(correct_prob ~ g_int + 
                  cog_style + pkScore + pk_conf_gap +
                  age + gender + ed_num + theta_e8 + fcasts8_e + ifp_ct8_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)


lmer_t7 <- lmer(correct_prob ~ g_int + 
                  cog_style + pkScore + pk_conf_gap +
                  age + gender + ed_num + theta_e7 + fcasts7_e + ifp_ct7_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_t6 <- lmer(correct_prob ~ g_int + 
                  cog_style + pkScore + pk_conf_gap +
                  age + gender + ed_num + theta_e6 + fcasts6_e + ifp_ct6_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_t5 <- lmer(correct_prob ~ g_int + 
                  cog_style + pkScore + pk_conf_gap +
                  age + gender + ed_num + theta_e5 + fcasts5_e + ifp_ct5_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_t4 <- lmer(correct_prob ~ g_int + 
                  cog_style + pkScore + pk_conf_gap +
                  age + gender + ed_num + theta_e4 + fcasts4_e + ifp_ct4_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_t3 <- lmer(correct_prob ~ g_int + 
                  cog_style + pkScore + pk_conf_gap +
                  age + gender + ed_num + theta_e3 + fcasts3_e + ifp_ct3_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_t2 <- lmer(correct_prob ~ g_int + 
                  cog_style + pkScore + pk_conf_gap +
                  age + gender + ed_num + theta_e2 + fcasts2_e + ifp_ct2_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_t1 <- lmer(correct_prob ~ g_int + 
                  cog_style + pkScore + pk_conf_gap +
                  age + gender + ed_num + theta_e1 + fcasts1_e + ifp_ct1_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)



lmer_h8 <- lmer(correct_prob ~ g_int + 
                  cog_style + pkScore + pk_conf_gap +
                  age + gender + ed_num + hier_e8 + fcasts8_e + ifp_ct8_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_h7 <- lmer(correct_prob ~ g_int + 
                  cog_style + pkScore + pk_conf_gap +
                  age + gender + ed_num + hier_e7 + fcasts7_e + ifp_ct7_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_h6 <- lmer(correct_prob ~ g_int + 
                  cog_style + pkScore + pk_conf_gap +
                  age + gender + ed_num + hier_e6 + fcasts6_e + ifp_ct6_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_h5 <- lmer(correct_prob ~ g_int + 
                  cog_style + pkScore + pk_conf_gap +
                  age + gender + ed_num + hier_e5 + fcasts5_e + ifp_ct5_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_h4 <- lmer(correct_prob ~ g_int + 
                  cog_style + pkScore + pk_conf_gap +
                  age + gender + ed_num + hier_e4 + fcasts4_e + ifp_ct4_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_h3 <- lmer(correct_prob ~ g_int + 
                  cog_style + pkScore + pk_conf_gap +
                  age + gender + ed_num + hier_e3 + fcasts3_e + ifp_ct3_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_h2 <- lmer(correct_prob ~ g_int + 
                  cog_style + pkScore + pk_conf_gap +
                  age + gender + ed_num + hier_e2 + fcasts2_e + ifp_ct2_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_h1 <- lmer(correct_prob ~ g_int + 
                  cog_style + pkScore + pk_conf_gap +
                  age + gender + ed_num + hier_e1 + fcasts1_e + ifp_ct1_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)



lmer_ind <- lmer(correct_prob ~ g_int + 
                   cog_style + pkScore + pk_conf_gap +
                   age + gender + ed_num + time_rem_log + 
                   (1 | discover_id) + (1 | user_id), irt_dat)



lmer_base <- lmer(correct_prob ~ time_rem_log + 
                    (1 | discover_id) + (1 | user_id), irt_dat)



lmer_unc <- lmer(correct_prob ~  
                   (1 | discover_id) + (1 | user_id), irt_dat)




## Get R^2s 
r2_h8 <- psuedr2(lmer_h8, lmer_base)
r2_h7 <- psuedr2(lmer_h7, lmer_base)
r2_h6 <- psuedr2(lmer_h6, lmer_base)
r2_h5 <- psuedr2(lmer_h5, lmer_base)
r2_h4 <- psuedr2(lmer_h4, lmer_base)
r2_h3 <- psuedr2(lmer_h3, lmer_base)
r2_h2 <- psuedr2(lmer_h2, lmer_base)
r2_h1 <- psuedr2(lmer_h1, lmer_base)

r2_a8 <- psuedr2(lmer_a8, lmer_base)
r2_a7 <- psuedr2(lmer_a7, lmer_base)
r2_a6 <- psuedr2(lmer_a6, lmer_base)
r2_a5 <- psuedr2(lmer_a5, lmer_base)
r2_a4 <- psuedr2(lmer_a4, lmer_base)
r2_a3 <- psuedr2(lmer_a3, lmer_base)
r2_a2 <- psuedr2(lmer_a2, lmer_base)
r2_a1 <- psuedr2(lmer_a1, lmer_base)


r2_t8 <- psuedr2(lmer_t8, lmer_base)
r2_t7 <- psuedr2(lmer_t7, lmer_base)
r2_t6 <- psuedr2(lmer_t6, lmer_base)
r2_t5 <- psuedr2(lmer_t5, lmer_base)
r2_t4 <- psuedr2(lmer_t4, lmer_base)
r2_t3 <- psuedr2(lmer_t3, lmer_base)
r2_t2 <- psuedr2(lmer_t2, lmer_base)
r2_t1 <- psuedr2(lmer_t1, lmer_base)

r2_base <- psuedr2(lmer_ind, lmer_base)

## Plot R^2 (fig 4a)
r2s <- data.frame(r2 = c(r2_base,r2_t1,r2_t2,r2_t3,r2_t4,r2_t5,
                         r2_t6,r2_t7,r2_t8,
                         r2_base, r2_h1,r2_h2,r2_h3,r2_h4,r2_h5,
                         r2_h6,r2_h7,r2_h8,
                         r2_base, r2_a1,r2_a2,r2_a3,r2_a4,r2_a5,
                         r2_a6,r2_a7,r2_a8),
                  model = c(rep("IRT",9),
                           rep("Hierarchical", 9),
                           rep("Simple", 9)),
                  time = rep(seq(0, 8, 1), 3)*10)

r2s$model <- factor(r2s$model, levels = c("Simple","Hierarchical","IRT"))


r2s$ncasts <- c(0, mean(irt_dat$fcasts1_e),
                mean(irt_dat$fcasts2_e),
                mean(irt_dat$fcasts3_e),
                mean(irt_dat$fcasts4_e),
                mean(irt_dat$fcasts5_e),
                mean(irt_dat$fcasts6_e),
                mean(irt_dat$fcasts7_e),
                mean(irt_dat$fcasts8_e))

r2s$timecasts <- paste(r2s$time, round(r2s$ncasts), sep = "\n")
timecasts <- unique(r2s[c("timecasts","time")])

r2s$timecasts <- factor(r2s$timecasts, levels = timecasts$timecasts)

p1 <- ggplot(r2s, aes(x = timecasts, y = r2, color = model, linetype = model, group = model)) + geom_line(size = 1.5) +
  labs(colour="Accuracy Measure", linetype = "Accuracy Measure") + xlab("Activity Partition (# of Questions) \nMean Forecasts per Forecaster") + 
  ylab(bquote("R"^2)) + scale_linetype_manual(values=c(3,2,1)) + 
  scale_color_manual(values = rev(brewer.pal(5,"Blues"))) +
  scale_y_continuous(limits = c(0, .7), n.breaks = 8) +
  theme_apa() +
  theme(legend.text=element_text(size=16),
        legend.title = element_text(size = 18),
        axis.title.x = element_text(size = 18),
        axis.title.y = element_text(size = 22),
        axis.text.x = element_text(size = 16),
        axis.text.y = element_text(size = 16),
        legend.position = "bottom")



## Plot BIC (fig 4b)
aovob <- anova(lmer_t1,lmer_t2,lmer_t3,lmer_t4,lmer_t5,
               lmer_t6,lmer_t7,lmer_t8,
               lmer_a1,lmer_a2,lmer_a3,lmer_a4,lmer_a5,
               lmer_a6,lmer_a7,lmer_a8,
               lmer_h1,lmer_h2,lmer_h3,lmer_h4,lmer_h5,
               lmer_h6,lmer_h7,lmer_h8,
               lmer_ind, lmer_base)

devians <- data.frame(aovob)

devians_dat <- rbind(devians["lmer_ind",],devians["lmer_t1",],
                     devians["lmer_t2",],devians["lmer_t3",],
                     devians["lmer_t4",],devians["lmer_t5",],
                     devians["lmer_t6",],devians["lmer_t7",],
                     devians["lmer_t8",],
                     devians["lmer_ind",],devians["lmer_h1",],
                     devians["lmer_h2",],devians["lmer_h3",],
                     devians["lmer_h4",],devians["lmer_h5",],
                     devians["lmer_h6",],devians["lmer_h7",],
                     devians["lmer_h8",],
                     devians["lmer_ind",],devians["lmer_a1",],
                     devians["lmer_a2",],devians["lmer_a3",],
                     devians["lmer_a4",],devians["lmer_a5",],
                     devians["lmer_a6",],devians["lmer_a7",],
                     devians["lmer_a8",])

devians_dat$model <- c(rep("IRT", 9),
                       rep("Hierarchical",9),
                       rep("Simple",9))

devians_dat$time <- rep(seq(0, 8, 1), 3)*10
devians_dat$model <- factor(devians_dat$model, levels = c("Simple","Hierarchical","IRT"))


devians_dat$timecasts <- paste(devians_dat$time, round(r2s$ncasts), sep = "\n")
timecasts <- unique(r2s[c("timecasts","time")])

devians_dat$timecasts <- factor(devians_dat$timecasts, levels = timecasts$timecasts)



p1

p2 <- ggplot(devians_dat, aes(x = timecasts, y = BIC, group = model,color = model, linetype = model)) + geom_line(size = 1.5) +
  labs(colour="Accuracy Measure", linetype = "Accuracy Measure") + xlab("Activity Partition (# of Questions) \nMean Forecasts per Forecaster") +
  ylab("BIC") + scale_linetype_manual(values=c(3,2,1)) + 
  scale_color_manual(values = rev(brewer.pal(5,"Reds")))  +
  scale_y_continuous(limits = c(24030, 24120), n.breaks = 9) +
  theme_apa() +
  theme(legend.text=element_text(size=16),
        legend.title = element_text(size = 18),
        axis.title.x = element_text(size = 18),
        axis.title.y = element_text(size = 22),
        axis.text.x = element_text(size = 16),
        axis.text.y = element_text(size = 16),
        legend.position = "bottom")


## Produce both panels of fig 4
png("r2 dev.png", width = 14, height = 6, units = "in", res = 300)
p3 <- gridExtra::grid.arrange(p1, p2, nrow = 1)

dev.off()
getwd()
postscript("fig4a.eps", width = 7, height = 6, horizontal = FALSE)
p1
dev.off()

postscript("fig4b.eps", width = 7, height = 6, horizontal = FALSE)
p2
dev.off()

## Dominance analyses WARNING: THESE ARE SLOW WITH (the procedure is especially time
## consuming on hierarchical models)
## You will also get some convergence warnings, but most, if not all
## Are very close to the default convergence tolerance

system.time(dom_a8 <- dominanceAnalysis(lmer_a8, null.model = lmer_unc))
system.time(dom_a7 <- dominanceAnalysis(lmer_a7, null.model = lmer_unc))
system.time(dom_a6 <- dominanceAnalysis(lmer_a6, null.model = lmer_unc))
system.time(dom_a5 <- dominanceAnalysis(lmer_a5, null.model = lmer_unc))
system.time(dom_a4 <- dominanceAnalysis(lmer_a4, null.model = lmer_unc))
system.time(dom_a3 <- dominanceAnalysis(lmer_a3, null.model = lmer_unc))
system.time(dom_a2 <- dominanceAnalysis(lmer_a2, null.model = lmer_unc))
system.time(dom_a1 <- dominanceAnalysis(lmer_a1, null.model = lmer_unc))



system.time(dom_t8 <- dominanceAnalysis(lmer_t8, null.model = lmer_unc))
system.time(dom_t7 <- dominanceAnalysis(lmer_t7, null.model = lmer_unc))
system.time(dom_t6 <- dominanceAnalysis(lmer_t6, null.model = lmer_unc))
system.time(dom_t5 <- dominanceAnalysis(lmer_t5, null.model = lmer_unc))
system.time(dom_t4 <- dominanceAnalysis(lmer_t4, null.model = lmer_unc))
system.time(dom_t3 <- dominanceAnalysis(lmer_t3, null.model = lmer_unc))
system.time(dom_t2 <- dominanceAnalysis(lmer_t2, null.model = lmer_unc))
system.time(dom_t1 <- dominanceAnalysis(lmer_t1, null.model = lmer_unc))


system.time(dom_h8 <- dominanceAnalysis(lmer_h8, null.model = lmer_unc))
system.time(dom_h7 <- dominanceAnalysis(lmer_h7, null.model = lmer_unc))
system.time(dom_h6 <- dominanceAnalysis(lmer_h6, null.model = lmer_unc))
system.time(dom_h5 <- dominanceAnalysis(lmer_h5, null.model = lmer_unc))
system.time(dom_h4 <- dominanceAnalysis(lmer_h4, null.model = lmer_unc))
system.time(dom_h3 <- dominanceAnalysis(lmer_h3, null.model = lmer_unc))
system.time(dom_h2 <- dominanceAnalysis(lmer_h2, null.model = lmer_unc))
system.time(dom_h1 <- dominanceAnalysis(lmer_h1, null.model = lmer_unc))


system.time(dom_b <- dominanceAnalysis(lmer_ind, null.model = lmer_unc))


## Obtain and plot dominance weights

da_t8 <- dom_t8$contribution.average$rb.r2.2/sum(dom_t8$contribution.average$rb.r2.2[-length(dom_t8$contribution.average$rb.r2.2)])*r2_t8
da_t7 <- dom_t7$contribution.average$rb.r2.2/sum(dom_t7$contribution.average$rb.r2.2[-length(dom_t7$contribution.average$rb.r2.2)])*r2_t7
da_t6 <- dom_t6$contribution.average$rb.r2.2/sum(dom_t6$contribution.average$rb.r2.2[-length(dom_t6$contribution.average$rb.r2.2)])*r2_t6
da_t5 <- dom_t5$contribution.average$rb.r2.2/sum(dom_t5$contribution.average$rb.r2.2[-length(dom_t5$contribution.average$rb.r2.2)])*r2_t5
da_t4 <- dom_t4$contribution.average$rb.r2.2/sum(dom_t4$contribution.average$rb.r2.2[-length(dom_t4$contribution.average$rb.r2.2)])*r2_t4
da_t3 <- dom_t3$contribution.average$rb.r2.2/sum(dom_t3$contribution.average$rb.r2.2[-length(dom_t3$contribution.average$rb.r2.2)])*r2_t3
da_t2 <- dom_t2$contribution.average$rb.r2.2/sum(dom_t2$contribution.average$rb.r2.2[-length(dom_t2$contribution.average$rb.r2.2)])*r2_t2
da_t1 <- dom_t1$contribution.average$rb.r2.2/sum(dom_t1$contribution.average$rb.r2.2[-length(dom_t1$contribution.average$rb.r2.2)])*r2_t1

da_a8 <- dom_a8$contribution.average$rb.r2.2/sum(dom_a8$contribution.average$rb.r2.2[-length(dom_a8$contribution.average$rb.r2.2)])*r2_a8
da_a7 <- dom_a7$contribution.average$rb.r2.2/sum(dom_a7$contribution.average$rb.r2.2[-length(dom_a7$contribution.average$rb.r2.2)])*r2_a7
da_a6 <- dom_a6$contribution.average$rb.r2.2/sum(dom_a6$contribution.average$rb.r2.2[-length(dom_a6$contribution.average$rb.r2.2)])*r2_a6
da_a5 <- dom_a5$contribution.average$rb.r2.2/sum(dom_a5$contribution.average$rb.r2.2[-length(dom_a5$contribution.average$rb.r2.2)])*r2_a5
da_a4 <- dom_a4$contribution.average$rb.r2.2/sum(dom_a4$contribution.average$rb.r2.2[-length(dom_a4$contribution.average$rb.r2.2)])*r2_a4
da_a3 <- dom_a3$contribution.average$rb.r2.2/sum(dom_a3$contribution.average$rb.r2.2[-length(dom_a3$contribution.average$rb.r2.2)])*r2_a3
da_a2 <- dom_a2$contribution.average$rb.r2.2/sum(dom_a2$contribution.average$rb.r2.2[-length(dom_a2$contribution.average$rb.r2.2)])*r2_a2
da_a1 <- dom_a1$contribution.average$rb.r2.2/sum(dom_a1$contribution.average$rb.r2.2[-length(dom_a1$contribution.average$rb.r2.2)])*r2_a1

da_h8 <- dom_h8$contribution.average$rb.r2.2/sum(dom_h8$contribution.average$rb.r2.2[-length(dom_h8$contribution.average$rb.r2.2)])*r2_h8
da_h7 <- dom_h7$contribution.average$rb.r2.2/sum(dom_h7$contribution.average$rb.r2.2[-length(dom_h7$contribution.average$rb.r2.2)])*r2_h7
da_h6 <- dom_h6$contribution.average$rb.r2.2/sum(dom_h6$contribution.average$rb.r2.2[-length(dom_h6$contribution.average$rb.r2.2)])*r2_h6
da_h5 <- dom_h5$contribution.average$rb.r2.2/sum(dom_h5$contribution.average$rb.r2.2[-length(dom_h5$contribution.average$rb.r2.2)])*r2_h5
da_h4 <- dom_h4$contribution.average$rb.r2.2/sum(dom_h4$contribution.average$rb.r2.2[-length(dom_h4$contribution.average$rb.r2.2)])*r2_h4
da_h3 <- dom_h3$contribution.average$rb.r2.2/sum(dom_h3$contribution.average$rb.r2.2[-length(dom_h3$contribution.average$rb.r2.2)])*r2_h3
da_h2 <- dom_h2$contribution.average$rb.r2.2/sum(dom_h2$contribution.average$rb.r2.2[-length(dom_h2$contribution.average$rb.r2.2)])*r2_h2
da_h1 <- dom_h1$contribution.average$rb.r2.2/sum(dom_h1$contribution.average$rb.r2.2[-length(dom_h1$contribution.average$rb.r2.2)])*r2_h1



da_b <- dom_b$contribution.average$rb.r2.2/sum(dom_b$contribution.average$rb.r2.2[-length(dom_b$contribution.average$rb.r2.2)])*r2_base


dom_wts <- c(da_b,da_a8,da_a7,da_a6,da_a5,
             da_a4,da_a3,da_a2,da_a1,
             da_b,da_h8,da_h7,da_h6,da_h5,
             da_h4,da_h3,da_h2,da_h1,
             da_b,da_t8,da_t7,da_t6,da_t5,
             da_t4,da_t3,da_t2,da_t1)

dwts <- data.frame(variable = names(dom_wts), dwts = dom_wts,
                   model = c(rep("Simple", length(da_b)), rep("Hierarchical", 8*length(da_h1)) ,
                             rep("Hierarchical", length(da_b)), rep("Hierarchical", 8*length(da_h1)), 
                             rep("IRT", length(da_b)), rep("IRT", 8*length(da_h1))),
                   questions = rep(c(rep(0, length(da_b)),
                                     rep(1, length(da_h1)),
                                     rep(2, length(da_h1)),
                                     rep(3, length(da_h1)),
                                     rep(4, length(da_h1)),
                                     rep(5, length(da_h1)),
                                     rep(6, length(da_h1)),
                                     rep(7, length(da_h1)),
                                     rep(8, length(da_h1))),3))


#write.csv(dwts, "all dominance weights2.csv", row.names = FALSE)


#dwts <- read.csv("all dominance weights2.csv")
dwts$model[1:nrow(dwts)/3] <- "Simple"

dwts <- rbind(dwts, data.frame(variable = rep(c("accuracy","forecasts","qs"),3),
                               dwts = rep(c(0, 0, 0),3),
                               model = c(rep("Simple",3),
                                         rep("Hierarchical",3),
                                         rep("IRT",3)),
                               questions = rep(0, 9)))



dwts$class <- ifelse(dwts$variable == "g_int" |
                       dwts$variable == "cog_style" |
                       dwts$variable == "pkScore" | 
                       dwts$variable == "pk_conf_gap", "Intake",
                     ifelse(dwts$variable == "gender" |
                              dwts$variable == "age" |
                              dwts$variable == "ed_num", "Demographic",
                     ifelse(dwts$variable == "time_rem_log","Time",
                            "Performance")))



dwts_v <- dwts[dwts$class == "Performance",]
dwts_v$Variable <- rep(c("Accuracy","Forecasts","Unique Questions"),
                       nrow(dwts_v)/3)

dwts <- left_join(dwts, unique(dwts_v[c("variable","Variable")]))

dwts$Variable[dwts$variable == "g_int"] <- "Intelligence"
dwts$Variable[dwts$variable == "cog_style"] <- "Cognitive Style"
dwts$Variable[dwts$variable == "pkScore"] <- "Political Knowledge"
dwts$Variable[dwts$variable == "pk_conf_gap"] <- "Overconfidence"
dwts$Variable[dwts$variable == "age"] <- "Age"
dwts$Variable[dwts$variable == "gender"] <- "Gender"
dwts$Variable[dwts$variable == "ed_ord"] <- "Education"
dwts$Variable[dwts$variable == "time_rem_log"] <- "Time Remaining"
dwts$class <- factor(dwts$class, levels = c("Intake","Performance","Demographic","Time"))

dwts$questions <- dwts$questions*10

names(timecasts) <- c("timecasts","questions")
dwts <- left_join(dwts, timecasts)

dwts$timecasts <- factor(dwts$timecasts, levels = timecasts$timecasts)

## Fig 5 and 6, followed by alternative versions in supplementary materials

## Fig 5
irtwts <- dwts[dwts$model == "IRT",]


irt_class <- aggregate(dwts ~ class + timecasts, irtwts, sum)
irt_class$dwts[irt_class$dwts < 0] <- 0

irt_class <- irt_class[irt_class$class != "Time",]

irt1 <- ggplot(irt_class, aes(x=timecasts,y=dwts,group=class,
                              colour=class, linetype = class)) + 
  geom_line(size=1) +
  theme_bw() + xlab("Activity Partition (# of Questions) \nMean Forecasts per Forecaster") + 
  labs(colour="Variable Type", linetype = "Variable Type") +
  ylab("Dominance Weight") + 
  scale_linetype_manual(values=c(3,2,1))  + 
  scale_color_manual(values = rev(brewer.pal(4,"Blues"))) +
  scale_y_continuous(limits = c(0, .7), n.breaks = 8) +
  theme_apa() +
  theme(legend.text=element_text(size=12))

png("irt class.png", width = 8, height = 4, units = "in", res = 300)
irt1
dev.off()

postscript("fig5.eps", width = 8, height = 4, horizontal = FALSE)
irt1
dev.off()

## Fig 6
irt_perf <- irtwts[irtwts$class == "Performance",]

irt2 <- ggplot(irt_perf, aes(x=timecasts,y=dwts,group=Variable,
                             colour=Variable, linetype = Variable)) + 
  geom_line(size=1) +
  theme_bw() + xlab("Activity Partition (# of Questions) \nMean Forecasts per Forecaster") +
  labs(colour="Variable", linetype = "Variable") +
  ylab("Dominance Weight") + 
  scale_linetype_manual(values=c(3,2,1))  + 
  scale_color_manual(values = rev(brewer.pal(4,"Blues"))) +
  scale_y_continuous(limits = c(0, .7), n.breaks = 8) +
  theme_apa() +
  theme(legend.text=element_text(size=12))

png("irt perf.png", width = 8, height = 4, units = "in", res = 300)
irt2
dev.off()

postscript("fig6.eps", width = 8, height = 4, horizontal = FALSE)
irt2
dev.off()



hierwts <- dwts[dwts$model == "Hierarchical",]


hier_class <- aggregate(dwts ~ class + timecasts, hierwts, sum)
hier_class$dwts[hier_class$dwts < 0] <- 0
hier_class <- hier_class[hier_class$class != "Time",]


hier1 <- ggplot(hier_class, aes(x=timecasts,y=dwts,group=class,
                                colour=class, linetype = class)) + 
  geom_line(size=1) +
  theme_bw() + xlab("Activity Partition (# of Questions) \nMean Forecasts per Forecaster") + 
  labs(colour="Variable Type", linetype = "Variable Type") +
  ylab("Dominance Weight") + 
  scale_linetype_manual(values=c(3,2,1))  + 
  scale_color_manual(values = rev(brewer.pal(4,"Blues"))) +
  scale_y_continuous(limits = c(0, .7), n.breaks = 8) +
  theme_apa() +
  theme(legend.text=element_text(size=12))

png("hier class.png", width = 8, height = 4, units = "in", res = 300)
hier1
dev.off()


hier_perf <- hierwts[hierwts$class == "Performance",]

hier_perf$dwts[hier_perf$dwts < 0] <- 0


hier2 <- ggplot(hier_perf, aes(x=timecasts,y=dwts,group=Variable,
                               colour=Variable, linetype = Variable)) + 
  geom_line(size=1) +
  theme_bw() + xlab("Activity Partition (# of Questions) \nMean Forecasts per Forecaster") +
  labs(colour="Variable", linetype = "Variable") +
  ylab("Dominance Weight") + 
  scale_linetype_manual(values=c(3,2,1))  + 
  scale_color_manual(values = rev(brewer.pal(4,"Blues"))) +
  scale_y_continuous(limits = c(0, .7), n.breaks = 8) +
  theme_apa() +
  theme(legend.text=element_text(size=12))

png("hier perf.png", width = 8, height = 4, units = "in", res = 300)
hier2
dev.off()


accwts <- dwts[dwts$model == "Simple",]


acc_class <- aggregate(dwts ~ class + timecasts, accwts, sum)
acc_class$dwts[acc_class$dwts < 0] <- 0
acc_class <- acc_class[acc_class$class != "Time",]

acc1 <- ggplot(acc_class, aes(x=timecasts,y=dwts,group=class,
                              colour=class, linetype = class)) + 
  geom_line(size=1) +
  theme_bw() + xlab("Activity Partition (# of Questions) \nMean Forecasts per Forecaster") + 
  labs(colour="Variable Type", linetype = "Variable Type") +
  ylab("Dominance Weight") + 
  scale_linetype_manual(values=c(3,2,1))  + 
  scale_color_manual(values = rev(brewer.pal(4,"Blues"))) +
  scale_y_continuous(limits = c(0, .7), n.breaks = 8) +
  theme_apa() +
  theme(legend.text=element_text(size=12))

png("acc class.png", width = 8, height = 4, units = "in", res = 300)
acc1
dev.off()


acc_perf <- accwts[accwts$class == "Performance",]
acc_perf$dwts[acc_perf$dwts < 0] <- 0

acc2 <- ggplot(acc_perf, aes(x=timecasts,y=dwts,group=Variable,
                             colour=Variable, linetype = Variable)) + 
  geom_line(size=1) +
  theme_bw() + xlab("Activity Partition (# of Questions) \nMean Forecasts per Forecaster") +
  labs(colour="Variable", linetype = "Variable") +
  ylab("Dominance Weight") + 
  scale_linetype_manual(values=c(3,2,1))  + 
  scale_color_manual(values = rev(brewer.pal(4,"Blues"))) +
  scale_y_continuous(limits = c(0, .7), n.breaks = 8) +
  theme_apa() +
  theme(legend.text=element_text(size=12))

png("acc perf.png", width = 8, height = 4, units = "in", res = 300)
acc2
dev.off()


## The remaining code is for the out-of-sample analyses
## We originally only analyzed models with Individual Differences (ID)
## Then added models without for comparison
## The easier way to do this was to save the results, then copy/paste
## The code rather than re-write it, which is what you see below

## Subset forecasts from training sample for tables 5-7 analysis
br_ifps_f <- br_ifps_s[br_ifps_s$e_l_f == "l" & br_ifps_s$fcasts >= 5,]

## Save separately
br_ifps_f_all <- br_ifps_f

## Fit training models with individual differences and obtain results
## Note the following conventions in these results
## i = individual difference only, v = simple, f = hierarchical, t = IRT
## We know the conventions don't make much sense, the code was adapted from
## a different analysis and would have have been tedious to change further

lmer_vf <- lmer(correct_prob ~ g_int + 
                  cog_style + pkScore + pk_conf_gap +
                  age + gender + ed_num + acc_std_f_e + fcasts_f_e + ifp_ct_f_e +
                  time_rem_log + 
                  (1 | discover_id) + (1 | user_id), br_ifps_f)


lmer_ff <- lmer(correct_prob ~ g_int + 
                  cog_style + pkScore + pk_conf_gap +
                  age + gender + ed_num + hier_e_f + fcasts_f_e + ifp_ct_f_e +
                  time_rem_log + 
                  (1 | discover_id) + (1 | user_id), br_ifps_f)


lmer_tf <- lmer(correct_prob ~ g_int + 
                  cog_style + pkScore + pk_conf_gap +
                  age + gender + ed_num + theta_train1 + fcasts_f_e + ifp_ct_f_e +
                  time_rem_log + 
                  (1 | discover_id) + (1 | user_id), br_ifps_f)



lmer_if <- lmer(correct_prob ~ g_int + 
                  cog_style + pkScore + pk_conf_gap +
                  age + gender + ed_num + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), br_ifps_f)


## Subset testing sample
br_ifps_test <- br_ifps_s[br_ifps_s$e_l_f =="f" & br_ifps_s$fcasts >= 5,]

users <- unique(irt_dat[c("user_id","g_int",
                            "cog_style", "pkScore", "pk_conf_gap",
                            "age", "gender", "ed_num")])


usrs2 <- irt_dat[c(grep("user_id",names(irt_dat)),
                   grep("acc",names(irt_dat)),
                   grep("hier",names(irt_dat)),
                   grep("theta", names(irt_dat)),
                   grep("ifp_ct",names(irt_dat)),
                   grep("fcasts",names(irt_dat)))]

usrs2 <- unique(usrs2)                      

users <- left_join(users, usrs2)


## Random intercepts from testing sample for correlation analysis (table 5)
testmod <- lmer(correct_prob ~ time_rem_log + (1 | user_id) + (1 | discover_id),
                br_ifps_test)


testres <- data.frame(user_id = rownames(ranef(testmod)$user_id),
                      mus = ranef(testmod)$user_id$`(Intercept)`)

users_test <- join_all(list(users, testres), type = "left")


users2 <- users_test

## Initialize new levels for question ID and set time remaining to 0
## And reset user IDs to different values
## To obtain predicted estimates for accuracy
## Based on fixed effects
users2$discover_id <- 0
users2$time_rem_log <- 0
users2$user_id <- paste(users2$user_id, "outsamp")


## Obtain predicted estiamtes
users2$rk_v <- predict(lmer_vf, newdata = users2, allow.new.levels = TRUE)
users2$rk_f <- predict(lmer_ff, newdata = users2, allow.new.levels = TRUE)
users2$rk_t <- predict(lmer_tf, newdata = users2, allow.new.levels = TRUE)
users2$rk_i <- predict(lmer_if, newdata = users2, allow.new.levels = TRUE)

## Portion of table 5 **with** ID

t5a <- round(cor(users2[c("mus","rk_f","rk_t","rk_v","rk_i")],
    use = "pairwise.complete.obs"),2)

write.csv(t5a, "table 5 with ID.csv")

## Save results separtely
users2a <- users2[c("user_id","mus","rk_f","rk_t","rk_v","rk_i")]


## rank users by predicted accuracy for aggregation weighting
users2$wt_v <- rank(users2$rk_v)
users2$wt_f <- rank(predict(lmer_ff, newdata = users2, allow.new.levels = TRUE))
users2$wt_t <- rank(predict(lmer_tf, newdata = users2, allow.new.levels = TRUE))
users2$wt_i <- rank(predict(lmer_if, newdata = users2, allow.new.levels = TRUE))

## Save testing sample data separately
test_dat <- br_ifps_test

test_dat2 <- test_dat


test_dat$user_id <- paste(test_dat$user_id, "outsamp")

## Compute mean daily Brier and accuracy scores by weighting method

#carry forward daily forecast values
#so any forecast is repeated for each day until it is updated
d_ifps <- data.frame(date=as.numeric(min(as.Date(test_dat$date))):as.numeric(max(as.Date(test_dat$date))))
d_ifps$date <- as.Date(d_ifps$date, origin="1970-01-01")

c_ifps <- expand.grid(d_ifps$date, unique(test_dat$user_id),unique(test_dat$discover_id))
colnames(c_ifps) <- c("date","user_id","discover_id")

c_ifps <- c_ifps[order(c_ifps$discover_id,c_ifps$user_id,c_ifps$date),]


c_ifps <- left_join(c_ifps, unique(test_dat[c("discover_id","start_date","close_date")]))

c_ifps <- c_ifps[c_ifps$date >= c_ifps$start_date & c_ifps$date <= c_ifps$close_date,]

test_dat$date <- as.Date(test_dat$date)
c_ifps <- left_join(c_ifps,test_dat[c("user_id","discover_id","date",
                                      "option_1","option_2","option_3","option_4",
                                      "option_5")])


c_ifps <- c_ifps %>% group_by(discover_id, user_id) %>% 
  mutate_all(funs(na.locf(.,na.rm = FALSE))) %>% ungroup()


c_ifps <- c_ifps[!is.na(c_ifps$option_1),]

c_ifps <- left_join(c_ifps, unique(test_dat[c("discover_id","is_ordinal")]))

c_ifps <- left_join(c_ifps, users2[c("user_id","wt_i","wt_v",
                                     "wt_f","wt_t")])



c_ifps <- c_ifps[!is.na(c_ifps$wt_v),]

## Weight forecasts by predicted forecaster ranking
daily_casts <- c_ifps %>% group_by(discover_id, date) %>% 
  summarize(option_v_1 = weighted.mean(option_1, wt_v),
            option_v_2 = weighted.mean(option_2, wt_v),
            option_v_3 = weighted.mean(option_3, wt_v),
            option_v_4 = weighted.mean(option_4, wt_v),
            option_v_5 = weighted.mean(option_5, wt_v),
            option_f_1 = weighted.mean(option_1, wt_f),
            option_f_2 = weighted.mean(option_2, wt_f),
            option_f_3 = weighted.mean(option_3, wt_f),
            option_f_4 = weighted.mean(option_4, wt_f),
            option_f_5 = weighted.mean(option_5, wt_f),
            option_t_1 = weighted.mean(option_1, wt_t),
            option_t_2 = weighted.mean(option_2, wt_t),
            option_t_3 = weighted.mean(option_3, wt_t),
            option_t_4 = weighted.mean(option_4, wt_t),
            option_t_5 = weighted.mean(option_5, wt_t),
            option_i_1 = weighted.mean(option_1, wt_i),
            option_i_2 = weighted.mean(option_2, wt_i),
            option_i_3 = weighted.mean(option_3, wt_i),
            option_i_4 = weighted.mean(option_4, wt_i),
            option_i_5 = weighted.mean(option_5, wt_i),
            option_1 = mean(option_1),
            option_2 = mean(option_2),
            option_3 = mean(option_3),
            option_4 = mean(option_4),
            option_5 = mean(option_5)) %>% ungroup()


daily_casts <- left_join(daily_casts, unique(test_dat[c("discover_id","is_ordinal","resolution",
                                                        "num_options")]))


## Calculate daily Brier scores for each weighted forecast
ord_ifps <- daily_casts[daily_casts$is_ordinal == "True",]
n_ord_ifps <- daily_casts[daily_casts$is_ordinal == "False",]


#brier_v score calculation for nomminal IFPs
n_ord_ifps$brier_v <- ifelse(n_ord_ifps$resolution == 1, ((1-n_ord_ifps$option_v_1)^2 + (0-n_ord_ifps$option_v_2)^2 +
                                                            (0-n_ord_ifps$option_v_3)^2 + (0-n_ord_ifps$option_v_4)^2 + (0-n_ord_ifps$option_v_5)^2),
                             ifelse(n_ord_ifps$resolution == 2, ((1-n_ord_ifps$option_v_2)^2 + (0-n_ord_ifps$option_v_1)^2 +
                                                                   (0-n_ord_ifps$option_v_3)^2 + (0-n_ord_ifps$option_v_4)^2 + (0-n_ord_ifps$option_v_5)^2),
                                    ifelse(n_ord_ifps$resolution == 3, ((1-n_ord_ifps$option_v_3)^2 + (0-n_ord_ifps$option_v_2)^2 +
                                                                          (0-n_ord_ifps$option_v_1)^2 + (0-n_ord_ifps$option_v_4)^2 + (0-n_ord_ifps$option_v_5)^2),
                                           ifelse(n_ord_ifps$resolution == 4, ((1-n_ord_ifps$option_v_4)^2 + (0-n_ord_ifps$option_v_2)^2 +
                                                                                 (0-n_ord_ifps$option_v_3)^2 + (0-n_ord_ifps$option_v_1)^2 + (0-n_ord_ifps$option_v_5)^2),
                                                  ifelse(n_ord_ifps$resolution == 5, ((1-n_ord_ifps$option_v_5)^2 + (0-n_ord_ifps$option_v_2)^2 +
                                                                                        (0-n_ord_ifps$option_v_3)^2 + (0-n_ord_ifps$option_v_4)^2 + (0-n_ord_ifps$option_v_1)^2),NA)))))


#brier_v score calculation for ordinal IFPs
ord_ifps$brier_v1 <- ifelse(ord_ifps$resolution == 1, ((1-ord_ifps$option_v_1)^2 + ((0-(1-ord_ifps$option_v_1))^2)),
                            ((0-ord_ifps$option_v_1)^2 + ((1-(1-ord_ifps$option_v_1))^2)))

ord_ifps$brier_v2 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2,
                            (1-(ord_ifps$option_v_1 + ord_ifps$option_v_2))^2 + (0-(1-(ord_ifps$option_v_1 + 
                                                                                         ord_ifps$option_v_2)))^2,
                            (0-(ord_ifps$option_v_1 + ord_ifps$option_v_2))^2 + (1-(1-(ord_ifps$option_v_1 + 
                                                                                         ord_ifps$option_v_2)))^2)

ord_ifps$brier_v3 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2 | ord_ifps$resolution == 3,
                            (0-(ord_ifps$option_v_4 + ord_ifps$option_v_5))^2 + (1-(1-(ord_ifps$option_v_4 + 
                                                                                         ord_ifps$option_v_5)))^2,
                            (1-(ord_ifps$option_v_4 + ord_ifps$option_v_5))^2 + (0-(1-(ord_ifps$option_v_4 + 
                                                                                         ord_ifps$option_v_5)))^2)

ord_ifps$brier_v4 <- ifelse(ord_ifps$resolution != 5, ((0-ord_ifps$option_v_5)^2 + ((1-(1-ord_ifps$option_v_5))^2)),
                            ((1-ord_ifps$option_v_5)^2 + ((0-(1-ord_ifps$option_v_5))^2)))

ord_ifps$brier_v <- (ord_ifps$brier_v1 + ord_ifps$brier_v2 + ord_ifps$brier_v3 + ord_ifps$brier_v4)/
  (ord_ifps$num_options - 1)


#create variables of all missing values so the nominal and ordinal IFP tables can be re-merged
n_ord_ifps$brier_v1 <- NA
n_ord_ifps$brier_v2 <- NA
n_ord_ifps$brier_v3 <- NA
n_ord_ifps$brier_v4 <- NA




#brier_f score calculation for nomminal IFPs
n_ord_ifps$brier_f <- ifelse(n_ord_ifps$resolution == 1, ((1-n_ord_ifps$option_f_1)^2 + (0-n_ord_ifps$option_f_2)^2 +
                                                            (0-n_ord_ifps$option_f_3)^2 + (0-n_ord_ifps$option_f_4)^2 + (0-n_ord_ifps$option_f_5)^2),
                             ifelse(n_ord_ifps$resolution == 2, ((1-n_ord_ifps$option_f_2)^2 + (0-n_ord_ifps$option_f_1)^2 +
                                                                   (0-n_ord_ifps$option_f_3)^2 + (0-n_ord_ifps$option_f_4)^2 + (0-n_ord_ifps$option_f_5)^2),
                                    ifelse(n_ord_ifps$resolution == 3, ((1-n_ord_ifps$option_f_3)^2 + (0-n_ord_ifps$option_f_2)^2 +
                                                                          (0-n_ord_ifps$option_f_1)^2 + (0-n_ord_ifps$option_f_4)^2 + (0-n_ord_ifps$option_f_5)^2),
                                           ifelse(n_ord_ifps$resolution == 4, ((1-n_ord_ifps$option_f_4)^2 + (0-n_ord_ifps$option_f_2)^2 +
                                                                                 (0-n_ord_ifps$option_f_3)^2 + (0-n_ord_ifps$option_f_1)^2 + (0-n_ord_ifps$option_f_5)^2),
                                                  ifelse(n_ord_ifps$resolution == 5, ((1-n_ord_ifps$option_f_5)^2 + (0-n_ord_ifps$option_f_2)^2 +
                                                                                        (0-n_ord_ifps$option_f_3)^2 + (0-n_ord_ifps$option_f_4)^2 + (0-n_ord_ifps$option_f_1)^2),NA)))))


#brier_f score calculation for ordinal IFPs
ord_ifps$brier_f1 <- ifelse(ord_ifps$resolution == 1, ((1-ord_ifps$option_f_1)^2 + ((0-(1-ord_ifps$option_f_1))^2)),
                            ((0-ord_ifps$option_f_1)^2 + ((1-(1-ord_ifps$option_f_1))^2)))

ord_ifps$brier_f2 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2,
                            (1-(ord_ifps$option_f_1 + ord_ifps$option_f_2))^2 + (0-(1-(ord_ifps$option_f_1 + 
                                                                                         ord_ifps$option_f_2)))^2,
                            (0-(ord_ifps$option_f_1 + ord_ifps$option_f_2))^2 + (1-(1-(ord_ifps$option_f_1 + 
                                                                                         ord_ifps$option_f_2)))^2)

ord_ifps$brier_f3 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2 | ord_ifps$resolution == 3,
                            (0-(ord_ifps$option_f_4 + ord_ifps$option_f_5))^2 + (1-(1-(ord_ifps$option_f_4 + 
                                                                                         ord_ifps$option_f_5)))^2,
                            (1-(ord_ifps$option_f_4 + ord_ifps$option_f_5))^2 + (0-(1-(ord_ifps$option_f_4 + 
                                                                                         ord_ifps$option_f_5)))^2)

ord_ifps$brier_f4 <- ifelse(ord_ifps$resolution != 5, ((0-ord_ifps$option_f_5)^2 + ((1-(1-ord_ifps$option_f_5))^2)),
                            ((1-ord_ifps$option_f_5)^2 + ((0-(1-ord_ifps$option_f_5))^2)))

ord_ifps$brier_f <- (ord_ifps$brier_f1 + ord_ifps$brier_f2 + ord_ifps$brier_f3 + ord_ifps$brier_f4)/
  (ord_ifps$num_options - 1)


#create variables of all missing values so the nominal and ordinal IFP tables can be re-merged
n_ord_ifps$brier_f1 <- NA
n_ord_ifps$brier_f2 <- NA
n_ord_ifps$brier_f3 <- NA
n_ord_ifps$brier_f4 <- NA



#brier_t score calculation for nomminal IFPs
n_ord_ifps$brier_t <- ifelse(n_ord_ifps$resolution == 1, ((1-n_ord_ifps$option_t_1)^2 + (0-n_ord_ifps$option_t_2)^2 +
                                                            (0-n_ord_ifps$option_t_3)^2 + (0-n_ord_ifps$option_t_4)^2 + (0-n_ord_ifps$option_t_5)^2),
                             ifelse(n_ord_ifps$resolution == 2, ((1-n_ord_ifps$option_t_2)^2 + (0-n_ord_ifps$option_t_1)^2 +
                                                                   (0-n_ord_ifps$option_t_3)^2 + (0-n_ord_ifps$option_t_4)^2 + (0-n_ord_ifps$option_t_5)^2),
                                    ifelse(n_ord_ifps$resolution == 3, ((1-n_ord_ifps$option_t_3)^2 + (0-n_ord_ifps$option_t_2)^2 +
                                                                          (0-n_ord_ifps$option_t_1)^2 + (0-n_ord_ifps$option_t_4)^2 + (0-n_ord_ifps$option_t_5)^2),
                                           ifelse(n_ord_ifps$resolution == 4, ((1-n_ord_ifps$option_t_4)^2 + (0-n_ord_ifps$option_t_2)^2 +
                                                                                 (0-n_ord_ifps$option_t_3)^2 + (0-n_ord_ifps$option_t_1)^2 + (0-n_ord_ifps$option_t_5)^2),
                                                  ifelse(n_ord_ifps$resolution == 5, ((1-n_ord_ifps$option_t_5)^2 + (0-n_ord_ifps$option_t_2)^2 +
                                                                                        (0-n_ord_ifps$option_t_3)^2 + (0-n_ord_ifps$option_t_4)^2 + (0-n_ord_ifps$option_t_1)^2),NA)))))


#brier_t score calculation for ordinal IFPs
ord_ifps$brier_t1 <- ifelse(ord_ifps$resolution == 1, ((1-ord_ifps$option_t_1)^2 + ((0-(1-ord_ifps$option_t_1))^2)),
                            ((0-ord_ifps$option_t_1)^2 + ((1-(1-ord_ifps$option_t_1))^2)))

ord_ifps$brier_t2 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2,
                            (1-(ord_ifps$option_t_1 + ord_ifps$option_t_2))^2 + (0-(1-(ord_ifps$option_t_1 + 
                                                                                         ord_ifps$option_t_2)))^2,
                            (0-(ord_ifps$option_t_1 + ord_ifps$option_t_2))^2 + (1-(1-(ord_ifps$option_t_1 + 
                                                                                         ord_ifps$option_t_2)))^2)

ord_ifps$brier_t3 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2 | ord_ifps$resolution == 3,
                            (0-(ord_ifps$option_t_4 + ord_ifps$option_t_5))^2 + (1-(1-(ord_ifps$option_t_4 + 
                                                                                         ord_ifps$option_t_5)))^2,
                            (1-(ord_ifps$option_t_4 + ord_ifps$option_t_5))^2 + (0-(1-(ord_ifps$option_t_4 + 
                                                                                         ord_ifps$option_t_5)))^2)

ord_ifps$brier_t4 <- ifelse(ord_ifps$resolution != 5, ((0-ord_ifps$option_t_5)^2 + ((1-(1-ord_ifps$option_t_5))^2)),
                            ((1-ord_ifps$option_t_5)^2 + ((0-(1-ord_ifps$option_t_5))^2)))

ord_ifps$brier_t <- (ord_ifps$brier_t1 + ord_ifps$brier_t2 + ord_ifps$brier_t3 + ord_ifps$brier_t4)/
  (ord_ifps$num_options - 1)


#create variables of all missing values so the nominal and ordinal IFP tables can be re-merged
n_ord_ifps$brier_t1 <- NA
n_ord_ifps$brier_t2 <- NA
n_ord_ifps$brier_t3 <- NA
n_ord_ifps$brier_t4 <- NA




#brier_i score calculation for nomminal IFPs
n_ord_ifps$brier_i <- ifelse(n_ord_ifps$resolution == 1, ((1-n_ord_ifps$option_i_1)^2 + (0-n_ord_ifps$option_i_2)^2 +
                                                            (0-n_ord_ifps$option_i_3)^2 + (0-n_ord_ifps$option_i_4)^2 + (0-n_ord_ifps$option_i_5)^2),
                             ifelse(n_ord_ifps$resolution == 2, ((1-n_ord_ifps$option_i_2)^2 + (0-n_ord_ifps$option_i_1)^2 +
                                                                   (0-n_ord_ifps$option_i_3)^2 + (0-n_ord_ifps$option_i_4)^2 + (0-n_ord_ifps$option_i_5)^2),
                                    ifelse(n_ord_ifps$resolution == 3, ((1-n_ord_ifps$option_i_3)^2 + (0-n_ord_ifps$option_i_2)^2 +
                                                                          (0-n_ord_ifps$option_i_1)^2 + (0-n_ord_ifps$option_i_4)^2 + (0-n_ord_ifps$option_i_5)^2),
                                           ifelse(n_ord_ifps$resolution == 4, ((1-n_ord_ifps$option_i_4)^2 + (0-n_ord_ifps$option_i_2)^2 +
                                                                                 (0-n_ord_ifps$option_i_3)^2 + (0-n_ord_ifps$option_i_1)^2 + (0-n_ord_ifps$option_i_5)^2),
                                                  ifelse(n_ord_ifps$resolution == 5, ((1-n_ord_ifps$option_i_5)^2 + (0-n_ord_ifps$option_i_2)^2 +
                                                                                        (0-n_ord_ifps$option_i_3)^2 + (0-n_ord_ifps$option_i_4)^2 + (0-n_ord_ifps$option_i_1)^2),NA)))))


#brier_i score calculation for ordinal IFPs
ord_ifps$brier_i1 <- ifelse(ord_ifps$resolution == 1, ((1-ord_ifps$option_i_1)^2 + ((0-(1-ord_ifps$option_i_1))^2)),
                            ((0-ord_ifps$option_i_1)^2 + ((1-(1-ord_ifps$option_i_1))^2)))

ord_ifps$brier_i2 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2,
                            (1-(ord_ifps$option_i_1 + ord_ifps$option_i_2))^2 + (0-(1-(ord_ifps$option_i_1 + 
                                                                                         ord_ifps$option_i_2)))^2,
                            (0-(ord_ifps$option_i_1 + ord_ifps$option_i_2))^2 + (1-(1-(ord_ifps$option_i_1 + 
                                                                                         ord_ifps$option_i_2)))^2)

ord_ifps$brier_i3 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2 | ord_ifps$resolution == 3,
                            (0-(ord_ifps$option_i_4 + ord_ifps$option_i_5))^2 + (1-(1-(ord_ifps$option_i_4 + 
                                                                                         ord_ifps$option_i_5)))^2,
                            (1-(ord_ifps$option_i_4 + ord_ifps$option_i_5))^2 + (0-(1-(ord_ifps$option_i_4 + 
                                                                                         ord_ifps$option_i_5)))^2)

ord_ifps$brier_i4 <- ifelse(ord_ifps$resolution != 5, ((0-ord_ifps$option_i_5)^2 + ((1-(1-ord_ifps$option_i_5))^2)),
                            ((1-ord_ifps$option_i_5)^2 + ((0-(1-ord_ifps$option_i_5))^2)))

ord_ifps$brier_i <- (ord_ifps$brier_i1 + ord_ifps$brier_i2 + ord_ifps$brier_i3 + ord_ifps$brier_i4)/
  (ord_ifps$num_options - 1)


#create variables of all missing values so the nominal and ordinal IFP tables can be re-merged
n_ord_ifps$brier_i1 <- NA
n_ord_ifps$brier_i2 <- NA
n_ord_ifps$brier_i3 <- NA
n_ord_ifps$brier_i4 <- NA



#brier score calculation for nomminal IFPs
n_ord_ifps$brier <- ifelse(n_ord_ifps$resolution == 1, ((1-n_ord_ifps$option_1)^2 + (0-n_ord_ifps$option_2)^2 +
                                                          (0-n_ord_ifps$option_3)^2 + (0-n_ord_ifps$option_4)^2 + (0-n_ord_ifps$option_5)^2),
                           ifelse(n_ord_ifps$resolution == 2, ((1-n_ord_ifps$option_2)^2 + (0-n_ord_ifps$option_1)^2 +
                                                                 (0-n_ord_ifps$option_3)^2 + (0-n_ord_ifps$option_4)^2 + (0-n_ord_ifps$option_5)^2),
                                  ifelse(n_ord_ifps$resolution == 3, ((1-n_ord_ifps$option_3)^2 + (0-n_ord_ifps$option_2)^2 +
                                                                        (0-n_ord_ifps$option_1)^2 + (0-n_ord_ifps$option_4)^2 + (0-n_ord_ifps$option_5)^2),
                                         ifelse(n_ord_ifps$resolution == 4, ((1-n_ord_ifps$option_4)^2 + (0-n_ord_ifps$option_2)^2 +
                                                                               (0-n_ord_ifps$option_3)^2 + (0-n_ord_ifps$option_1)^2 + (0-n_ord_ifps$option_5)^2),
                                                ifelse(n_ord_ifps$resolution == 5, ((1-n_ord_ifps$option_5)^2 + (0-n_ord_ifps$option_2)^2 +
                                                                                      (0-n_ord_ifps$option_3)^2 + (0-n_ord_ifps$option_4)^2 + (0-n_ord_ifps$option_1)^2),NA)))))


#brier score calculation for ordinal IFPs
ord_ifps$brier1 <- ifelse(ord_ifps$resolution == 1, ((1-ord_ifps$option_1)^2 + ((0-(1-ord_ifps$option_1))^2)),
                          ((0-ord_ifps$option_1)^2 + ((1-(1-ord_ifps$option_1))^2)))

ord_ifps$brier2 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2,
                          (1-(ord_ifps$option_1 + ord_ifps$option_2))^2 + (0-(1-(ord_ifps$option_1 + 
                                                                                   ord_ifps$option_2)))^2,
                          (0-(ord_ifps$option_1 + ord_ifps$option_2))^2 + (1-(1-(ord_ifps$option_1 + 
                                                                                   ord_ifps$option_2)))^2)

ord_ifps$brier3 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2 | ord_ifps$resolution == 3,
                          (0-(ord_ifps$option_4 + ord_ifps$option_5))^2 + (1-(1-(ord_ifps$option_4 + 
                                                                                   ord_ifps$option_5)))^2,
                          (1-(ord_ifps$option_4 + ord_ifps$option_5))^2 + (0-(1-(ord_ifps$option_4 + 
                                                                                   ord_ifps$option_5)))^2)

ord_ifps$brier4 <- ifelse(ord_ifps$resolution != 5, ((0-ord_ifps$option_5)^2 + ((1-(1-ord_ifps$option_5))^2)),
                          ((1-ord_ifps$option_5)^2 + ((0-(1-ord_ifps$option_5))^2)))

ord_ifps$brier <- (ord_ifps$brier1 + ord_ifps$brier2 + ord_ifps$brier3 + ord_ifps$brier4)/
  (ord_ifps$num_options - 1)



#create variables of all missing values so the nominal and ordinal IFP tables can be re-merged
n_ord_ifps$brier1 <- NA
n_ord_ifps$brier2 <- NA
n_ord_ifps$brier3 <- NA
n_ord_ifps$brier4 <- NA


## Portion of Table 6 **with** ID. Repeated below for portions without
br_wtscrs <- rbind(ord_ifps, n_ord_ifps)

## Mean daily Brier scores

cm1a <- colMeans(br_wtscrs[c("brier_f","brier_v","brier_t","brier_i",
                     "brier")])




br_wtscrs$acc_f <- VGAM::probitlink(1-(sqrt(br_wtscrs$brier_f/2)))
br_wtscrs$acc_v <- VGAM::probitlink(1-(sqrt(br_wtscrs$brier_v/2)))
br_wtscrs$acc_t <- VGAM::probitlink(1-(sqrt(br_wtscrs$brier_t/2)))
br_wtscrs$acc_i <- VGAM::probitlink(1-(sqrt(br_wtscrs$brier_i/2)))
br_wtscrs$acc <- VGAM::probitlink(1-(sqrt(br_wtscrs$brier/2)))

## Mean daily normalized accuracy
cm1b <- colMeans(br_wtscrs[c(grep("acc", names(br_wtscrs)))])

## Repeat above for models **without** ID for table 5-7 results
br_wtscrs_a <- br_wtscrs




lmer_vf <- lmer(correct_prob ~  acc_std_f_e + fcasts_f_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), br_ifps_f)


lmer_ff <- lmer(correct_prob ~ hier_e_f + fcasts_f_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), br_ifps_f)

lmer_tf <- lmer(correct_prob ~ theta_train1 + fcasts_f_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), br_ifps_f)



lmer_if <- lmer(correct_prob ~ g_int + 
                  cog_style + pkScore + pk_conf_gap +
                  age + gender + ed_num + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), br_ifps_f)



br_ifps_test <- br_ifps_s[br_ifps_s$e_l_f =="f" & br_ifps_s$fcasts >= 5,]


users <- unique(irt_dat[c("user_id","g_int",
                          "cog_style", "pkScore", "pk_conf_gap",
                          "age", "gender", "ed_num")])


usrs2 <- irt_dat[c(grep("user_id",names(irt_dat)),
                   grep("acc",names(irt_dat)),
                   grep("hier",names(irt_dat)),
                   grep("theta", names(irt_dat)),
                   grep("ifp_ct",names(irt_dat)),
                   grep("fcasts",names(irt_dat)))]


usrs2 <- unique(usrs2)                      

users <- left_join(users, usrs2)




testmod <- lmer(correct_prob ~ time_rem_log + (1 | user_id) + (1 | discover_id),
                br_ifps_test)


testres <- data.frame(user_id = rownames(ranef(testmod)$user_id),
                      mus = ranef(testmod)$user_id$`(Intercept)`)

users_test <- join_all(list(users, testres), type = "left")

users2 <- users_test

users2$discover_id <- 0
users2$time_rem_log <- 0
users2$user_id <- paste(users2$user_id, "outsamp")

users2$rk_v <- predict(lmer_vf, newdata = users2, allow.new.levels = TRUE)
users2$rk_f <- predict(lmer_ff, newdata = users2, allow.new.levels = TRUE)
users2$rk_t <- predict(lmer_tf, newdata = users2, allow.new.levels = TRUE)
users2$rk_i <- predict(lmer_if, newdata = users2, allow.new.levels = TRUE)

t5b <- cor(users2[c("mus","rk_f","rk_t","rk_v","rk_i")],
    use = "pairwise.complete.obs")

write.csv(t5b, "table 5 wo ID.csv")

users2b <- users2[c("user_id","mus","rk_f","rk_t","rk_v","rk_i")]



users2$wt_v <- rank(users2$rk_v)
users2$wt_f <- rank(predict(lmer_ff, newdata = users2, allow.new.levels = TRUE))
users2$wt_t <- rank(predict(lmer_tf, newdata = users2, allow.new.levels = TRUE))
users2$wt_i <- rank(predict(lmer_if, newdata = users2, allow.new.levels = TRUE))


test_dat <- br_ifps_test

test_dat2 <- test_dat


test_dat$user_id <- paste(test_dat$user_id, "outsamp")



#carry forward daily forecast values
d_ifps <- data.frame(date=as.numeric(min(as.Date(test_dat$date))):as.numeric(max(as.Date(test_dat$date))))
d_ifps$date <- as.Date(d_ifps$date, origin="1970-01-01")

c_ifps <- expand.grid(d_ifps$date, unique(test_dat$user_id),unique(test_dat$discover_id))
colnames(c_ifps) <- c("date","user_id","discover_id")

c_ifps <- c_ifps[order(c_ifps$discover_id,c_ifps$user_id,c_ifps$date),]


c_ifps <- left_join(c_ifps, unique(test_dat[c("discover_id","start_date","close_date")]))

c_ifps <- c_ifps[c_ifps$date >= c_ifps$start_date & c_ifps$date <= c_ifps$close_date,]

test_dat$date <- as.Date(test_dat$date)
c_ifps <- left_join(c_ifps,test_dat[c("user_id","discover_id","date",
                                      "option_1","option_2","option_3","option_4",
                                      "option_5")])


c_ifps <- c_ifps %>% group_by(discover_id, user_id) %>% 
  mutate_all(funs(na.locf(.,na.rm = FALSE))) %>% ungroup()


c_ifps <- c_ifps[!is.na(c_ifps$option_1),]

c_ifps <- left_join(c_ifps, unique(test_dat[c("discover_id","is_ordinal")]))

c_ifps <- left_join(c_ifps, users2[c("user_id","wt_i","wt_v",
                                     "wt_f","wt_t")])



c_ifps <- c_ifps[!is.na(c_ifps$wt_v),]

daily_casts <- c_ifps %>% group_by(discover_id, date) %>% 
  summarize(option_v_1 = weighted.mean(option_1, wt_v),
            option_v_2 = weighted.mean(option_2, wt_v),
            option_v_3 = weighted.mean(option_3, wt_v),
            option_v_4 = weighted.mean(option_4, wt_v),
            option_v_5 = weighted.mean(option_5, wt_v),
            option_f_1 = weighted.mean(option_1, wt_f),
            option_f_2 = weighted.mean(option_2, wt_f),
            option_f_3 = weighted.mean(option_3, wt_f),
            option_f_4 = weighted.mean(option_4, wt_f),
            option_f_5 = weighted.mean(option_5, wt_f),
            option_t_1 = weighted.mean(option_1, wt_t),
            option_t_2 = weighted.mean(option_2, wt_t),
            option_t_3 = weighted.mean(option_3, wt_t),
            option_t_4 = weighted.mean(option_4, wt_t),
            option_t_5 = weighted.mean(option_5, wt_t),
            option_i_1 = weighted.mean(option_1, wt_i),
            option_i_2 = weighted.mean(option_2, wt_i),
            option_i_3 = weighted.mean(option_3, wt_i),
            option_i_4 = weighted.mean(option_4, wt_i),
            option_i_5 = weighted.mean(option_5, wt_i),
            option_1 = mean(option_1),
            option_2 = mean(option_2),
            option_3 = mean(option_3),
            option_4 = mean(option_4),
            option_5 = mean(option_5)) %>% ungroup()


daily_casts <- left_join(daily_casts, unique(test_dat[c("discover_id","is_ordinal","resolution",
                                                        "num_options")]))

ord_ifps <- daily_casts[daily_casts$is_ordinal == "True",]
n_ord_ifps <- daily_casts[daily_casts$is_ordinal == "False",]


#brier_v score calculation for nomminal IFPs
n_ord_ifps$brier_v <- ifelse(n_ord_ifps$resolution == 1, ((1-n_ord_ifps$option_v_1)^2 + (0-n_ord_ifps$option_v_2)^2 +
                                                            (0-n_ord_ifps$option_v_3)^2 + (0-n_ord_ifps$option_v_4)^2 + (0-n_ord_ifps$option_v_5)^2),
                             ifelse(n_ord_ifps$resolution == 2, ((1-n_ord_ifps$option_v_2)^2 + (0-n_ord_ifps$option_v_1)^2 +
                                                                   (0-n_ord_ifps$option_v_3)^2 + (0-n_ord_ifps$option_v_4)^2 + (0-n_ord_ifps$option_v_5)^2),
                                    ifelse(n_ord_ifps$resolution == 3, ((1-n_ord_ifps$option_v_3)^2 + (0-n_ord_ifps$option_v_2)^2 +
                                                                          (0-n_ord_ifps$option_v_1)^2 + (0-n_ord_ifps$option_v_4)^2 + (0-n_ord_ifps$option_v_5)^2),
                                           ifelse(n_ord_ifps$resolution == 4, ((1-n_ord_ifps$option_v_4)^2 + (0-n_ord_ifps$option_v_2)^2 +
                                                                                 (0-n_ord_ifps$option_v_3)^2 + (0-n_ord_ifps$option_v_1)^2 + (0-n_ord_ifps$option_v_5)^2),
                                                  ifelse(n_ord_ifps$resolution == 5, ((1-n_ord_ifps$option_v_5)^2 + (0-n_ord_ifps$option_v_2)^2 +
                                                                                        (0-n_ord_ifps$option_v_3)^2 + (0-n_ord_ifps$option_v_4)^2 + (0-n_ord_ifps$option_v_1)^2),NA)))))


#brier_v score calculation for ordinal IFPs
ord_ifps$brier_v1 <- ifelse(ord_ifps$resolution == 1, ((1-ord_ifps$option_v_1)^2 + ((0-(1-ord_ifps$option_v_1))^2)),
                            ((0-ord_ifps$option_v_1)^2 + ((1-(1-ord_ifps$option_v_1))^2)))

ord_ifps$brier_v2 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2,
                            (1-(ord_ifps$option_v_1 + ord_ifps$option_v_2))^2 + (0-(1-(ord_ifps$option_v_1 + 
                                                                                         ord_ifps$option_v_2)))^2,
                            (0-(ord_ifps$option_v_1 + ord_ifps$option_v_2))^2 + (1-(1-(ord_ifps$option_v_1 + 
                                                                                         ord_ifps$option_v_2)))^2)

ord_ifps$brier_v3 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2 | ord_ifps$resolution == 3,
                            (0-(ord_ifps$option_v_4 + ord_ifps$option_v_5))^2 + (1-(1-(ord_ifps$option_v_4 + 
                                                                                         ord_ifps$option_v_5)))^2,
                            (1-(ord_ifps$option_v_4 + ord_ifps$option_v_5))^2 + (0-(1-(ord_ifps$option_v_4 + 
                                                                                         ord_ifps$option_v_5)))^2)

ord_ifps$brier_v4 <- ifelse(ord_ifps$resolution != 5, ((0-ord_ifps$option_v_5)^2 + ((1-(1-ord_ifps$option_v_5))^2)),
                            ((1-ord_ifps$option_v_5)^2 + ((0-(1-ord_ifps$option_v_5))^2)))

ord_ifps$brier_v <- (ord_ifps$brier_v1 + ord_ifps$brier_v2 + ord_ifps$brier_v3 + ord_ifps$brier_v4)/
  (ord_ifps$num_options - 1)


#create variables of all missing values so the nominal and ordinal IFP tables can be re-merged
n_ord_ifps$brier_v1 <- NA
n_ord_ifps$brier_v2 <- NA
n_ord_ifps$brier_v3 <- NA
n_ord_ifps$brier_v4 <- NA




#brier_f score calculation for nomminal IFPs
n_ord_ifps$brier_f <- ifelse(n_ord_ifps$resolution == 1, ((1-n_ord_ifps$option_f_1)^2 + (0-n_ord_ifps$option_f_2)^2 +
                                                            (0-n_ord_ifps$option_f_3)^2 + (0-n_ord_ifps$option_f_4)^2 + (0-n_ord_ifps$option_f_5)^2),
                             ifelse(n_ord_ifps$resolution == 2, ((1-n_ord_ifps$option_f_2)^2 + (0-n_ord_ifps$option_f_1)^2 +
                                                                   (0-n_ord_ifps$option_f_3)^2 + (0-n_ord_ifps$option_f_4)^2 + (0-n_ord_ifps$option_f_5)^2),
                                    ifelse(n_ord_ifps$resolution == 3, ((1-n_ord_ifps$option_f_3)^2 + (0-n_ord_ifps$option_f_2)^2 +
                                                                          (0-n_ord_ifps$option_f_1)^2 + (0-n_ord_ifps$option_f_4)^2 + (0-n_ord_ifps$option_f_5)^2),
                                           ifelse(n_ord_ifps$resolution == 4, ((1-n_ord_ifps$option_f_4)^2 + (0-n_ord_ifps$option_f_2)^2 +
                                                                                 (0-n_ord_ifps$option_f_3)^2 + (0-n_ord_ifps$option_f_1)^2 + (0-n_ord_ifps$option_f_5)^2),
                                                  ifelse(n_ord_ifps$resolution == 5, ((1-n_ord_ifps$option_f_5)^2 + (0-n_ord_ifps$option_f_2)^2 +
                                                                                        (0-n_ord_ifps$option_f_3)^2 + (0-n_ord_ifps$option_f_4)^2 + (0-n_ord_ifps$option_f_1)^2),NA)))))


#brier_f score calculation for ordinal IFPs
ord_ifps$brier_f1 <- ifelse(ord_ifps$resolution == 1, ((1-ord_ifps$option_f_1)^2 + ((0-(1-ord_ifps$option_f_1))^2)),
                            ((0-ord_ifps$option_f_1)^2 + ((1-(1-ord_ifps$option_f_1))^2)))

ord_ifps$brier_f2 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2,
                            (1-(ord_ifps$option_f_1 + ord_ifps$option_f_2))^2 + (0-(1-(ord_ifps$option_f_1 + 
                                                                                         ord_ifps$option_f_2)))^2,
                            (0-(ord_ifps$option_f_1 + ord_ifps$option_f_2))^2 + (1-(1-(ord_ifps$option_f_1 + 
                                                                                         ord_ifps$option_f_2)))^2)

ord_ifps$brier_f3 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2 | ord_ifps$resolution == 3,
                            (0-(ord_ifps$option_f_4 + ord_ifps$option_f_5))^2 + (1-(1-(ord_ifps$option_f_4 + 
                                                                                         ord_ifps$option_f_5)))^2,
                            (1-(ord_ifps$option_f_4 + ord_ifps$option_f_5))^2 + (0-(1-(ord_ifps$option_f_4 + 
                                                                                         ord_ifps$option_f_5)))^2)

ord_ifps$brier_f4 <- ifelse(ord_ifps$resolution != 5, ((0-ord_ifps$option_f_5)^2 + ((1-(1-ord_ifps$option_f_5))^2)),
                            ((1-ord_ifps$option_f_5)^2 + ((0-(1-ord_ifps$option_f_5))^2)))

ord_ifps$brier_f <- (ord_ifps$brier_f1 + ord_ifps$brier_f2 + ord_ifps$brier_f3 + ord_ifps$brier_f4)/
  (ord_ifps$num_options - 1)


#create variables of all missing values so the nominal and ordinal IFP tables can be re-merged
n_ord_ifps$brier_f1 <- NA
n_ord_ifps$brier_f2 <- NA
n_ord_ifps$brier_f3 <- NA
n_ord_ifps$brier_f4 <- NA



#brier_t score calculation for nomminal IFPs
n_ord_ifps$brier_t <- ifelse(n_ord_ifps$resolution == 1, ((1-n_ord_ifps$option_t_1)^2 + (0-n_ord_ifps$option_t_2)^2 +
                                                            (0-n_ord_ifps$option_t_3)^2 + (0-n_ord_ifps$option_t_4)^2 + (0-n_ord_ifps$option_t_5)^2),
                             ifelse(n_ord_ifps$resolution == 2, ((1-n_ord_ifps$option_t_2)^2 + (0-n_ord_ifps$option_t_1)^2 +
                                                                   (0-n_ord_ifps$option_t_3)^2 + (0-n_ord_ifps$option_t_4)^2 + (0-n_ord_ifps$option_t_5)^2),
                                    ifelse(n_ord_ifps$resolution == 3, ((1-n_ord_ifps$option_t_3)^2 + (0-n_ord_ifps$option_t_2)^2 +
                                                                          (0-n_ord_ifps$option_t_1)^2 + (0-n_ord_ifps$option_t_4)^2 + (0-n_ord_ifps$option_t_5)^2),
                                           ifelse(n_ord_ifps$resolution == 4, ((1-n_ord_ifps$option_t_4)^2 + (0-n_ord_ifps$option_t_2)^2 +
                                                                                 (0-n_ord_ifps$option_t_3)^2 + (0-n_ord_ifps$option_t_1)^2 + (0-n_ord_ifps$option_t_5)^2),
                                                  ifelse(n_ord_ifps$resolution == 5, ((1-n_ord_ifps$option_t_5)^2 + (0-n_ord_ifps$option_t_2)^2 +
                                                                                        (0-n_ord_ifps$option_t_3)^2 + (0-n_ord_ifps$option_t_4)^2 + (0-n_ord_ifps$option_t_1)^2),NA)))))


#brier_t score calculation for ordinal IFPs
ord_ifps$brier_t1 <- ifelse(ord_ifps$resolution == 1, ((1-ord_ifps$option_t_1)^2 + ((0-(1-ord_ifps$option_t_1))^2)),
                            ((0-ord_ifps$option_t_1)^2 + ((1-(1-ord_ifps$option_t_1))^2)))

ord_ifps$brier_t2 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2,
                            (1-(ord_ifps$option_t_1 + ord_ifps$option_t_2))^2 + (0-(1-(ord_ifps$option_t_1 + 
                                                                                         ord_ifps$option_t_2)))^2,
                            (0-(ord_ifps$option_t_1 + ord_ifps$option_t_2))^2 + (1-(1-(ord_ifps$option_t_1 + 
                                                                                         ord_ifps$option_t_2)))^2)

ord_ifps$brier_t3 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2 | ord_ifps$resolution == 3,
                            (0-(ord_ifps$option_t_4 + ord_ifps$option_t_5))^2 + (1-(1-(ord_ifps$option_t_4 + 
                                                                                         ord_ifps$option_t_5)))^2,
                            (1-(ord_ifps$option_t_4 + ord_ifps$option_t_5))^2 + (0-(1-(ord_ifps$option_t_4 + 
                                                                                         ord_ifps$option_t_5)))^2)

ord_ifps$brier_t4 <- ifelse(ord_ifps$resolution != 5, ((0-ord_ifps$option_t_5)^2 + ((1-(1-ord_ifps$option_t_5))^2)),
                            ((1-ord_ifps$option_t_5)^2 + ((0-(1-ord_ifps$option_t_5))^2)))

ord_ifps$brier_t <- (ord_ifps$brier_t1 + ord_ifps$brier_t2 + ord_ifps$brier_t3 + ord_ifps$brier_t4)/
  (ord_ifps$num_options - 1)


#create variables of all missing values so the nominal and ordinal IFP tables can be re-merged
n_ord_ifps$brier_t1 <- NA
n_ord_ifps$brier_t2 <- NA
n_ord_ifps$brier_t3 <- NA
n_ord_ifps$brier_t4 <- NA




#brier_i score calculation for nomminal IFPs
n_ord_ifps$brier_i <- ifelse(n_ord_ifps$resolution == 1, ((1-n_ord_ifps$option_i_1)^2 + (0-n_ord_ifps$option_i_2)^2 +
                                                            (0-n_ord_ifps$option_i_3)^2 + (0-n_ord_ifps$option_i_4)^2 + (0-n_ord_ifps$option_i_5)^2),
                             ifelse(n_ord_ifps$resolution == 2, ((1-n_ord_ifps$option_i_2)^2 + (0-n_ord_ifps$option_i_1)^2 +
                                                                   (0-n_ord_ifps$option_i_3)^2 + (0-n_ord_ifps$option_i_4)^2 + (0-n_ord_ifps$option_i_5)^2),
                                    ifelse(n_ord_ifps$resolution == 3, ((1-n_ord_ifps$option_i_3)^2 + (0-n_ord_ifps$option_i_2)^2 +
                                                                          (0-n_ord_ifps$option_i_1)^2 + (0-n_ord_ifps$option_i_4)^2 + (0-n_ord_ifps$option_i_5)^2),
                                           ifelse(n_ord_ifps$resolution == 4, ((1-n_ord_ifps$option_i_4)^2 + (0-n_ord_ifps$option_i_2)^2 +
                                                                                 (0-n_ord_ifps$option_i_3)^2 + (0-n_ord_ifps$option_i_1)^2 + (0-n_ord_ifps$option_i_5)^2),
                                                  ifelse(n_ord_ifps$resolution == 5, ((1-n_ord_ifps$option_i_5)^2 + (0-n_ord_ifps$option_i_2)^2 +
                                                                                        (0-n_ord_ifps$option_i_3)^2 + (0-n_ord_ifps$option_i_4)^2 + (0-n_ord_ifps$option_i_1)^2),NA)))))


#brier_i score calculation for ordinal IFPs
ord_ifps$brier_i1 <- ifelse(ord_ifps$resolution == 1, ((1-ord_ifps$option_i_1)^2 + ((0-(1-ord_ifps$option_i_1))^2)),
                            ((0-ord_ifps$option_i_1)^2 + ((1-(1-ord_ifps$option_i_1))^2)))

ord_ifps$brier_i2 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2,
                            (1-(ord_ifps$option_i_1 + ord_ifps$option_i_2))^2 + (0-(1-(ord_ifps$option_i_1 + 
                                                                                         ord_ifps$option_i_2)))^2,
                            (0-(ord_ifps$option_i_1 + ord_ifps$option_i_2))^2 + (1-(1-(ord_ifps$option_i_1 + 
                                                                                         ord_ifps$option_i_2)))^2)

ord_ifps$brier_i3 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2 | ord_ifps$resolution == 3,
                            (0-(ord_ifps$option_i_4 + ord_ifps$option_i_5))^2 + (1-(1-(ord_ifps$option_i_4 + 
                                                                                         ord_ifps$option_i_5)))^2,
                            (1-(ord_ifps$option_i_4 + ord_ifps$option_i_5))^2 + (0-(1-(ord_ifps$option_i_4 + 
                                                                                         ord_ifps$option_i_5)))^2)

ord_ifps$brier_i4 <- ifelse(ord_ifps$resolution != 5, ((0-ord_ifps$option_i_5)^2 + ((1-(1-ord_ifps$option_i_5))^2)),
                            ((1-ord_ifps$option_i_5)^2 + ((0-(1-ord_ifps$option_i_5))^2)))

ord_ifps$brier_i <- (ord_ifps$brier_i1 + ord_ifps$brier_i2 + ord_ifps$brier_i3 + ord_ifps$brier_i4)/
  (ord_ifps$num_options - 1)


#create variables of all missing values so the nominal and ordinal IFP tables can be re-merged
n_ord_ifps$brier_i1 <- NA
n_ord_ifps$brier_i2 <- NA
n_ord_ifps$brier_i3 <- NA
n_ord_ifps$brier_i4 <- NA



#brier score calculation for nomminal IFPs
n_ord_ifps$brier <- ifelse(n_ord_ifps$resolution == 1, ((1-n_ord_ifps$option_1)^2 + (0-n_ord_ifps$option_2)^2 +
                                                          (0-n_ord_ifps$option_3)^2 + (0-n_ord_ifps$option_4)^2 + (0-n_ord_ifps$option_5)^2),
                           ifelse(n_ord_ifps$resolution == 2, ((1-n_ord_ifps$option_2)^2 + (0-n_ord_ifps$option_1)^2 +
                                                                 (0-n_ord_ifps$option_3)^2 + (0-n_ord_ifps$option_4)^2 + (0-n_ord_ifps$option_5)^2),
                                  ifelse(n_ord_ifps$resolution == 3, ((1-n_ord_ifps$option_3)^2 + (0-n_ord_ifps$option_2)^2 +
                                                                        (0-n_ord_ifps$option_1)^2 + (0-n_ord_ifps$option_4)^2 + (0-n_ord_ifps$option_5)^2),
                                         ifelse(n_ord_ifps$resolution == 4, ((1-n_ord_ifps$option_4)^2 + (0-n_ord_ifps$option_2)^2 +
                                                                               (0-n_ord_ifps$option_3)^2 + (0-n_ord_ifps$option_1)^2 + (0-n_ord_ifps$option_5)^2),
                                                ifelse(n_ord_ifps$resolution == 5, ((1-n_ord_ifps$option_5)^2 + (0-n_ord_ifps$option_2)^2 +
                                                                                      (0-n_ord_ifps$option_3)^2 + (0-n_ord_ifps$option_4)^2 + (0-n_ord_ifps$option_1)^2),NA)))))


#brier score calculation for ordinal IFPs
ord_ifps$brier1 <- ifelse(ord_ifps$resolution == 1, ((1-ord_ifps$option_1)^2 + ((0-(1-ord_ifps$option_1))^2)),
                          ((0-ord_ifps$option_1)^2 + ((1-(1-ord_ifps$option_1))^2)))

ord_ifps$brier2 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2,
                          (1-(ord_ifps$option_1 + ord_ifps$option_2))^2 + (0-(1-(ord_ifps$option_1 + 
                                                                                   ord_ifps$option_2)))^2,
                          (0-(ord_ifps$option_1 + ord_ifps$option_2))^2 + (1-(1-(ord_ifps$option_1 + 
                                                                                   ord_ifps$option_2)))^2)

ord_ifps$brier3 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2 | ord_ifps$resolution == 3,
                          (0-(ord_ifps$option_4 + ord_ifps$option_5))^2 + (1-(1-(ord_ifps$option_4 + 
                                                                                   ord_ifps$option_5)))^2,
                          (1-(ord_ifps$option_4 + ord_ifps$option_5))^2 + (0-(1-(ord_ifps$option_4 + 
                                                                                   ord_ifps$option_5)))^2)

ord_ifps$brier4 <- ifelse(ord_ifps$resolution != 5, ((0-ord_ifps$option_5)^2 + ((1-(1-ord_ifps$option_5))^2)),
                          ((1-ord_ifps$option_5)^2 + ((0-(1-ord_ifps$option_5))^2)))

ord_ifps$brier <- (ord_ifps$brier1 + ord_ifps$brier2 + ord_ifps$brier3 + ord_ifps$brier4)/
  (ord_ifps$num_options - 1)



#create variables of all missing values so the nominal and ordinal IFP tables can be re-merged
n_ord_ifps$brier1 <- NA
n_ord_ifps$brier2 <- NA
n_ord_ifps$brier3 <- NA
n_ord_ifps$brier4 <- NA


br_wtscrs <- rbind(ord_ifps, n_ord_ifps)


cm2a <- colMeans(br_wtscrs[c("brier_f","brier_v","brier_t","brier_i",
                             "brier")])



br_wtscrs$acc_f <- VGAM::probitlink(1-(sqrt(br_wtscrs$brier_f/2)))
br_wtscrs$acc_v <- VGAM::probitlink(1-(sqrt(br_wtscrs$brier_v/2)))
br_wtscrs$acc_t <- VGAM::probitlink(1-(sqrt(br_wtscrs$brier_t/2)))
br_wtscrs$acc_i <- VGAM::probitlink(1-(sqrt(br_wtscrs$brier_i/2)))
br_wtscrs$acc <- VGAM::probitlink(1-(sqrt(br_wtscrs$brier/2)))

cm2b <- colMeans(br_wtscrs[c("acc_f","acc_v","acc_t","acc_i",
                             "acc")])


## Combine versions with ID and without ID

br_wtscrs_a <- br_wtscrs_a[c("discover_id","date","brier_v",
                             "brier_t","brier_f","brier_i","brier",
                             "acc_v","acc_t","acc_f","acc_i","acc")]

br_wtscrs <- br_wtscrs[c("discover_id","date","brier_v",
                             "brier_t","brier_f",
                             "acc_v","acc_t","acc_f")]

names(br_wtscrs_a) <- c("discover_id","date",paste(names(br_wtscrs_a)[3:ncol(br_wtscrs_a)],
                                                   "ind",sep = "_"))

br_wtscrs <- left_join(br_wtscrs, br_wtscrs_a)

## Generate Table 6

tab6 <- round(data.frame(brier = c(colMeans(br_wtscrs_a[c("brier_ind","brier_i_ind","brier_v_ind",
                                                    "brier_f_ind","brier_t_ind")]),
                                      colMeans(br_wtscrs[c("brier_v","brier_f","brier_t")])),
                   acc = c(colMeans(br_wtscrs_a[c("acc_ind","acc_i_ind","acc_v_ind",
                                                  "acc_f_ind","acc_t_ind")]),
                           colMeans(br_wtscrs[c("acc_v","acc_f","acc_t")]))),3)


write.csv(tab6, "table6.csv")

## Fit hierarchical model for Table 7
br_wtscrs_l <- pivot_longer(br_wtscrs, 
                            cols = c("acc_f","acc_v","acc_t",
                                     paste(c("acc","acc_i","acc_f","acc_v","acc_t"),"ind",sep = "_")), names_to = "model",
                            values_to = "acc")

options(contrasts = c("contr.sum", "contr.poly"))

fin_hlm <- lmer(acc ~ model + (1 | discover_id), br_wtscrs_l)


mx1 <- afex::mixed(acc ~ model + (1 | discover_id), br_wtscrs_l,
                    method = "S")

## Pairwise comparisons for Table 7
library(emmeans)

emm1 <- emmeans(fin_hlm, "model", lmer.df = "satterthwaite",
                lmerTest.limit = 100000)

ctrst <- contrast(emm1, 'tukey') %>%
  broom::tidy()


## Get d values
ctrst_d <- effectsize::t_to_d(ctrst$statistic, ctrst$df, paired = TRUE)

ctrst_d_t <- cbind(ctrst, ctrst_d)

## Table 7 results
write.csv(ctrst_d_t, "rcta contrasts.csv")

