rm(list=ls())
setwd("~/S2") # Set Working Directory Path

library(tidyverse)
library(zoo)
library(rstan)

## Load question data
ifps <- read.csv("season 2 questions.csv",stringsAsFactors = F)

## Load forecast data
br_ifps <- read.csv("season 2 forecasts.csv",stringsAsFactors = F)

## Transform briers to normalized accuracy
br_ifps$correct <- 1-(sqrt(br_ifps$brier/2))


br_ifps$correct_prob <- ifelse(br_ifps$correct == 1, .999,
                               ifelse(br_ifps$correct == 0, .001,
                                      br_ifps$correct))

br_ifps$correct_probit <- VGAM::probitlink(br_ifps$correct_prob)

## Merge question information

br_ifps <- left_join(br_ifps, ifps[c("discover_id","e_l0","e_l1","e_l2",
                                       "e_l3","e_l4","e_l5","e_l6","e_l7",
                                       "e_l8","e_l9","e_l10","e_l_f")])

## calculate time remaining for each forecast

br_ifps$time_rem <- as.numeric(as.Date(br_ifps$end_date) - as.Date(br_ifps$date))



br_ifps$time_rem <- ifelse(br_ifps$time_rem < 0, 0, 
                           br_ifps$time_rem)


br_ifps$time_rem_scl <- br_ifps$time_rem / 365





## Merge all IRT results
br_ifps_all <- br_ifps

br_ifps_all$caster <- as.numeric(as.factor(br_ifps_all$user_id))
br_ifps_all$item <- as.numeric(as.factor(br_ifps_all$ifp_id))


all_base <- unique(br_ifps_all[c("caster","user_id")])



all1 <- read.csv("post_n_all.csv")
theta1 <- all1[grep("theta", all1$X),]
theta1$caster <- 1:nrow(theta1)
theta1 <- theta1[c("caster","mean")]
names(theta1) <- c("caster","theta_alll1")

all_results <- left_join(all_base, theta1)
all_results$caster <- NULL


## First Half
br_ifps_e10 <- br_ifps[br_ifps$e_l10 == "e",]

br_ifps_e10$caster <- as.numeric(as.factor(br_ifps_e10$user_id))
br_ifps_e10$item <- as.numeric(as.factor(br_ifps_e10$ifp_id))

half1_base <- unique(br_ifps_e10[c("caster","user_id")])



half1 <- read.csv("post_n_e10.csv")
theta1 <- half1[grep("theta", half1$X),]
theta1$caster <- 1:nrow(theta1)
theta1 <- theta1[c("caster","mean")]
names(theta1) <- c("caster","theta_half1")

half1_results <- left_join(half1_base, theta1)
half1_results$caster <- NULL

## Second half

br_ifps_l10 <- br_ifps[br_ifps$e_l10 == "l",]

br_ifps_l10$caster <- as.numeric(as.factor(br_ifps_l10$user_id))
br_ifps_l10$item <- as.numeric(as.factor(br_ifps_l10$ifp_id))


half2_base <- unique(br_ifps_l10[c("caster","user_id")])


half2 <- read.csv("post_n_l10.csv")
theta2 <- half2[grep("theta", half2$X),]
theta2$caster <- 1:nrow(theta2)
theta2 <- theta2[c("caster","mean")]
names(theta2) <- c("caster","theta_half2")

half2_results <- left_join(half2_base, theta2)

half2_results$caster <- NULL

base_results <- left_join(unique(br_ifps[c("user_id")]),half1_results)

base_results <- left_join(base_results, half2_results)




## Cross Validation Training Half 1
br_ifps_e_f <- br_ifps[br_ifps$e_l_f == "e",]


br_ifps_e_f$caster <- as.numeric(as.factor(br_ifps_e_f$user_id))

train1_base <- unique(br_ifps_e_f[c("caster","user_id")])



train1 <- read.csv("post_n_e_f.csv")
theta_t1 <- train1[grep("theta", train1$X),]
theta_t1$caster <- 1:nrow(theta_t1)
theta_t1 <- theta_t1[c("caster","mean")]
names(theta_t1) <- c("caster","theta_train1")

train1_results <- left_join(train1_base, theta_t1)
train1_results$caster <- NULL

## Second train

br_ifps_l_f <- br_ifps[br_ifps$e_l_f == "l",]

br_ifps_l_f$caster <- as.numeric(as.factor(br_ifps_l_f$user_id))

train2_base <- unique(br_ifps_l_f[c("caster","user_id")])


train2 <- read.csv("post_n_l_f.csv")
theta_t2 <- train2[grep("theta", train2$X),]
theta_t2$caster <- 1:nrow(theta_t2)
theta_t2 <- theta_t2[c("caster","mean")]
names(theta_t2) <- c("caster","theta_train2")

train2_results <- left_join(train2_base, theta_t2)

train2_results$caster <- NULL

base_results <- left_join(base_results, train1_results)

base_results <- left_join(base_results, train2_results)

## Partition 9

br_ifps_e9 <- br_ifps[br_ifps$e_l9 == "e" & !is.na(br_ifps$e_l9),]


br_ifps_e9$caster <- as.numeric(as.factor(br_ifps_e9$user_id))
br_ifps_e9$item <- as.numeric(as.factor(br_ifps_e9$discover_id))


e9_base <- unique(br_ifps_e9[c("caster","user_id")])



e9 <- read.csv("post_n_e9.csv")
theta_t1 <- e9[grep("theta", e9$X),]
theta_t1$caster <- 1:nrow(theta_t1)
theta_t1 <- theta_t1[c("caster","mean")]
names(theta_t1) <- c("caster","theta_e9")

e9_results <- left_join(e9_base, theta_t1)
e9_results$caster <- NULL


## Partition 8

br_ifps_e8 <- br_ifps[br_ifps$e_l8 == "e" & !is.na(br_ifps$e_l8),]


br_ifps_e8$caster <- as.numeric(as.factor(br_ifps_e8$user_id))
br_ifps_e8$item <- as.numeric(as.factor(br_ifps_e8$discover_id))


e8_base <- unique(br_ifps_e8[c("caster","user_id")])



e8 <- read.csv("post_n_e8.csv")
theta_t1 <- e8[grep("theta", e8$X),]
theta_t1$caster <- 1:nrow(theta_t1)
theta_t1 <- theta_t1[c("caster","mean")]
names(theta_t1) <- c("caster","theta_e8")

e8_results <- left_join(e8_base, theta_t1)
e8_results$caster <- NULL

## Partition 7

br_ifps_e7 <- br_ifps[br_ifps$e_l7 == "e" & !is.na(br_ifps$e_l7),]


br_ifps_e7$caster <- as.numeric(as.factor(br_ifps_e7$user_id))
br_ifps_e7$item <- as.numeric(as.factor(br_ifps_e7$discover_id))


e7_base <- unique(br_ifps_e7[c("caster","user_id")])



e7 <- read.csv("post_n_e7.csv")
theta_t1 <- e7[grep("theta", e7$X),]
theta_t1$caster <- 1:nrow(theta_t1)
theta_t1 <- theta_t1[c("caster","mean")]
names(theta_t1) <- c("caster","theta_e7")

e7_results <- left_join(e7_base, theta_t1)
e7_results$caster <- NULL

## Partition 6

br_ifps_e6 <- br_ifps[br_ifps$e_l6 == "e" & !is.na(br_ifps$e_l6),]


br_ifps_e6$caster <- as.numeric(as.factor(br_ifps_e6$user_id))
br_ifps_e6$item <- as.numeric(as.factor(br_ifps_e6$discover_id))


e6_base <- unique(br_ifps_e6[c("caster","user_id")])



e6 <- read.csv("post_n_e6.csv")
theta_t1 <- e6[grep("theta", e6$X),]
theta_t1$caster <- 1:nrow(theta_t1)
theta_t1 <- theta_t1[c("caster","mean")]
names(theta_t1) <- c("caster","theta_e6")

e6_results <- left_join(e6_base, theta_t1)
e6_results$caster <- NULL

## Partition 5

br_ifps_e5 <- br_ifps[br_ifps$e_l5 == "e" & !is.na(br_ifps$e_l5),]


br_ifps_e5$caster <- as.numeric(as.factor(br_ifps_e5$user_id))
br_ifps_e5$item <- as.numeric(as.factor(br_ifps_e5$discover_id))


e5_base <- unique(br_ifps_e5[c("caster","user_id")])



e5 <- read.csv("post_n_e5.csv")
theta_t1 <- e5[grep("theta", e5$X),]
theta_t1$caster <- 1:nrow(theta_t1)
theta_t1 <- theta_t1[c("caster","mean")]
names(theta_t1) <- c("caster","theta_e5")

e5_results <- left_join(e5_base, theta_t1)
e5_results$caster <- NULL

## Partition 4

br_ifps_e4 <- br_ifps[br_ifps$e_l4 == "e" & !is.na(br_ifps$e_l4),]


br_ifps_e4$caster <- as.numeric(as.factor(br_ifps_e4$user_id))
br_ifps_e4$item <- as.numeric(as.factor(br_ifps_e4$discover_id))


e4_base <- unique(br_ifps_e4[c("caster","user_id")])



e4 <- read.csv("post_n_e4.csv")
theta_t1 <- e4[grep("theta", e4$X),]
theta_t1$caster <- 1:nrow(theta_t1)
theta_t1 <- theta_t1[c("caster","mean")]
names(theta_t1) <- c("caster","theta_e4")

e4_results <- left_join(e4_base, theta_t1)
e4_results$caster <- NULL

## Partition 3

br_ifps_e3 <- br_ifps[br_ifps$e_l3 == "e" & !is.na(br_ifps$e_l3),]


br_ifps_e3$caster <- as.numeric(as.factor(br_ifps_e3$user_id))
br_ifps_e3$item <- as.numeric(as.factor(br_ifps_e3$discover_id))


e3_base <- unique(br_ifps_e3[c("caster","user_id")])



e3 <- read.csv("post_n2_e3.csv")
theta_t1 <- e3[grep("theta", e3$X),]
theta_t1$caster <- 1:nrow(theta_t1)
theta_t1 <- theta_t1[c("caster","mean")]
names(theta_t1) <- c("caster","theta_e3")

e3_results <- left_join(e3_base, theta_t1)
e3_results$caster <- NULL


## Partition 2

br_ifps_e2 <- br_ifps[br_ifps$e_l2 == "e" & !is.na(br_ifps$e_l2),]


br_ifps_e2$caster <- as.numeric(as.factor(br_ifps_e2$user_id))
br_ifps_e2$item <- as.numeric(as.factor(br_ifps_e2$discover_id))


e2_base <- unique(br_ifps_e2[c("caster","user_id")])



e2 <- read.csv("post_n2_e2.csv")
theta_t1 <- e2[grep("theta", e2$X),]
theta_t1$caster <- 1:nrow(theta_t1)
theta_t1 <- theta_t1[c("caster","mean")]
names(theta_t1) <- c("caster","theta_e2")

e2_results <- left_join(e2_base, theta_t1)
e2_results$caster <- NULL

## Partition 1

br_ifps_e1 <- br_ifps[br_ifps$e_l1 == "e" & !is.na(br_ifps$e_l1),]


br_ifps_e1$caster <- as.numeric(as.factor(br_ifps_e1$user_id))
br_ifps_e1$item <- as.numeric(as.factor(br_ifps_e1$discover_id))


e1_base <- unique(br_ifps_e1[c("caster","user_id")])



e1 <- read.csv("post_e1.csv")

theta_t1 <- e1[grep("theta", e1$X),]
theta_t1$caster <- 1:nrow(theta_t1)
theta_t1 <- theta_t1[c("caster","mean")]
names(theta_t1) <- c("caster","theta_e1")

e1_results <- left_join(e1_base, theta_t1)

e1_results$caster <- NULL

full_results <- join_all(list(all_results,base_results,
                              e9_results,
                              e8_results,
                              e7_results,
                              e6_results,
                              e5_results,
                              e4_results,
                              e3_results,
                              e2_results,
                              e1_results), type = "left")

View(round(cor(full_results[2:ncol(full_results)],
               use = "pairwise.complete.obs"),2))
write.csv(full_results, "Stan RCTB Results.csv", row.names = FALSE)
