rm(list=ls())
setwd("~/S2") # Set Working Directory Path

library(reshape2)
library(plyr)
library(dplyr)
library(stringr)
library(ggplot2)
library(standardize)
library(zoo)
library(tidyr)
library(dominanceanalysis)
library(mirt)
library(data.table)
library(RColorBrewer)
library(papaja)
library(rstan)
library(lme4)


## load data

br_ifps_s <- read.csv("season 2 forecasts.csv")


## Transform brier scores to accuracy and normalized accuracy
br_ifps_s$correct <- 1-(sqrt(br_ifps_s$brier/2))
br_ifps_s$correct_trim <- ifelse(br_ifps_s$correct == 1, .999,
                                 ifelse(br_ifps_s$correct == 0, .001, br_ifps_s$correct))


br_ifps_s$correct_prob <- VGAM::probitlink(br_ifps_s$correct_trim)

## Compute time remaining in forecasts

br_ifps_s$time_rem <- as.numeric(as.Date(br_ifps_s$end_date) - as.Date(br_ifps_s$date))
br_ifps_s$time_rem <- ifelse(br_ifps_s$time_rem < 0, 0, br_ifps_s$time_rem) + 1

br_ifps_s$time_rem_log <- log(br_ifps_s$time_rem)


br_ifps_s$resolved_date <- as.Date(br_ifps_s$resolved_date)


## Load and merge question data
ifps <- read.csv("season 2 questions.csv")
ifps$resolved_date <- as.Date(ifps$resolved_date)

br_ifps_s <- left_join(br_ifps_s, ifps)


## Compute hierarchical accuracy at each partition

## First 199
lmer_e0 <- lmer(correct_prob ~ time_rem_log + (time_rem_log | discover_id) + 
                  (1 | user_id), br_ifps_s[br_ifps_s$e_l0 == "e",],
                control = lmerControl(optimizer = "Nelder_Mead"))

## Last 199
lmer_l0 <- lmer(correct_prob ~ time_rem_log + (time_rem_log | discover_id) + 
                  (1 | user_id), br_ifps_s[br_ifps_s$e_l0 == "l",],
                control = lmerControl(optimizer = "Nelder_Mead"))

## Intervals of 20, 40....2000
lmer_e1 <- lmer(correct_prob ~ time_rem_log + (time_rem_log | discover_id) + 
                  (1 | user_id), br_ifps_s[br_ifps_s$e_l1 == "e",],
                control = lmerControl(optimizer = "Nelder_Mead"))

lmer_e2 <- lmer(correct_prob ~ time_rem_log + (time_rem_log | discover_id) + 
                  (1 | user_id), br_ifps_s[br_ifps_s$e_l2 == "e",],
                control = lmerControl(optimizer = "Nelder_Mead"))

lmer_e3 <- lmer(correct_prob ~ time_rem_log + (time_rem_log | discover_id) + 
                  (1 | user_id), br_ifps_s[br_ifps_s$e_l3 == "e",],
                control = lmerControl(optimizer = "Nelder_Mead"))

lmer_e4 <- lmer(correct_prob ~ time_rem_log + (time_rem_log | discover_id) + 
                  (1 | user_id), br_ifps_s[br_ifps_s$e_l4 == "e",],
                control = lmerControl(optimizer = "Nelder_Mead"))

lmer_e5 <- lmer(correct_prob ~ time_rem_log + (time_rem_log | discover_id) + 
                  (1 | user_id), br_ifps_s[br_ifps_s$e_l5 == "e",],
                control = lmerControl(optimizer = "Nelder_Mead"))

lmer_e6 <- lmer(correct_prob ~ time_rem_log + (time_rem_log | discover_id) + 
                  (1 | user_id), br_ifps_s[br_ifps_s$e_l6 == "e",],
                control = lmerControl(optimizer = "Nelder_Mead"))

lmer_e7 <- lmer(correct_prob ~ time_rem_log + (time_rem_log | discover_id) + 
                  (1 | user_id), br_ifps_s[br_ifps_s$e_l7 == "e",],
                control = lmerControl(optimizer = "Nelder_Mead"))

lmer_e8 <- lmer(correct_prob ~ time_rem_log + (time_rem_log | discover_id) + 
                  (1 | user_id), br_ifps_s[br_ifps_s$e_l8 == "e",],
                control = lmerControl(optimizer = "Nelder_Mead"))

lmer_e_f <- lmer(correct_prob ~ time_rem_log + (time_rem_log | discover_id) + 
                   (1 | user_id), br_ifps_s[br_ifps_s$e_l_f == "e",],
                 control = lmerControl(optimizer = "Nelder_Mead"))


lmer_e9 <- lmer(correct_prob ~ time_rem_log + (time_rem_log | discover_id) + 
                  (1 | user_id), br_ifps_s[br_ifps_s$e_l9 == "e",],
                control = lmerControl(optimizer = "Nelder_Mead"))

lmer_e10 <- lmer(correct_prob ~ time_rem_log + (time_rem_log | discover_id) + 
                   (1 | user_id), br_ifps_s[br_ifps_s$e_l10 == "e",],
                 control = lmerControl(optimizer = "Nelder_Mead"))


## Calibration sample
lmer_e_f <- lmer(correct_prob ~ time_rem_log + (time_rem_log | discover_id) + 
                   (1 | user_id), br_ifps_s[br_ifps_s$e_l_f == "e",],
                 control = lmerControl(optimizer = "Nelder_Mead"))


## Training sample
lmer_l_f <- lmer(correct_prob ~ time_rem_log + (time_rem_log | discover_id) + 
                   (1 | user_id), br_ifps_s[br_ifps_s$e_l_f == "l",],
                 control = lmerControl(optimizer = "Nelder_Mead"))


## Full sample
lmer_all <- lmer(correct_prob ~ time_rem_log + (time_rem_log | discover_id) + 
                   (1 | user_id), br_ifps_s,
                 control = lmerControl(optimizer = "Nelder_Mead"))





lmer_e10dat <- data.frame(user_id = rownames(ranef(lmer_e10)$user_id),
                          hier_e10 = ranef(lmer_e10)$user_id$`(Intercept)`)

lmer_e9dat <- data.frame(user_id = rownames(ranef(lmer_e9)$user_id),
                         hier_e9 = ranef(lmer_e9)$user_id$`(Intercept)`)

lmer_e8dat <- data.frame(user_id = rownames(ranef(lmer_e8)$user_id),
                         hier_e8 = ranef(lmer_e8)$user_id$`(Intercept)`)

lmer_e7dat <- data.frame(user_id = rownames(ranef(lmer_e7)$user_id),
                         hier_e7 = ranef(lmer_e7)$user_id$`(Intercept)`)

lmer_e6dat <- data.frame(user_id = rownames(ranef(lmer_e6)$user_id),
                         hier_e6 = ranef(lmer_e6)$user_id$`(Intercept)`)

lmer_e5dat <- data.frame(user_id = rownames(ranef(lmer_e5)$user_id),
                         hier_e5 = ranef(lmer_e5)$user_id$`(Intercept)`)

lmer_e4dat <- data.frame(user_id = rownames(ranef(lmer_e4)$user_id),
                         hier_e4 = ranef(lmer_e4)$user_id$`(Intercept)`)

lmer_e3dat <- data.frame(user_id = rownames(ranef(lmer_e3)$user_id),
                         hier_e3 = ranef(lmer_e3)$user_id$`(Intercept)`)

lmer_e2dat <- data.frame(user_id = rownames(ranef(lmer_e2)$user_id),
                         hier_e2 = ranef(lmer_e2)$user_id$`(Intercept)`)

lmer_e1dat <- data.frame(user_id = rownames(ranef(lmer_e1)$user_id),
                         hier_e1 = ranef(lmer_e1)$user_id$`(Intercept)`)

lmer_e_fdat <- data.frame(user_id = rownames(ranef(lmer_e_f)$user_id),
                          hier_e_f = ranef(lmer_e_f)$user_id$`(Intercept)`)

lmer_l_fdat <- data.frame(user_id = rownames(ranef(lmer_l_f)$user_id),
                          hier_l_f = ranef(lmer_l_f)$user_id$`(Intercept)`)


lmer_alldat<- data.frame(user_id = rownames(ranef(lmer_all)$user_id),
                         hier_all = ranef(lmer_all)$user_id$`(Intercept)`)

lmer_e0dat<- data.frame(user_id = rownames(ranef(lmer_e0)$user_id),
                        hier_e0 = ranef(lmer_e0)$user_id$`(Intercept)`)

lmerl_0dat<- data.frame(user_id = rownames(ranef(lmer_l0)$user_id),
                        hier_l0 = ranef(lmer_l0)$user_id$`(Intercept)`)



## Compute Simple standardized Brier Scores (no time penalty)

acc_std0_e <- br_ifps_s %>% filter(e_l0 == "e") %>% group_by(user_id, discover_id) %>% 
  summarize(correct_prob = mean(correct_prob)) %>% ungroup() %>% 
  group_by(discover_id) %>%
  mutate(std_brier = scale(correct_prob)) %>% ungroup() %>%
  group_by(user_id) %>% summarize(acc_std0_e = mean(std_brier))


acc_std1_e <- br_ifps_s %>% filter(e_l1 == "e") %>% group_by(user_id, discover_id) %>% 
  summarize(correct_prob = mean(correct_prob)) %>% ungroup() %>% 
  group_by(discover_id) %>%
  mutate(std_brier = scale(correct_prob)) %>% ungroup() %>%
  group_by(user_id) %>% summarize(acc_std1_e = mean(std_brier))


acc_std2_e <- br_ifps_s %>% filter(e_l2 == "e") %>% group_by(user_id, discover_id) %>% 
  summarize(correct_prob = mean(correct_prob)) %>% ungroup() %>% 
  group_by(discover_id) %>%
  mutate(std_brier = scale(correct_prob)) %>% ungroup() %>%
  group_by(user_id) %>% summarize(acc_std2_e = mean(std_brier))


acc_std3_e <- br_ifps_s %>% filter(e_l3 == "e") %>% group_by(user_id, discover_id) %>% 
  summarize(correct_prob = mean(correct_prob)) %>% ungroup() %>% 
  group_by(discover_id) %>%
  mutate(std_brier = scale(correct_prob)) %>% ungroup() %>%
  group_by(user_id) %>% summarize(acc_std3_e = mean(std_brier))


acc_std4_e <- br_ifps_s %>% filter(e_l4 == "e") %>% group_by(user_id, discover_id) %>% 
  summarize(correct_prob = mean(correct_prob)) %>% ungroup() %>% 
  group_by(discover_id) %>%
  mutate(std_brier = scale(correct_prob)) %>% ungroup() %>%
  group_by(user_id) %>% summarize(acc_std4_e = mean(std_brier))


acc_std5_e <- br_ifps_s %>% filter(e_l5 == "e") %>% group_by(user_id, discover_id) %>% 
  summarize(correct_prob = mean(correct_prob)) %>% ungroup() %>% 
  group_by(discover_id) %>%
  mutate(std_brier = scale(correct_prob)) %>% ungroup() %>%
  group_by(user_id) %>% summarize(acc_std5_e = mean(std_brier))


acc_std6_e <- br_ifps_s %>% filter(e_l6 == "e") %>% group_by(user_id, discover_id) %>% 
  summarize(correct_prob = mean(correct_prob)) %>% ungroup() %>% 
  group_by(discover_id) %>%
  mutate(std_brier = scale(correct_prob)) %>% ungroup() %>%
  group_by(user_id) %>% summarize(acc_std6_e = mean(std_brier))


acc_std7_e <- br_ifps_s %>% filter(e_l7 == "e") %>% group_by(user_id, discover_id) %>% 
  summarize(correct_prob = mean(correct_prob)) %>% ungroup() %>% 
  group_by(discover_id) %>%
  mutate(std_brier = scale(correct_prob)) %>% ungroup() %>%
  group_by(user_id) %>% summarize(acc_std7_e = mean(std_brier))


acc_std8_e <- br_ifps_s %>% filter(e_l8 == "e") %>% group_by(user_id, discover_id) %>% 
  summarize(correct_prob = mean(correct_prob)) %>% ungroup() %>% 
  group_by(discover_id) %>%
  mutate(std_brier = scale(correct_prob)) %>% ungroup() %>%
  group_by(user_id) %>% summarize(acc_std8_e = mean(std_brier))


acc_std9_e <- br_ifps_s %>% filter(e_l9 == "e") %>% group_by(user_id, discover_id) %>% 
  summarize(correct_prob = mean(correct_prob)) %>% ungroup() %>% 
  group_by(discover_id) %>%
  mutate(std_brier = scale(correct_prob)) %>% ungroup() %>%
  group_by(user_id) %>% summarize(acc_std9_e = mean(std_brier))


acc_std10_e <- br_ifps_s %>% filter(e_l10 == "e") %>% group_by(user_id, discover_id) %>% 
  summarize(correct_prob = mean(correct_prob)) %>% ungroup() %>% 
  group_by(discover_id) %>%
  mutate(std_brier = scale(correct_prob)) %>% ungroup() %>%
  group_by(user_id) %>% summarize(acc_std10_e = mean(std_brier))

acc_std0_l <- br_ifps_s %>% filter(e_l0 == "l") %>% group_by(user_id, discover_id) %>% 
  summarize(correct_prob = mean(correct_prob)) %>% ungroup() %>% 
  group_by(discover_id) %>%
  mutate(std_brier = scale(correct_prob)) %>% ungroup() %>%
  group_by(user_id) %>% summarize(acc_std0_l = mean(std_brier))


acc_std_f_e <- br_ifps_s %>% filter(e_l_f == "e") %>% group_by(user_id, discover_id) %>% 
  summarize(correct_prob = mean(correct_prob)) %>% ungroup() %>% 
  group_by(discover_id) %>%
  mutate(std_brier = scale(correct_prob)) %>% ungroup() %>%
  group_by(user_id) %>% summarize(acc_std_f_e = mean(std_brier))


acc_std_f_l <- br_ifps_s %>% filter(e_l_f == "l") %>% group_by(user_id, discover_id) %>% 
  summarize(correct_prob = mean(correct_prob)) %>% ungroup() %>% 
  group_by(discover_id) %>%
  mutate(std_brier = scale(correct_prob)) %>% ungroup() %>%
  group_by(user_id) %>% summarize(acc_std_f_l = mean(std_brier))

acc_std1_l <- br_ifps_s %>% filter(e_l1 == "l") %>% group_by(user_id, discover_id) %>% 
  summarize(correct_prob = mean(correct_prob)) %>% ungroup() %>% 
  group_by(discover_id) %>%
  mutate(std_brier = scale(correct_prob)) %>% ungroup() %>%
  group_by(user_id) %>% summarize(acc_std1_l = mean(std_brier))


acc_std_all <- br_ifps_s %>% group_by(user_id, discover_id) %>% 
  summarize(correct_prob = mean(correct_prob)) %>% ungroup() %>% 
  group_by(discover_id) %>%
  mutate(std_brier = scale(correct_prob)) %>% ungroup() %>%
  group_by(user_id) %>% summarize(acc_std_all = mean(std_brier))


## Forecasts

fcasts0_e <- br_ifps_s %>% filter(e_l0 == "e") %>% group_by(user_id) %>% 
  summarize(fcasts0_e = length(user_id))

fcasts1_e <- br_ifps_s %>% filter(e_l1 == "e") %>% group_by(user_id) %>% 
  summarize(fcasts1_e = length(user_id))

fcasts2_e <- br_ifps_s %>% filter(e_l2 == "e") %>% group_by(user_id) %>% 
  summarize(fcasts2_e = length(user_id))

fcasts3_e <- br_ifps_s %>% filter(e_l3 == "e") %>% group_by(user_id) %>% 
  summarize(fcasts3_e = length(user_id))

fcasts4_e <- br_ifps_s %>% filter(e_l4 == "e") %>% group_by(user_id) %>% 
  summarize(fcasts4_e = length(user_id))

fcasts5_e <- br_ifps_s %>% filter(e_l5 == "e") %>% group_by(user_id) %>% 
  summarize(fcasts5_e = length(user_id))

fcasts6_e <- br_ifps_s %>% filter(e_l6 == "e") %>% group_by(user_id) %>% 
  summarize(fcasts6_e = length(user_id))

fcasts7_e <- br_ifps_s %>% filter(e_l7 == "e") %>% group_by(user_id) %>% 
  summarize(fcasts7_e = length(user_id))

fcasts8_e <- br_ifps_s %>% filter(e_l8 == "e") %>% group_by(user_id) %>% 
  summarize(fcasts8_e = length(user_id))

fcasts9_e <- br_ifps_s %>% filter(e_l9 == "e") %>% group_by(user_id) %>% 
  summarize(fcasts9_e = length(user_id))

fcasts10_e <- br_ifps_s %>% filter(e_l10 == "e") %>% group_by(user_id) %>% 
  summarize(fcasts10_e = length(user_id))

fcasts0_l <- br_ifps_s %>% filter(e_l0 == "l") %>% group_by(user_id) %>% 
  summarize(fcasts0_l = length(user_id))

fcasts1_l <- br_ifps_s %>% filter(e_l1 == "l") %>% group_by(user_id) %>% 
  summarize(fcasts1_l = length(user_id))

fcasts_f_e <- br_ifps_s %>% filter(e_l_f == "e") %>% group_by(user_id) %>% 
  summarize(fcasts_f_e = length(user_id))

fcasts_f_l <- br_ifps_s %>% filter(e_l_f == "l") %>% group_by(user_id) %>% 
  summarize(fcasts_f_l = length(user_id))

fcasts_all <- br_ifps_s %>% group_by(user_id) %>% 
  summarize(fcasts = length(user_id))


## unique questions

ifp_ct0_e <- br_ifps_s %>% filter(e_l0 == "e") %>% group_by(user_id) %>% 
  summarize(ifp_ct0_e = length(unique(discover_id)))

ifp_ct1_e <- br_ifps_s %>% filter(e_l1 == "e") %>% group_by(user_id) %>% 
  summarize(ifp_ct1_e = length(unique(discover_id)))

ifp_ct2_e <- br_ifps_s %>% filter(e_l2 == "e") %>% group_by(user_id) %>% 
  summarize(ifp_ct2_e = length(unique(discover_id)))

ifp_ct3_e <- br_ifps_s %>% filter(e_l3 == "e") %>% group_by(user_id) %>% 
  summarize(ifp_ct3_e = length(unique(discover_id)))

ifp_ct4_e <- br_ifps_s %>% filter(e_l4 == "e") %>% group_by(user_id) %>% 
  summarize(ifp_ct4_e = length(unique(discover_id)))

ifp_ct5_e <- br_ifps_s %>% filter(e_l5 == "e") %>% group_by(user_id) %>% 
  summarize(ifp_ct5_e = length(unique(discover_id)))

ifp_ct6_e <- br_ifps_s %>% filter(e_l6 == "e") %>% group_by(user_id) %>% 
  summarize(ifp_ct6_e = length(unique(discover_id)))

ifp_ct7_e <- br_ifps_s %>% filter(e_l7 == "e") %>% group_by(user_id) %>% 
  summarize(ifp_ct7_e = length(unique(discover_id)))

ifp_ct8_e <- br_ifps_s %>% filter(e_l8 == "e") %>% group_by(user_id) %>% 
  summarize(ifp_ct8_e = length(unique(discover_id)))

ifp_ct9_e <- br_ifps_s %>% filter(e_l9 == "e") %>% group_by(user_id) %>% 
  summarize(ifp_ct9_e = length(unique(discover_id)))

ifp_ct10_e <- br_ifps_s %>% filter(e_l10 == "e") %>% group_by(user_id) %>% 
  summarize(ifp_ct10_e = length(unique(discover_id)))

ifp_ct0_l <- br_ifps_s %>% filter(e_l0 == "l") %>% group_by(user_id) %>% 
  summarize(ifp_ct0_l = length(unique(discover_id)))

ifp_ct1_l <- br_ifps_s %>% filter(e_l1 == "l") %>% group_by(user_id) %>% 
  summarize(ifp_ct1_l = length(unique(discover_id)))

ifp_ct_f_e <- br_ifps_s %>% filter(e_l_f == "e") %>% group_by(user_id) %>% 
  summarize(ifp_ct_f_e = length(unique(discover_id)))

ifp_ct_f_l <- br_ifps_s %>% filter(e_l_f == "l") %>% group_by(user_id) %>% 
  summarize(ifp_ct_f_l = length(unique(discover_id)))

ifp_ct_all <- br_ifps_s  %>% group_by(user_id) %>% 
  summarize(ifp_ct = length(unique(discover_id)))

## Merge results together

allscores <- join_all(list(acc_std_all,
                           fcasts_all, ifp_ct_all,
                           fcasts0_e,fcasts0_l,
                           fcasts1_e,fcasts2_e,
                           fcasts3_e,fcasts4_e,
                           fcasts5_e,fcasts6_e,
                           fcasts7_e,fcasts8_e,
                           fcasts9_e,fcasts10_e,
                           fcasts1_l,fcasts_f_e,
                           fcasts_f_l,
                           acc_std0_e,acc_std0_l,
                           acc_std1_e,acc_std2_e,
                           acc_std3_e,acc_std4_e,
                           acc_std5_e,acc_std6_e,
                           acc_std7_e,acc_std8_e,
                           acc_std9_e,acc_std10_e,
                           acc_std1_l,acc_std_f_e,
                           acc_std_f_l,
                           ifp_ct0_e,ifp_ct0_l,
                           ifp_ct1_e,ifp_ct2_e,
                           ifp_ct3_e,ifp_ct4_e,
                           ifp_ct5_e,ifp_ct6_e,
                           ifp_ct7_e,ifp_ct8_e,
                           ifp_ct9_e,ifp_ct10_e,
                           ifp_ct1_l,ifp_ct_f_e,
                           ifp_ct_f_l,
                           lmer_e10dat, lmer_e9dat,
                           lmer_e8dat, lmer_e7dat, 
                           lmer_e6dat, lmer_e5dat, 
                           lmer_e4dat, lmer_e3dat, 
                           lmer_e2dat, lmer_e1dat,
                           lmerl_0dat, lmer_e0dat,
                           lmer_alldat, lmer_e_fdat, 
                           lmer_l_fdat), type = "left")


## Load and merge IRT results (computed separately)
stn <- read.csv("Stan RCTB Results.csv")
allscores <- left_join(allscores, stn)


## Generate figure 7
library(GGally)

ggally_cor2 <- function(data, stars = FALSE, mapping = mapping){
  ggally_cor(data, stars = stars, mapping = mapping, family = "Helvetica")
}
score_cor_dat <- allscores[c("acc_std_all","hier_all",
                             "theta_alll1")]

names(score_cor_dat) <- c("Simple","Hierarchical","IRT")

f7 <- ggpairs(score_cor_dat, upper = list(continuous = ggally_cor2)) + theme_bw() + 
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())

postscript("fig7.eps", width = 6, height = 4, horizontal = FALSE)
f7
dev.off()


png("splom.png", width = 6, height = 4, units = "in", res = 300)
ggpairs(score_cor_dat, upper = list(continuous = ggally_cor2)) + theme_bw() + 
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())
dev.off()

## Table 8
all_hlf_crs <- round(cor(allscores[c("acc_std0_e",
                                     "hier_e0","theta_half1",
                                     "acc_std0_l",
                                     "hier_l0","theta_half2")],
                         use = "pairwise.complete.obs"), 2)


write.csv(all_hlf_crs, "split correlations.csv")

## Merge accuracy scores into forecast data
br_ifps_s <- left_join(br_ifps_s, allscores)




## Load individual difference data
indvs <-read.csv("season 2 user info.csv")

## Convert gender and education to numeric for correlations
indvs$gen_num <- as.numeric(factor(indvs$demo_gender_f))


indvs$education <- factor(ifelse(indvs$demo_edu < 4,"pre",
                                      ifelse(indvs$demo_edu == 4, "bac",
                                             ifelse(indvs$demo_edu == 5, "grad",NA))),
                               levels = c("pre","bac","grad"), ordered = TRUE)

indvs$ed_num <- ifelse(indvs$demo_edu < 4,1,
                            ifelse(indvs$demo_edu == 4, 2,
                                   ifelse(indvs$demo_edu == 5,3,NA)))



## Table 9
allscr_ind <- left_join(allscores, indvs)



allscr_cor <- round(cor(allscr_ind[c("acc_std_all","hier_all",
                                     "theta_alll1",
                                     "ns_score","bn_score","aomt_score",
                                     "pk_score_percent","pk_overconf",
                                     "demo_age","ed_num","gen_num")],
                        use = "pairwise.complete.obs"), 2)

write.csv(allscr_cor, "indv cors.csv")


## Merge individual differences into forecast file
br_ifps_s <- left_join(br_ifps_s, indvs)



## Subest complete cases
br_ifps_comp <- br_ifps_s[c("ns_score","bn_score","aomt_score",
                            "pk_score_percent","pk_overconf",
                            "demo_age","ed_num","demo_gender_f",
                            "time_rem_log",
                            "correct_prob","discover_id","user_id")]

br_ifps_comp <- br_ifps_comp[complete.cases(br_ifps_comp),]

## Model based on individual differences only and full forecast data
lmer_full <- lmer(correct_prob ~ ns_score + bn_score + aomt_score + 
                    pk_score_percent + pk_overconf + demo_age + ed_num +
                    demo_gender_f  + time_rem_log +
                    (1 | discover_id) + (1 | user_id),
                  br_ifps_comp)

lmer_red <- lmer(correct_prob ~ time_rem_log + 
                   (1 | discover_id) + (1 | user_id),
                 br_ifps_comp)

lmer_unc_all <- lmer(correct_prob ~ (1 | discover_id) + (1 | user_id),
                     br_ifps_comp)


## Define R^2 as reduction in random intercept variance
psuedr2 <- function(mod1, mod2){
  mfr1 <- as.data.frame(VarCorr(mod1))
  mfr2 <- as.data.frame(VarCorr(mod2))
  oupt <- 1 - mfr1$vcov[1]/mfr2$vcov[1]
  return(oupt)
}


r2_all <- psuedr2(lmer_full, lmer_red)

anova(lmer_full, lmer_red)

## Dominance Analysis WARNING: DA is very slow for hierarchical models
system.time(dom_all <- dominanceAnalysis(lmer_full, null.model = lmer_unc_all))

dom_cor <- dom_all$contribution.average$rb.r2.2[1:8]
dom_cor[dom_cor < 0] <- 0

da_all <- dom_cor/sum(dom_cor)*r2_all

## Subset data for analysis in figures 8-10
irt_dat <- br_ifps_s[br_ifps_s$e_l1 == "l" & !is.na(br_ifps_s$acc_std1_e),]


irt_dat_all <- irt_dat

irt_dat <- irt_dat[!is.na(irt_dat$ns_score) &
                     !is.na(irt_dat$bn_score) &
                     !is.na(irt_dat$aomt_score) &
                     !is.na(irt_dat$pk_score_percent) &
                     !is.na(irt_dat$pk_overconf) &
                     !is.na(irt_dat$demo_age) &
                     !is.na(irt_dat$education) &
                     !is.na(irt_dat$demo_gender_f), ]


## Models for figures 8-10
lmer_a10 <- lmer(correct_prob ~ ns_score + bn_score + aomt_score + 
                   pk_score_percent + pk_overconf + demo_age + ed_num +
                   demo_gender_f + acc_std10_e + fcasts10_e + ifp_ct10_e + time_rem_log + 
                   (1 | discover_id) + (1 | user_id), irt_dat)

lmer_a9 <- lmer(correct_prob ~ ns_score + bn_score + aomt_score + 
                  pk_score_percent + pk_overconf + demo_age + ed_num +
                  demo_gender_f + acc_std9_e + fcasts9_e + ifp_ct9_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_a8 <- lmer(correct_prob ~ ns_score + bn_score + aomt_score + 
                  pk_score_percent + pk_overconf + demo_age + ed_num +
                  demo_gender_f + acc_std8_e + fcasts8_e + ifp_ct8_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_a7 <- lmer(correct_prob ~ ns_score + bn_score + aomt_score + 
                  pk_score_percent + pk_overconf + demo_age + ed_num +
                  demo_gender_f + acc_std7_e + fcasts7_e + ifp_ct7_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_a6 <- lmer(correct_prob ~ ns_score + bn_score + aomt_score + 
                  pk_score_percent + pk_overconf + demo_age + ed_num +
                  demo_gender_f + acc_std6_e + fcasts6_e + ifp_ct6_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_a5 <- lmer(correct_prob ~ ns_score + bn_score + aomt_score + 
                  pk_score_percent + pk_overconf + demo_age + ed_num +
                  demo_gender_f + acc_std5_e + fcasts5_e + ifp_ct5_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_a4 <- lmer(correct_prob ~ ns_score + bn_score + aomt_score + 
                  pk_score_percent + pk_overconf + demo_age + ed_num +
                  demo_gender_f + acc_std4_e + fcasts4_e + ifp_ct4_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_a3 <- lmer(correct_prob ~ ns_score + bn_score + aomt_score + 
                  pk_score_percent + pk_overconf + demo_age + ed_num +
                  demo_gender_f + acc_std3_e + fcasts3_e + ifp_ct3_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_a2 <- lmer(correct_prob ~ ns_score + bn_score + aomt_score + 
                  pk_score_percent + pk_overconf + demo_age + ed_num +
                  demo_gender_f + acc_std2_e + fcasts2_e + ifp_ct2_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_a1 <- lmer(correct_prob ~ ns_score + bn_score + aomt_score + 
                  pk_score_percent + pk_overconf + demo_age + ed_num +
                  demo_gender_f + acc_std1_e + fcasts1_e + ifp_ct1_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)




lmer_t10 <- lmer(correct_prob ~ ns_score + bn_score + aomt_score + 
                   pk_score_percent + pk_overconf + demo_age + ed_num +
                   demo_gender_f + theta_half1 + fcasts10_e + ifp_ct10_e + time_rem_log + 
                   (1 | discover_id) + (1 | user_id), irt_dat)


lmer_t9 <- lmer(correct_prob ~ ns_score + bn_score + aomt_score + 
                  pk_score_percent + pk_overconf + demo_age + ed_num +
                  demo_gender_f + theta_e9 + fcasts9_e + ifp_ct9_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)



lmer_t8 <- lmer(correct_prob ~ ns_score + bn_score + aomt_score + 
                  pk_score_percent + pk_overconf + demo_age + ed_num +
                  demo_gender_f + theta_e8 + fcasts8_e + ifp_ct8_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_t7 <- lmer(correct_prob ~ ns_score + bn_score + aomt_score + 
                  pk_score_percent + pk_overconf + demo_age + ed_num +
                  demo_gender_f + theta_e7 + fcasts7_e + ifp_ct7_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_t6 <- lmer(correct_prob ~ ns_score + bn_score + aomt_score + 
                  pk_score_percent + pk_overconf + demo_age + ed_num +
                  demo_gender_f + theta_e6 + fcasts6_e + ifp_ct6_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_t5 <- lmer(correct_prob ~ ns_score + bn_score + aomt_score + 
                  pk_score_percent + pk_overconf + demo_age + ed_num +
                  demo_gender_f + theta_e5 + fcasts5_e + ifp_ct5_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_t4 <- lmer(correct_prob ~ ns_score + bn_score + aomt_score + 
                  pk_score_percent + pk_overconf + demo_age + ed_num +
                  demo_gender_f + theta_e4 + fcasts4_e + ifp_ct4_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_t3 <- lmer(correct_prob ~ ns_score + bn_score + aomt_score + 
                  pk_score_percent + pk_overconf + demo_age + ed_num +
                  demo_gender_f + theta_e3 + fcasts3_e + ifp_ct3_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_t2 <- lmer(correct_prob ~ ns_score + bn_score + aomt_score + 
                  pk_score_percent + pk_overconf + demo_age + ed_num +
                  demo_gender_f + theta_e2 + fcasts2_e + ifp_ct2_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_t1 <- lmer(correct_prob ~ ns_score + bn_score + aomt_score + 
                  pk_score_percent + pk_overconf + demo_age + ed_num +
                  demo_gender_f + theta_e1 + fcasts1_e + ifp_ct1_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)




lmer_h10 <- lmer(correct_prob ~ ns_score + bn_score + aomt_score + 
                   pk_score_percent + pk_overconf + demo_age + ed_num +
                   demo_gender_f + hier_e10 + fcasts10_e + ifp_ct10_e + time_rem_log + 
                   (1 | discover_id) + (1 | user_id), irt_dat)

lmer_h9 <- lmer(correct_prob ~ ns_score + bn_score + aomt_score + 
                  pk_score_percent + pk_overconf + demo_age + ed_num +
                  demo_gender_f + hier_e9 + fcasts9_e + ifp_ct9_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_h8 <- lmer(correct_prob ~ ns_score + bn_score + aomt_score + 
                  pk_score_percent + pk_overconf + demo_age + ed_num +
                  demo_gender_f + hier_e8 + fcasts8_e + ifp_ct8_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_h7 <- lmer(correct_prob ~ ns_score + bn_score + aomt_score + 
                  pk_score_percent + pk_overconf + demo_age + ed_num +
                  demo_gender_f + hier_e7 + fcasts7_e + ifp_ct7_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_h6 <- lmer(correct_prob ~ ns_score + bn_score + aomt_score + 
                  pk_score_percent + pk_overconf + demo_age + ed_num +
                  demo_gender_f + hier_e6 + fcasts6_e + ifp_ct6_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_h5 <- lmer(correct_prob ~ ns_score + bn_score + aomt_score + 
                  pk_score_percent + pk_overconf + demo_age + ed_num +
                  demo_gender_f + hier_e5 + fcasts5_e + ifp_ct5_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_h4 <- lmer(correct_prob ~ ns_score + bn_score + aomt_score + 
                  pk_score_percent + pk_overconf + demo_age + ed_num +
                  demo_gender_f + hier_e4 + fcasts4_e + ifp_ct4_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_h3 <- lmer(correct_prob ~ ns_score + bn_score + aomt_score + 
                  pk_score_percent + pk_overconf + demo_age + ed_num +
                  demo_gender_f + hier_e3 + fcasts3_e + ifp_ct3_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_h2 <- lmer(correct_prob ~ ns_score + bn_score + aomt_score + 
                  pk_score_percent + pk_overconf + demo_age + ed_num +
                  demo_gender_f + hier_e2 + fcasts2_e + ifp_ct2_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)

lmer_h1 <- lmer(correct_prob ~ ns_score + bn_score + aomt_score + 
                  pk_score_percent + pk_overconf + demo_age + ed_num +
                  demo_gender_f + hier_e1 + fcasts1_e + ifp_ct1_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), irt_dat)



lmer_ind <- lmer(correct_prob ~ ns_score + bn_score + aomt_score + 
                   pk_score_percent + pk_overconf + demo_age + ed_num +
                   demo_gender_f + time_rem_log + 
                   (1 | discover_id) + (1 | user_id), irt_dat)


lmer_base <- lmer(correct_prob ~ time_rem_log +
                    (1 | discover_id) + (1 | user_id), irt_dat)

lmer_unc <- lmer(correct_prob ~ 
                   (1 | discover_id) + (1 | user_id), irt_dat)


## Get results for figure 8a
r2_h10 <- psuedr2(lmer_h10, lmer_base)
r2_h9 <- psuedr2(lmer_h9, lmer_base)
r2_h8 <- psuedr2(lmer_h8, lmer_base)
r2_h7 <- psuedr2(lmer_h7, lmer_base)
r2_h6 <- psuedr2(lmer_h6, lmer_base)
r2_h5 <- psuedr2(lmer_h5, lmer_base)
r2_h4 <- psuedr2(lmer_h4, lmer_base)
r2_h3 <- psuedr2(lmer_h3, lmer_base)
r2_h2 <- psuedr2(lmer_h2, lmer_base)
r2_h1 <- psuedr2(lmer_h1, lmer_base)

r2_a10 <- psuedr2(lmer_a10, lmer_base)
r2_a9 <- psuedr2(lmer_a9, lmer_base)
r2_a8 <- psuedr2(lmer_a8, lmer_base)
r2_a7 <- psuedr2(lmer_a7, lmer_base)
r2_a6 <- psuedr2(lmer_a6, lmer_base)
r2_a5 <- psuedr2(lmer_a5, lmer_base)
r2_a4 <- psuedr2(lmer_a4, lmer_base)
r2_a3 <- psuedr2(lmer_a3, lmer_base)
r2_a2 <- psuedr2(lmer_a2, lmer_base)
r2_a1 <- psuedr2(lmer_a1, lmer_base)

r2_t10 <- psuedr2(lmer_t10, lmer_base)
r2_t9 <- psuedr2(lmer_t9, lmer_base)
r2_t8 <- psuedr2(lmer_t8, lmer_base)
r2_t7 <- psuedr2(lmer_t7, lmer_base)
r2_t6 <- psuedr2(lmer_t6, lmer_base)
r2_t5 <- psuedr2(lmer_t5, lmer_base)
r2_t4 <- psuedr2(lmer_t4, lmer_base)
r2_t3 <- psuedr2(lmer_t3, lmer_base)
r2_t2 <- psuedr2(lmer_t2, lmer_base)
r2_t1 <- psuedr2(lmer_t1, lmer_base)

r2_base <- psuedr2(lmer_ind, lmer_base)


r2s <- data.frame(r2 = c(r2_base,r2_t1,r2_t2,r2_t3,r2_t4,r2_t5,
                         r2_t6,r2_t7,r2_t8,r2_t9,r2_t10,
                         r2_base, r2_h1,r2_h2,r2_h3,r2_h4,r2_h5,
                         r2_h6,r2_h7,r2_h8,r2_h9,r2_h10,
                         r2_base, r2_a1,r2_a2,r2_a3,r2_a4,r2_a5,
                         r2_a6,r2_a7,r2_a8,r2_a9,r2_a10),
                  model = c(rep("IRT",11),
                            rep("Hierarchical", 11),
                            rep("Simple", 11)),
                  time = rep(seq(0, 10, 1)*20, 3))


r2s$ncasts <- c(0, mean(irt_dat$fcasts1_e),
                mean(irt_dat$fcasts2_e),
                mean(irt_dat$fcasts3_e),
                mean(irt_dat$fcasts4_e),
                mean(irt_dat$fcasts5_e),
                mean(irt_dat$fcasts6_e),
                mean(irt_dat$fcasts7_e),
                mean(irt_dat$fcasts8_e),
                mean(irt_dat$fcasts9_e),
                mean(irt_dat$fcasts10_e))

r2s$timecasts <- paste(r2s$time, round(r2s$ncasts), sep = "\n")
timecasts <- unique(r2s[c("timecasts","time")])


r2s$timecasts <- factor(r2s$timecasts, levels = timecasts$timecasts)

r2s$model <- factor(r2s$model, levels = c("Simple","Hierarchical","IRT"))

p1 <- ggplot(r2s, aes(x = timecasts, y = r2, color = model, linetype = model, group = model)) + geom_line(size = 1.5) +
  labs(colour="Accuracy Measure", linetype = "Accuracy Measure") + xlab("Activity Partition (# of Questions) \nMean Forecasts per Forecaster") + 
  ylab(bquote("R"^2)) + scale_linetype_manual(values=c(3,2,1)) + 
  scale_color_manual(values = rev(brewer.pal(5,"Blues"))) +
  scale_y_continuous(limits = c(0, .7), n.breaks = 8) +
  theme_apa() +
  theme(legend.text=element_text(size=16),
        legend.title = element_text(size = 18),
        axis.title.x = element_text(size = 18),
        axis.title.y = element_text(size = 22),
        axis.text.x = element_text(size = 16),
        axis.text.y = element_text(size = 16),
        legend.position = "bottom")


## Get results for figure 8b
aovob <- anova(lmer_t1,lmer_t2,lmer_t3,lmer_t4,lmer_t5,
               lmer_t6,lmer_t7,lmer_t8,lmer_t9,lmer_t10,
               lmer_h1,lmer_h2,lmer_h3,lmer_h4,lmer_h5,
               lmer_h6,lmer_h7,lmer_h8,lmer_h9,lmer_h10,
               lmer_a1,lmer_a2,lmer_a3,lmer_a4,lmer_a5,
               lmer_a6,lmer_a7,lmer_a8,lmer_a9,lmer_a10,
               lmer_ind, lmer_base)

devians <- as.data.frame(aovob)

devians_dat <- rbind(devians["lmer_ind",],devians["lmer_t1",],
                     devians["lmer_t2",],devians["lmer_t3",],
                     devians["lmer_t4",],devians["lmer_t5",],
                     devians["lmer_t6",],devians["lmer_t7",],
                     devians["lmer_t8",],devians["lmer_t9",],
                     devians["lmer_t10",],
                     devians["lmer_ind",],devians["lmer_h1",],
                     devians["lmer_h2",],devians["lmer_h3",],
                     devians["lmer_h4",],devians["lmer_h5",],
                     devians["lmer_h6",],devians["lmer_h7",],
                     devians["lmer_h8",],devians["lmer_h9",],
                     devians["lmer_h10",],
                     devians["lmer_ind",],devians["lmer_a1",],
                     devians["lmer_a2",],devians["lmer_a3",],
                     devians["lmer_a4",],devians["lmer_a5",],
                     devians["lmer_a6",],devians["lmer_a7",],
                     devians["lmer_a8",],devians["lmer_a9",],
                     devians["lmer_a10",])

devians_dat$model <- c(rep("IRT", 11),
                       rep("Hierarchical",11),
                       rep("Simple",11))

devians_dat$time <- rep(seq(0, 10, 1)*20, 3)

devians_dat$timecasts <- paste(devians_dat$time, round(r2s$ncasts), sep = "\n")
timecasts <- unique(r2s[c("timecasts","time")])

devians_dat$timecasts <- factor(devians_dat$timecasts, levels = timecasts$timecasts)

devians_dat$model <- factor(devians_dat$model, levels = c("Simple","Hierarchical","IRT"))

p1

p2 <- ggplot(devians_dat, aes(x = timecasts, y = BIC, group = model,color = model, linetype = model)) + geom_line(size = 1.5) +
  labs(colour="Accuracy Measure", linetype = "Accuracy Measure") + xlab("Activity Partition (# of Questions) \nMean Forecasts per Forecaster") + 
  ylab("BIC") + scale_linetype_manual(values=c(3,2,1)) + 
  scale_color_manual(values = rev(brewer.pal(5,"Reds")))  +
  scale_y_continuous(limits = c(90550, 90850), n.breaks = 9) +
  theme_apa() +
  theme(legend.text=element_text(size=16),
        legend.title = element_text(size = 18),
        axis.title.x = element_text(size = 18),
        axis.title.y = element_text(size = 22),
        axis.text.x = element_text(size = 16),
        axis.text.y = element_text(size = 16),
        legend.position = "bottom")


## Figure 8
png("r2 dev.png", width = 14, height = 6, units = "in", res = 300)
p3 <- gridExtra::grid.arrange(p1, p2, nrow = 1)

dev.off()

postscript("fig8a.eps", width = 7, height = 6, horizontal = FALSE)
p1
dev.off()

postscript("fig8b.eps", width = 7, height = 6, horizontal = FALSE)
p2
dev.off()

## Compute dominance analyses for figures 9 and 10
## WARNING these are VERY time consuming for hierarchical models

system.time(dom_a10 <- dominanceAnalysis(lmer_a10, null.model = lmer_unc))
system.time(dom_a9 <- dominanceAnalysis(lmer_a9, null.model = lmer_unc))
system.time(dom_a8 <- dominanceAnalysis(lmer_a8, null.model = lmer_unc))
system.time(dom_a7 <- dominanceAnalysis(lmer_a7, null.model = lmer_unc))
system.time(dom_a6 <- dominanceAnalysis(lmer_a6, null.model = lmer_unc))
system.time(dom_a5 <- dominanceAnalysis(lmer_a5, null.model = lmer_unc))
system.time(dom_a4 <- dominanceAnalysis(lmer_a4, null.model = lmer_unc))
system.time(dom_a3 <- dominanceAnalysis(lmer_a3, null.model = lmer_unc))
system.time(dom_a2 <- dominanceAnalysis(lmer_a2, null.model = lmer_unc))
system.time(dom_a1 <- dominanceAnalysis(lmer_a1, null.model = lmer_unc))

system.time(dom_h10 <- dominanceAnalysis(lmer_h10, null.model = lmer_unc))
system.time(dom_h9 <- dominanceAnalysis(lmer_h9, null.model = lmer_unc))
system.time(dom_h8 <- dominanceAnalysis(lmer_h8, null.model = lmer_unc))
system.time(dom_h7 <- dominanceAnalysis(lmer_h7, null.model = lmer_unc))
system.time(dom_h6 <- dominanceAnalysis(lmer_h6, null.model = lmer_unc))
system.time(dom_h5 <- dominanceAnalysis(lmer_h5, null.model = lmer_unc))
system.time(dom_h4 <- dominanceAnalysis(lmer_h4, null.model = lmer_unc))
system.time(dom_h3 <- dominanceAnalysis(lmer_h3, null.model = lmer_unc))
system.time(dom_h2 <- dominanceAnalysis(lmer_h2, null.model = lmer_unc))
system.time(dom_h1 <- dominanceAnalysis(lmer_h1, null.model = lmer_unc))

system.time(dom_t10 <- dominanceAnalysis(lmer_t10, null.model = lmer_unc))
system.time(dom_t9 <- dominanceAnalysis(lmer_t9, null.model = lmer_unc))
system.time(dom_t8 <- dominanceAnalysis(lmer_t8, null.model = lmer_unc))
system.time(dom_t7 <- dominanceAnalysis(lmer_t7, null.model = lmer_unc))
system.time(dom_t6 <- dominanceAnalysis(lmer_t6, null.model = lmer_unc))
system.time(dom_t5 <- dominanceAnalysis(lmer_t5, null.model = lmer_unc))
system.time(dom_t4 <- dominanceAnalysis(lmer_t4, null.model = lmer_unc))
system.time(dom_t3 <- dominanceAnalysis(lmer_t3, null.model = lmer_unc))
system.time(dom_t2 <- dominanceAnalysis(lmer_t2, null.model = lmer_unc))
system.time(dom_t1 <- dominanceAnalysis(lmer_t1, null.model = lmer_unc))


system.time(dom_b <- dominanceAnalysis(lmer_ind, null.model = lmer_unc))


da_t10 <- dom_t10$contribution.average$rb.r2.2/sum(dom_t10$contribution.average$rb.r2.2[-length(dom_t10$contribution.average$rb.r2.2)])*r2_t10
da_t9 <- dom_t9$contribution.average$rb.r2.2/sum(dom_t9$contribution.average$rb.r2.2[-length(dom_t9$contribution.average$rb.r2.2)])*r2_t9
da_t8 <- dom_t8$contribution.average$rb.r2.2/sum(dom_t8$contribution.average$rb.r2.2[-length(dom_t8$contribution.average$rb.r2.2)])*r2_t8
da_t7 <- dom_t7$contribution.average$rb.r2.2/sum(dom_t7$contribution.average$rb.r2.2[-length(dom_t7$contribution.average$rb.r2.2)])*r2_t7
da_t6 <- dom_t6$contribution.average$rb.r2.2/sum(dom_t6$contribution.average$rb.r2.2[-length(dom_t6$contribution.average$rb.r2.2)])*r2_t6
da_t5 <- dom_t5$contribution.average$rb.r2.2/sum(dom_t5$contribution.average$rb.r2.2[-length(dom_t5$contribution.average$rb.r2.2)])*r2_t5
da_t4 <- dom_t4$contribution.average$rb.r2.2/sum(dom_t4$contribution.average$rb.r2.2[-length(dom_t4$contribution.average$rb.r2.2)])*r2_t4
da_t3 <- dom_t3$contribution.average$rb.r2.2/sum(dom_t3$contribution.average$rb.r2.2[-length(dom_t3$contribution.average$rb.r2.2)])*r2_t3
da_t2 <- dom_t2$contribution.average$rb.r2.2/sum(dom_t2$contribution.average$rb.r2.2[-length(dom_t2$contribution.average$rb.r2.2)])*r2_t2
da_t1 <- dom_t1$contribution.average$rb.r2.2/sum(dom_t1$contribution.average$rb.r2.2[-length(dom_t1$contribution.average$rb.r2.2)])*r2_t1

da_h10 <- dom_h10$contribution.average$rb.r2.2/sum(dom_h10$contribution.average$rb.r2.2[-length(dom_h10$contribution.average$rb.r2.2)])*r2_h10
da_h9 <- dom_h9$contribution.average$rb.r2.2/sum(dom_h9$contribution.average$rb.r2.2[-length(dom_h9$contribution.average$rb.r2.2)])*r2_h9
da_h8 <- dom_h8$contribution.average$rb.r2.2/sum(dom_h8$contribution.average$rb.r2.2[-length(dom_h8$contribution.average$rb.r2.2)])*r2_h8
da_h7 <- dom_h7$contribution.average$rb.r2.2/sum(dom_h7$contribution.average$rb.r2.2[-length(dom_h7$contribution.average$rb.r2.2)])*r2_h7
da_h6 <- dom_h6$contribution.average$rb.r2.2/sum(dom_h6$contribution.average$rb.r2.2[-length(dom_h6$contribution.average$rb.r2.2)])*r2_h6
da_h5 <- dom_h5$contribution.average$rb.r2.2/sum(dom_h5$contribution.average$rb.r2.2[-length(dom_h5$contribution.average$rb.r2.2)])*r2_h5
da_h4 <- dom_h4$contribution.average$rb.r2.2/sum(dom_h4$contribution.average$rb.r2.2[-length(dom_h4$contribution.average$rb.r2.2)])*r2_h4
da_h3 <- dom_h3$contribution.average$rb.r2.2/sum(dom_h3$contribution.average$rb.r2.2[-length(dom_h3$contribution.average$rb.r2.2)])*r2_h3
da_h2 <- dom_h2$contribution.average$rb.r2.2/sum(dom_h2$contribution.average$rb.r2.2[-length(dom_h2$contribution.average$rb.r2.2)])*r2_h2
da_h1 <- dom_h1$contribution.average$rb.r2.2/sum(dom_h1$contribution.average$rb.r2.2[-length(dom_h1$contribution.average$rb.r2.2)])*r2_h1

da_a10 <- dom_a10$contribution.average$rb.r2.2/sum(dom_a10$contribution.average$rb.r2.2[-length(dom_a10$contribution.average$rb.r2.2)])*r2_a10
da_a9 <- dom_a9$contribution.average$rb.r2.2/sum(dom_a9$contribution.average$rb.r2.2[-length(dom_a9$contribution.average$rb.r2.2)])*r2_a9
da_a8 <- dom_a8$contribution.average$rb.r2.2/sum(dom_a8$contribution.average$rb.r2.2[-length(dom_a8$contribution.average$rb.r2.2)])*r2_a8
da_a7 <- dom_a7$contribution.average$rb.r2.2/sum(dom_a7$contribution.average$rb.r2.2[-length(dom_a7$contribution.average$rb.r2.2)])*r2_a7
da_a6 <- dom_a6$contribution.average$rb.r2.2/sum(dom_a6$contribution.average$rb.r2.2[-length(dom_a6$contribution.average$rb.r2.2)])*r2_a6
da_a5 <- dom_a5$contribution.average$rb.r2.2/sum(dom_a5$contribution.average$rb.r2.2[-length(dom_a5$contribution.average$rb.r2.2)])*r2_a5
da_a4 <- dom_a4$contribution.average$rb.r2.2/sum(dom_a4$contribution.average$rb.r2.2[-length(dom_a4$contribution.average$rb.r2.2)])*r2_a4
da_a3 <- dom_a3$contribution.average$rb.r2.2/sum(dom_a3$contribution.average$rb.r2.2[-length(dom_a3$contribution.average$rb.r2.2)])*r2_a3
da_a2 <- dom_a2$contribution.average$rb.r2.2/sum(dom_a2$contribution.average$rb.r2.2[-length(dom_a2$contribution.average$rb.r2.2)])*r2_a2
da_a1 <- dom_a1$contribution.average$rb.r2.2/sum(dom_a1$contribution.average$rb.r2.2[-length(dom_a1$contribution.average$rb.r2.2)])*r2_a1

da_b <- dom_b$contribution.average$rb.r2.2/sum(dom_b$contribution.average$rb.r2.2[-length(dom_b$contribution.average$rb.r2.2)])*r2_base


dom_wts <- c(da_b, da_a1,da_a2,da_a3,da_a4,da_a5,da_a6,
             da_a7,da_a8,da_a9,da_a10,
             da_b, da_h1,da_h2,da_h3,da_h4,da_h5,da_h6,
             da_h7,da_h8,da_h9,da_h10,
             da_b, da_t1,da_t2,da_t3,da_t4,da_t5,da_t6,
             da_t7,da_t8,da_t9,da_t10)

dwts <- data.frame(variable = names(dom_wts), dwts = dom_wts,
                   model = c(rep("Simple", length(da_b)), rep("Simple", 10*length(da_h1)), 
                             rep("Hierarchical", length(da_b)), rep("Hierarchical", 10*length(da_h1)),
                             rep("IRT", length(da_b)), rep("IRT", 10*length(da_h1))),
                   questions = rep(c(rep(0, length(da_b)),
                                     rep(1, length(da_h1)),
                                     rep(2, length(da_h1)),
                                     rep(3, length(da_h1)),
                                     rep(4, length(da_h1)),
                                     rep(5, length(da_h1)),
                                     rep(6, length(da_h1)),
                                     rep(7, length(da_h1)),
                                     rep(8, length(da_h1)),
                                     rep(9, length(da_h1)),
                                     rep(10, length(da_h1))),3))


dwts <- dwts[dwts$variable != "time_rem_log",]


dwts$class <- ifelse(dwts$variable == "ns_score" |
                       dwts$variable == "bn_score" |
                       dwts$variable == "aomt_score" |
                       dwts$variable == "pk_score_percent" |
                       dwts$variable == "pk_overconf", "Intake", 
                     ifelse(dwts$variable == "demo_age" | 
                              dwts$variable == "ed_num" |
                              dwts$variable == "demo_gender_f", "Demographic",
                            "Performance"))

dwts$weight <- dwts$dwts


zeros <- data.frame(variable = rep(c("accuracy0","fcasts0","ifp_ct0"),3),
                    dwts = 0,
                    weight = 0,
                    model = c(rep("IRT",3),rep("Simple",3), rep("Hierarchical",3)),
                    questions = 0,
                    class = "Performance")
dwts <- rbind(dwts, zeros)





#write.csv(dwts, "all dominance weights.csv", row.names = FALSE)

#dwts <- read.csv("all dominance weights.csv")

## Figure 9 and 10 (with alternate versions from supplementary material below)
## Figure 9
dwts_v <- dwts[dwts$class == "Performance",]

dwts_v$Variable <- rep(c("Accuracy","Forecasts","Unique Questions"),
                       nrow(dwts_v)/3)


dwts <- left_join(dwts, dwts_v[c("variable","Variable","model")])

dwts$questions <- dwts$questions*20

names(timecasts) <- c("timecasts","questions")
dwts <- left_join(dwts, timecasts)

dwts$timecasts <- factor(dwts$timecasts, levels = timecasts$timecasts)

dwts$class <- factor(dwts$class, levels = c("Intake","Performance","Demographic"))
dwts$Variable <- factor(dwts$Variable, levels = c("Accuracy","Forecasts","Unique Questions"))
irtwts <- dwts[dwts$model == "IRT",]


irt_class <- aggregate(dwts ~ class + timecasts, irtwts, sum)
irt_class$dwts[irt_class$dwts < 0] <- 0

irt1 <- ggplot(irt_class, aes(x=timecasts,y=dwts,group=class,
                              colour=class, linetype = class)) + 
  geom_line(size=1) +
  theme_bw() + xlab("Activity Partition (# of Questions) \nMean Forecasts per Forecaster") + 
  labs(colour="Variable Type", linetype = "Variable Type") +
  ylab("Dominance Weight") + 
  scale_linetype_manual(values=c(3,2,1))  + 
  scale_color_manual(values = rev(brewer.pal(4,"Blues"))) +
  scale_y_continuous(limits = c(0, .7), n.breaks = 8) +
  theme_apa() +
  theme(legend.text=element_text(size=12))

png("irt class.png", width = 8, height = 4, units = "in", res = 300)
irt1
dev.off()

postscript("fig9.eps", width = 8, height = 4, horizontal = FALSE)
irt1
dev.off()


## Figure 10
irt_perf <- irtwts[irtwts$class == "Performance",]

irt2 <- ggplot(irt_perf, aes(x=timecasts,y=dwts,group=Variable,
                             colour=Variable, linetype = Variable)) + 
  geom_line(size=1) +
  theme_bw() + xlab("Activity Partition (# of Questions) \nMean Forecasts per Forecaster") +
  labs(colour="Variable", linetype = "Variable") +
  ylab("Dominance Weight") + 
  scale_linetype_manual(values=c(3,2,1))  + 
  scale_color_manual(values = rev(brewer.pal(4,"Blues"))) +
  scale_y_continuous(limits = c(0, .7), n.breaks = 8) +
  theme_apa() +
  theme(legend.text=element_text(size=12))

png("irt perf.png", width = 8, height = 4, units = "in", res = 300)
irt2
dev.off()

postscript("fig10.eps", width = 8, height = 4, horizontal = FALSE)
irt2
dev.off()

## Alternate plots from supplementary materials
hierwts <- dwts[dwts$model == "Hierarchical",]


hier_class <- aggregate(dwts ~ class + timecasts, hierwts, sum)
hier_class$dwts[hier_class$dwts < 0] <- 0

hier1 <- ggplot(hier_class, aes(x=timecasts,y=dwts,group=class,
                              colour=class, linetype = class)) + 
  geom_line(size=1) +
  theme_bw() + xlab("Activity Partition (# of Questions) \nMean Forecasts per Forecaster") + 
  labs(colour="Variable Type", linetype = "Variable Type") +
  ylab("Dominance Weight") + 
  scale_linetype_manual(values=c(3,2,1))  + 
  scale_color_manual(values = rev(brewer.pal(4,"Blues"))) +
  scale_y_continuous(limits = c(0, .7), n.breaks = 8) +
  theme_apa() +
  theme(legend.text=element_text(size=12))

png("hier class.png", width = 8, height = 4, units = "in", res = 300)
hier1
dev.off()


hier_perf <- hierwts[hierwts$class == "Performance",]

hier2 <- ggplot(hier_perf, aes(x=timecasts,y=dwts,group=Variable,
                             colour=Variable, linetype = Variable)) + 
  geom_line(size=1) +
  theme_bw() + xlab("Activity Partition (# of Questions) \nMean Forecasts per Forecaster") +
  labs(colour="Variable", linetype = "Variable") +
  ylab("Dominance Weight") + 
  scale_linetype_manual(values=c(3,2,1))  + 
  scale_color_manual(values = rev(brewer.pal(4,"Blues"))) +
  scale_y_continuous(limits = c(0, .7), n.breaks = 8) +
  theme_apa() +
  theme(legend.text=element_text(size=12))

png("hier perf.png", width = 8, height = 4, units = "in", res = 300)
hier2
dev.off()


accwts <- dwts[dwts$model == "Simple",]


acc_class <- aggregate(dwts ~ class + timecasts, accwts, sum)
acc_class$dwts[acc_class$dwts < 0] <- 0

acc1 <- ggplot(acc_class, aes(x=timecasts,y=dwts,group=class,
                              colour=class, linetype = class)) + 
  geom_line(size=1) +
  theme_bw() + xlab("Activity Partition (# of Questions) \nMean Forecasts per Forecaster") + 
  labs(colour="Variable Type", linetype = "Variable Type") +
  ylab("Dominance Weight") + 
  scale_linetype_manual(values=c(3,2,1))  + 
  scale_color_manual(values = rev(brewer.pal(4,"Blues"))) +
  scale_y_continuous(limits = c(0, .7), n.breaks = 8) +
  theme_apa() +
  theme(legend.text=element_text(size=12))

png("acc class.png", width = 8, height = 4, units = "in", res = 300)
acc1
dev.off()


acc_perf <- accwts[accwts$class == "Performance",]

acc2 <- ggplot(acc_perf, aes(x=timecasts,y=dwts,group=Variable,
                             colour=Variable, linetype = Variable)) + 
  geom_line(size=1) +
  theme_bw() + xlab("Activity Partition (# of Questions) \nMean Forecasts per Forecaster") +
  labs(colour="Variable", linetype = "Variable") +
  ylab("Dominance Weight") + 
  scale_linetype_manual(values=c(3,2,1))  + 
  scale_color_manual(values = rev(brewer.pal(4,"Blues"))) +
  scale_y_continuous(limits = c(0, .7), n.breaks = 8) +
  theme_apa() +
  theme(legend.text=element_text(size=12))

png("acc perf.png", width = 8, height = 4, units = "in", res = 300)
acc2
dev.off()





## The remaining code is for the out-of-sample analyses
## We originally only analyzed models with Individual Differences (ID)
## Then added models without for comparison
## The easier way to do this was to save the results, then copy/paste
## The code rather than re-write it, which is what you see below

## Subset forecasts from training sample for tables 11-13 analysis
br_ifps_f <- br_ifps_s[br_ifps_s$e_l_f == "l",]

br_ifps_f_all <- br_ifps_f


## Fit models on training sample
lmer_vf <- lmer(correct_prob ~ ns_score + bn_score + aomt_score + 
                  pk_score_percent + pk_overconf + demo_age + ed_num +
                  demo_gender_f + acc_std_f_e + fcasts_f_e + ifp_ct_f_e +
                  time_rem_log + 
                  (1 | discover_id) + (1 | user_id), br_ifps_f)


lmer_ff <- lmer(correct_prob ~ ns_score + bn_score + aomt_score + 
                  pk_score_percent + pk_overconf + demo_age + ed_num +
                  demo_gender_f + hier_e_f + fcasts_f_e + ifp_ct_f_e +
                  time_rem_log + 
                  (1 | discover_id) + (1 | user_id), br_ifps_f)


lmer_tf <- lmer(correct_prob ~ ns_score + bn_score + aomt_score + 
                  pk_score_percent + pk_overconf + demo_age + ed_num +
                  demo_gender_f  + theta_train1 + fcasts_f_e + ifp_ct_f_e +
                  time_rem_log + 
                  (1 | discover_id) + (1 | user_id), br_ifps_f)



lmer_if <- lmer(correct_prob ~ ns_score + bn_score + aomt_score + 
                  pk_score_percent + pk_overconf + demo_age + ed_num +
                  demo_gender_f  + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), br_ifps_f)


## Subset testing sample
br_ifps_test <- br_ifps_s[br_ifps_s$e_l_f =="f",]


users <- unique(irt_dat[c("user_id","ns_score",
                          "bn_score", "aomt_score", "pk_score_percent",
                          "pk_overconf",
                          "demo_age", "demo_gender_f", "ed_num")])


usrs2 <- irt_dat[c(grep("user_id",names(irt_dat)),
                   grep("acc",names(irt_dat)),
                   grep("hier",names(irt_dat)),
                   grep("theta", names(irt_dat)),
                   grep("ifp_ct",names(irt_dat)),
                   grep("fcasts",names(irt_dat)))]

usrs2 <- unique(usrs2)                      

users <- left_join(users, usrs2)



## Get forecaster intercepts from testing sample
testmod <- lmer(correct_prob ~ time_rem_log + (1 | user_id) + (1 | discover_id),
                br_ifps_test)


testres <- data.frame(user_id = rownames(ranef(testmod)$user_id),
                      mus = ranef(testmod)$user_id$`(Intercept)`)

## Merge training sample results with testing sample estimates
users_test <- join_all(list(users, testres), type = "left")

## Save results
users2 <- users_test


## Initialize question IDs and time remaining at 0 
## and change the user IDs to new values to obtain 
## estimates based on fixed effects
users2$discover_id <- 0
users2$time_rem_log <- 0
users2$user_id <- paste(users2$user_id, "outsamp")

## Obtain predicted results based on fixed effects
users2$rk_v <- predict(lmer_vf, newdata = users2, allow.new.levels = TRUE)
users2$rk_f <- predict(lmer_ff, newdata = users2, allow.new.levels = TRUE)
users2$rk_t <- predict(lmer_tf, newdata = users2, allow.new.levels = TRUE)
users2$rk_i <- predict(lmer_if, newdata = users2, allow.new.levels = TRUE)


## Table 11 results with ID
t11a <- round(cor(users2[c("mus","rk_f","rk_t","rk_v","rk_i")],
    use = "pairwise.complete.obs"),2)

write.csv(t11a, "table 11a.csv")


## Save results
users2a <- users2[c("user_id","mus","rk_f","rk_t","rk_v","rk_i")]

## Rank participants by predicted accuracy
users2$wt_v <- rank(users2$rk_v)
users2$wt_f <- rank(predict(lmer_ff, newdata = users2, allow.new.levels = TRUE))
users2$wt_t <- rank(predict(lmer_tf, newdata = users2, allow.new.levels = TRUE))
users2$wt_i <- rank(predict(lmer_if, newdata = users2, allow.new.levels = TRUE))

## Save data separately
test_dat <- br_ifps_test

test_dat2 <- test_dat


test_dat$user_id <- paste(test_dat$user_id, "outsamp")



#carry forward daily forecast values
d_ifps <- data.frame(date=as.numeric(min(as.Date(test_dat$date))):as.numeric(max(as.Date(test_dat$date))))
d_ifps$date <- as.Date(d_ifps$date, origin="1970-01-01")

c_ifps <- expand.grid(d_ifps$date, unique(test_dat$user_id),unique(test_dat$discover_id))
colnames(c_ifps) <- c("date","user_id","discover_id")

c_ifps <- c_ifps[order(c_ifps$discover_id,c_ifps$user_id,c_ifps$date),]


c_ifps <- left_join(c_ifps, unique(test_dat[c("discover_id","start_date","close_date")]))

c_ifps <- c_ifps[c_ifps$date >= c_ifps$start_date & c_ifps$date <= c_ifps$close_date,]

test_dat$date <- as.Date(test_dat$date)
c_ifps <- left_join(c_ifps,test_dat[c("user_id","discover_id","date",
                                      "option_1","option_2","option_3","option_4",
                                      "option_5")])


c_ifps <- c_ifps %>% group_by(discover_id, user_id) %>% 
  mutate_all(funs(na.locf(.,na.rm = FALSE))) %>% ungroup()


c_ifps <- c_ifps[!is.na(c_ifps$option_1),]

c_ifps <- left_join(c_ifps, unique(test_dat[c("discover_id","is_ordinal")]))

c_ifps <- left_join(c_ifps, users2[c("user_id","wt_i","wt_v",
                                     "wt_f","wt_t")])



c_ifps <- c_ifps[!is.na(c_ifps$wt_v),]


## Weight forecasts by predicted forecaster ranking
daily_casts <- c_ifps %>% group_by(discover_id, date) %>% 
  summarize(option_v_1 = weighted.mean(option_1, wt_v),
            option_v_2 = weighted.mean(option_2, wt_v),
            option_v_3 = weighted.mean(option_3, wt_v),
            option_v_4 = weighted.mean(option_4, wt_v),
            option_v_5 = weighted.mean(option_5, wt_v),
            option_f_1 = weighted.mean(option_1, wt_f),
            option_f_2 = weighted.mean(option_2, wt_f),
            option_f_3 = weighted.mean(option_3, wt_f),
            option_f_4 = weighted.mean(option_4, wt_f),
            option_f_5 = weighted.mean(option_5, wt_f),
            option_t_1 = weighted.mean(option_1, wt_t),
            option_t_2 = weighted.mean(option_2, wt_t),
            option_t_3 = weighted.mean(option_3, wt_t),
            option_t_4 = weighted.mean(option_4, wt_t),
            option_t_5 = weighted.mean(option_5, wt_t),
            option_i_1 = weighted.mean(option_1, wt_i),
            option_i_2 = weighted.mean(option_2, wt_i),
            option_i_3 = weighted.mean(option_3, wt_i),
            option_i_4 = weighted.mean(option_4, wt_i),
            option_i_5 = weighted.mean(option_5, wt_i),
            option_1 = mean(option_1),
            option_2 = mean(option_2),
            option_3 = mean(option_3),
            option_4 = mean(option_4),
            option_5 = mean(option_5)) %>% ungroup()


daily_casts <- left_join(daily_casts, unique(test_dat[c("discover_id","is_ordinal","resolution",
                                                        "num_options")]))

## Calculate daily Brier scores for each weighted forecast
ord_ifps <- daily_casts[daily_casts$is_ordinal == "True",]
n_ord_ifps <- daily_casts[daily_casts$is_ordinal == "False",]


#brier_v score calculation for nomminal IFPs
n_ord_ifps$brier_v <- ifelse(n_ord_ifps$resolution == 1, ((1-n_ord_ifps$option_v_1)^2 + (0-n_ord_ifps$option_v_2)^2 +
                                                            (0-n_ord_ifps$option_v_3)^2 + (0-n_ord_ifps$option_v_4)^2 + (0-n_ord_ifps$option_v_5)^2),
                             ifelse(n_ord_ifps$resolution == 2, ((1-n_ord_ifps$option_v_2)^2 + (0-n_ord_ifps$option_v_1)^2 +
                                                                   (0-n_ord_ifps$option_v_3)^2 + (0-n_ord_ifps$option_v_4)^2 + (0-n_ord_ifps$option_v_5)^2),
                                    ifelse(n_ord_ifps$resolution == 3, ((1-n_ord_ifps$option_v_3)^2 + (0-n_ord_ifps$option_v_2)^2 +
                                                                          (0-n_ord_ifps$option_v_1)^2 + (0-n_ord_ifps$option_v_4)^2 + (0-n_ord_ifps$option_v_5)^2),
                                           ifelse(n_ord_ifps$resolution == 4, ((1-n_ord_ifps$option_v_4)^2 + (0-n_ord_ifps$option_v_2)^2 +
                                                                                 (0-n_ord_ifps$option_v_3)^2 + (0-n_ord_ifps$option_v_1)^2 + (0-n_ord_ifps$option_v_5)^2),
                                                  ifelse(n_ord_ifps$resolution == 5, ((1-n_ord_ifps$option_v_5)^2 + (0-n_ord_ifps$option_v_2)^2 +
                                                                                        (0-n_ord_ifps$option_v_3)^2 + (0-n_ord_ifps$option_v_4)^2 + (0-n_ord_ifps$option_v_1)^2),NA)))))


#brier_v score calculation for ordinal IFPs
ord_ifps$brier_v1 <- ifelse(ord_ifps$resolution == 1, ((1-ord_ifps$option_v_1)^2 + ((0-(1-ord_ifps$option_v_1))^2)),
                            ((0-ord_ifps$option_v_1)^2 + ((1-(1-ord_ifps$option_v_1))^2)))

ord_ifps$brier_v2 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2,
                            (1-(ord_ifps$option_v_1 + ord_ifps$option_v_2))^2 + (0-(1-(ord_ifps$option_v_1 + 
                                                                                         ord_ifps$option_v_2)))^2,
                            (0-(ord_ifps$option_v_1 + ord_ifps$option_v_2))^2 + (1-(1-(ord_ifps$option_v_1 + 
                                                                                         ord_ifps$option_v_2)))^2)

ord_ifps$brier_v3 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2 | ord_ifps$resolution == 3,
                            (0-(ord_ifps$option_v_4 + ord_ifps$option_v_5))^2 + (1-(1-(ord_ifps$option_v_4 + 
                                                                                         ord_ifps$option_v_5)))^2,
                            (1-(ord_ifps$option_v_4 + ord_ifps$option_v_5))^2 + (0-(1-(ord_ifps$option_v_4 + 
                                                                                         ord_ifps$option_v_5)))^2)

ord_ifps$brier_v4 <- ifelse(ord_ifps$resolution != 5, ((0-ord_ifps$option_v_5)^2 + ((1-(1-ord_ifps$option_v_5))^2)),
                            ((1-ord_ifps$option_v_5)^2 + ((0-(1-ord_ifps$option_v_5))^2)))

ord_ifps$brier_v <- (ord_ifps$brier_v1 + ord_ifps$brier_v2 + ord_ifps$brier_v3 + ord_ifps$brier_v4)/
  (ord_ifps$num_options - 1)


#create variables of all missing values so the nominal and ordinal IFP tables can be re-merged
n_ord_ifps$brier_v1 <- NA
n_ord_ifps$brier_v2 <- NA
n_ord_ifps$brier_v3 <- NA
n_ord_ifps$brier_v4 <- NA




#brier_f score calculation for nomminal IFPs
n_ord_ifps$brier_f <- ifelse(n_ord_ifps$resolution == 1, ((1-n_ord_ifps$option_f_1)^2 + (0-n_ord_ifps$option_f_2)^2 +
                                                            (0-n_ord_ifps$option_f_3)^2 + (0-n_ord_ifps$option_f_4)^2 + (0-n_ord_ifps$option_f_5)^2),
                             ifelse(n_ord_ifps$resolution == 2, ((1-n_ord_ifps$option_f_2)^2 + (0-n_ord_ifps$option_f_1)^2 +
                                                                   (0-n_ord_ifps$option_f_3)^2 + (0-n_ord_ifps$option_f_4)^2 + (0-n_ord_ifps$option_f_5)^2),
                                    ifelse(n_ord_ifps$resolution == 3, ((1-n_ord_ifps$option_f_3)^2 + (0-n_ord_ifps$option_f_2)^2 +
                                                                          (0-n_ord_ifps$option_f_1)^2 + (0-n_ord_ifps$option_f_4)^2 + (0-n_ord_ifps$option_f_5)^2),
                                           ifelse(n_ord_ifps$resolution == 4, ((1-n_ord_ifps$option_f_4)^2 + (0-n_ord_ifps$option_f_2)^2 +
                                                                                 (0-n_ord_ifps$option_f_3)^2 + (0-n_ord_ifps$option_f_1)^2 + (0-n_ord_ifps$option_f_5)^2),
                                                  ifelse(n_ord_ifps$resolution == 5, ((1-n_ord_ifps$option_f_5)^2 + (0-n_ord_ifps$option_f_2)^2 +
                                                                                        (0-n_ord_ifps$option_f_3)^2 + (0-n_ord_ifps$option_f_4)^2 + (0-n_ord_ifps$option_f_1)^2),NA)))))


#brier_f score calculation for ordinal IFPs
ord_ifps$brier_f1 <- ifelse(ord_ifps$resolution == 1, ((1-ord_ifps$option_f_1)^2 + ((0-(1-ord_ifps$option_f_1))^2)),
                            ((0-ord_ifps$option_f_1)^2 + ((1-(1-ord_ifps$option_f_1))^2)))

ord_ifps$brier_f2 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2,
                            (1-(ord_ifps$option_f_1 + ord_ifps$option_f_2))^2 + (0-(1-(ord_ifps$option_f_1 + 
                                                                                         ord_ifps$option_f_2)))^2,
                            (0-(ord_ifps$option_f_1 + ord_ifps$option_f_2))^2 + (1-(1-(ord_ifps$option_f_1 + 
                                                                                         ord_ifps$option_f_2)))^2)

ord_ifps$brier_f3 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2 | ord_ifps$resolution == 3,
                            (0-(ord_ifps$option_f_4 + ord_ifps$option_f_5))^2 + (1-(1-(ord_ifps$option_f_4 + 
                                                                                         ord_ifps$option_f_5)))^2,
                            (1-(ord_ifps$option_f_4 + ord_ifps$option_f_5))^2 + (0-(1-(ord_ifps$option_f_4 + 
                                                                                         ord_ifps$option_f_5)))^2)

ord_ifps$brier_f4 <- ifelse(ord_ifps$resolution != 5, ((0-ord_ifps$option_f_5)^2 + ((1-(1-ord_ifps$option_f_5))^2)),
                            ((1-ord_ifps$option_f_5)^2 + ((0-(1-ord_ifps$option_f_5))^2)))

ord_ifps$brier_f <- (ord_ifps$brier_f1 + ord_ifps$brier_f2 + ord_ifps$brier_f3 + ord_ifps$brier_f4)/
  (ord_ifps$num_options - 1)


#create variables of all missing values so the nominal and ordinal IFP tables can be re-merged
n_ord_ifps$brier_f1 <- NA
n_ord_ifps$brier_f2 <- NA
n_ord_ifps$brier_f3 <- NA
n_ord_ifps$brier_f4 <- NA



#brier_t score calculation for nomminal IFPs
n_ord_ifps$brier_t <- ifelse(n_ord_ifps$resolution == 1, ((1-n_ord_ifps$option_t_1)^2 + (0-n_ord_ifps$option_t_2)^2 +
                                                            (0-n_ord_ifps$option_t_3)^2 + (0-n_ord_ifps$option_t_4)^2 + (0-n_ord_ifps$option_t_5)^2),
                             ifelse(n_ord_ifps$resolution == 2, ((1-n_ord_ifps$option_t_2)^2 + (0-n_ord_ifps$option_t_1)^2 +
                                                                   (0-n_ord_ifps$option_t_3)^2 + (0-n_ord_ifps$option_t_4)^2 + (0-n_ord_ifps$option_t_5)^2),
                                    ifelse(n_ord_ifps$resolution == 3, ((1-n_ord_ifps$option_t_3)^2 + (0-n_ord_ifps$option_t_2)^2 +
                                                                          (0-n_ord_ifps$option_t_1)^2 + (0-n_ord_ifps$option_t_4)^2 + (0-n_ord_ifps$option_t_5)^2),
                                           ifelse(n_ord_ifps$resolution == 4, ((1-n_ord_ifps$option_t_4)^2 + (0-n_ord_ifps$option_t_2)^2 +
                                                                                 (0-n_ord_ifps$option_t_3)^2 + (0-n_ord_ifps$option_t_1)^2 + (0-n_ord_ifps$option_t_5)^2),
                                                  ifelse(n_ord_ifps$resolution == 5, ((1-n_ord_ifps$option_t_5)^2 + (0-n_ord_ifps$option_t_2)^2 +
                                                                                        (0-n_ord_ifps$option_t_3)^2 + (0-n_ord_ifps$option_t_4)^2 + (0-n_ord_ifps$option_t_1)^2),NA)))))


#brier_t score calculation for ordinal IFPs
ord_ifps$brier_t1 <- ifelse(ord_ifps$resolution == 1, ((1-ord_ifps$option_t_1)^2 + ((0-(1-ord_ifps$option_t_1))^2)),
                            ((0-ord_ifps$option_t_1)^2 + ((1-(1-ord_ifps$option_t_1))^2)))

ord_ifps$brier_t2 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2,
                            (1-(ord_ifps$option_t_1 + ord_ifps$option_t_2))^2 + (0-(1-(ord_ifps$option_t_1 + 
                                                                                         ord_ifps$option_t_2)))^2,
                            (0-(ord_ifps$option_t_1 + ord_ifps$option_t_2))^2 + (1-(1-(ord_ifps$option_t_1 + 
                                                                                         ord_ifps$option_t_2)))^2)

ord_ifps$brier_t3 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2 | ord_ifps$resolution == 3,
                            (0-(ord_ifps$option_t_4 + ord_ifps$option_t_5))^2 + (1-(1-(ord_ifps$option_t_4 + 
                                                                                         ord_ifps$option_t_5)))^2,
                            (1-(ord_ifps$option_t_4 + ord_ifps$option_t_5))^2 + (0-(1-(ord_ifps$option_t_4 + 
                                                                                         ord_ifps$option_t_5)))^2)

ord_ifps$brier_t4 <- ifelse(ord_ifps$resolution != 5, ((0-ord_ifps$option_t_5)^2 + ((1-(1-ord_ifps$option_t_5))^2)),
                            ((1-ord_ifps$option_t_5)^2 + ((0-(1-ord_ifps$option_t_5))^2)))

ord_ifps$brier_t <- (ord_ifps$brier_t1 + ord_ifps$brier_t2 + ord_ifps$brier_t3 + ord_ifps$brier_t4)/
  (ord_ifps$num_options - 1)


#create variables of all missing values so the nominal and ordinal IFP tables can be re-merged
n_ord_ifps$brier_t1 <- NA
n_ord_ifps$brier_t2 <- NA
n_ord_ifps$brier_t3 <- NA
n_ord_ifps$brier_t4 <- NA




#brier_i score calculation for nomminal IFPs
n_ord_ifps$brier_i <- ifelse(n_ord_ifps$resolution == 1, ((1-n_ord_ifps$option_i_1)^2 + (0-n_ord_ifps$option_i_2)^2 +
                                                            (0-n_ord_ifps$option_i_3)^2 + (0-n_ord_ifps$option_i_4)^2 + (0-n_ord_ifps$option_i_5)^2),
                             ifelse(n_ord_ifps$resolution == 2, ((1-n_ord_ifps$option_i_2)^2 + (0-n_ord_ifps$option_i_1)^2 +
                                                                   (0-n_ord_ifps$option_i_3)^2 + (0-n_ord_ifps$option_i_4)^2 + (0-n_ord_ifps$option_i_5)^2),
                                    ifelse(n_ord_ifps$resolution == 3, ((1-n_ord_ifps$option_i_3)^2 + (0-n_ord_ifps$option_i_2)^2 +
                                                                          (0-n_ord_ifps$option_i_1)^2 + (0-n_ord_ifps$option_i_4)^2 + (0-n_ord_ifps$option_i_5)^2),
                                           ifelse(n_ord_ifps$resolution == 4, ((1-n_ord_ifps$option_i_4)^2 + (0-n_ord_ifps$option_i_2)^2 +
                                                                                 (0-n_ord_ifps$option_i_3)^2 + (0-n_ord_ifps$option_i_1)^2 + (0-n_ord_ifps$option_i_5)^2),
                                                  ifelse(n_ord_ifps$resolution == 5, ((1-n_ord_ifps$option_i_5)^2 + (0-n_ord_ifps$option_i_2)^2 +
                                                                                        (0-n_ord_ifps$option_i_3)^2 + (0-n_ord_ifps$option_i_4)^2 + (0-n_ord_ifps$option_i_1)^2),NA)))))


#brier_i score calculation for ordinal IFPs
ord_ifps$brier_i1 <- ifelse(ord_ifps$resolution == 1, ((1-ord_ifps$option_i_1)^2 + ((0-(1-ord_ifps$option_i_1))^2)),
                            ((0-ord_ifps$option_i_1)^2 + ((1-(1-ord_ifps$option_i_1))^2)))

ord_ifps$brier_i2 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2,
                            (1-(ord_ifps$option_i_1 + ord_ifps$option_i_2))^2 + (0-(1-(ord_ifps$option_i_1 + 
                                                                                         ord_ifps$option_i_2)))^2,
                            (0-(ord_ifps$option_i_1 + ord_ifps$option_i_2))^2 + (1-(1-(ord_ifps$option_i_1 + 
                                                                                         ord_ifps$option_i_2)))^2)

ord_ifps$brier_i3 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2 | ord_ifps$resolution == 3,
                            (0-(ord_ifps$option_i_4 + ord_ifps$option_i_5))^2 + (1-(1-(ord_ifps$option_i_4 + 
                                                                                         ord_ifps$option_i_5)))^2,
                            (1-(ord_ifps$option_i_4 + ord_ifps$option_i_5))^2 + (0-(1-(ord_ifps$option_i_4 + 
                                                                                         ord_ifps$option_i_5)))^2)

ord_ifps$brier_i4 <- ifelse(ord_ifps$resolution != 5, ((0-ord_ifps$option_i_5)^2 + ((1-(1-ord_ifps$option_i_5))^2)),
                            ((1-ord_ifps$option_i_5)^2 + ((0-(1-ord_ifps$option_i_5))^2)))

ord_ifps$brier_i <- (ord_ifps$brier_i1 + ord_ifps$brier_i2 + ord_ifps$brier_i3 + ord_ifps$brier_i4)/
  (ord_ifps$num_options - 1)


#create variables of all missing values so the nominal and ordinal IFP tables can be re-merged
n_ord_ifps$brier_i1 <- NA
n_ord_ifps$brier_i2 <- NA
n_ord_ifps$brier_i3 <- NA
n_ord_ifps$brier_i4 <- NA



#brier score calculation for nomminal IFPs
n_ord_ifps$brier <- ifelse(n_ord_ifps$resolution == 1, ((1-n_ord_ifps$option_1)^2 + (0-n_ord_ifps$option_2)^2 +
                                                          (0-n_ord_ifps$option_3)^2 + (0-n_ord_ifps$option_4)^2 + (0-n_ord_ifps$option_5)^2),
                           ifelse(n_ord_ifps$resolution == 2, ((1-n_ord_ifps$option_2)^2 + (0-n_ord_ifps$option_1)^2 +
                                                                 (0-n_ord_ifps$option_3)^2 + (0-n_ord_ifps$option_4)^2 + (0-n_ord_ifps$option_5)^2),
                                  ifelse(n_ord_ifps$resolution == 3, ((1-n_ord_ifps$option_3)^2 + (0-n_ord_ifps$option_2)^2 +
                                                                        (0-n_ord_ifps$option_1)^2 + (0-n_ord_ifps$option_4)^2 + (0-n_ord_ifps$option_5)^2),
                                         ifelse(n_ord_ifps$resolution == 4, ((1-n_ord_ifps$option_4)^2 + (0-n_ord_ifps$option_2)^2 +
                                                                               (0-n_ord_ifps$option_3)^2 + (0-n_ord_ifps$option_1)^2 + (0-n_ord_ifps$option_5)^2),
                                                ifelse(n_ord_ifps$resolution == 5, ((1-n_ord_ifps$option_5)^2 + (0-n_ord_ifps$option_2)^2 +
                                                                                      (0-n_ord_ifps$option_3)^2 + (0-n_ord_ifps$option_4)^2 + (0-n_ord_ifps$option_1)^2),NA)))))


#brier score calculation for ordinal IFPs
ord_ifps$brier1 <- ifelse(ord_ifps$resolution == 1, ((1-ord_ifps$option_1)^2 + ((0-(1-ord_ifps$option_1))^2)),
                          ((0-ord_ifps$option_1)^2 + ((1-(1-ord_ifps$option_1))^2)))

ord_ifps$brier2 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2,
                          (1-(ord_ifps$option_1 + ord_ifps$option_2))^2 + (0-(1-(ord_ifps$option_1 + 
                                                                                   ord_ifps$option_2)))^2,
                          (0-(ord_ifps$option_1 + ord_ifps$option_2))^2 + (1-(1-(ord_ifps$option_1 + 
                                                                                   ord_ifps$option_2)))^2)

ord_ifps$brier3 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2 | ord_ifps$resolution == 3,
                          (0-(ord_ifps$option_4 + ord_ifps$option_5))^2 + (1-(1-(ord_ifps$option_4 + 
                                                                                   ord_ifps$option_5)))^2,
                          (1-(ord_ifps$option_4 + ord_ifps$option_5))^2 + (0-(1-(ord_ifps$option_4 + 
                                                                                   ord_ifps$option_5)))^2)

ord_ifps$brier4 <- ifelse(ord_ifps$resolution != 5, ((0-ord_ifps$option_5)^2 + ((1-(1-ord_ifps$option_5))^2)),
                          ((1-ord_ifps$option_5)^2 + ((0-(1-ord_ifps$option_5))^2)))

ord_ifps$brier <- (ord_ifps$brier1 + ord_ifps$brier2 + ord_ifps$brier3 + ord_ifps$brier4)/
  (ord_ifps$num_options - 1)



#create variables of all missing values so the nominal and ordinal IFP tables can be re-merged
n_ord_ifps$brier1 <- NA
n_ord_ifps$brier2 <- NA
n_ord_ifps$brier3 <- NA
n_ord_ifps$brier4 <- NA


br_wtscrs <- rbind(ord_ifps, n_ord_ifps)

## Mean daily Brier Scores with ID

cm1a <- colMeans(br_wtscrs[c("brier_f","brier_v","brier_t","brier_i",
                             "brier")])



br_wtscrs$brier[br_wtscrs$brier == 0] <- .0001
br_wtscrs$brier_f[br_wtscrs$brier_f == 0] <- .0001
br_wtscrs$brier_v[br_wtscrs$brier_v == 0] <- .0001
br_wtscrs$brier_i[br_wtscrs$brier_i == 0] <- .0001
br_wtscrs$brier_t[br_wtscrs$brier_t == 0] <- .0001

br_wtscrs$acc_f <- VGAM::probitlink(1-(sqrt(br_wtscrs$brier_f/2)))
br_wtscrs$acc_v <- VGAM::probitlink(1-(sqrt(br_wtscrs$brier_v/2)))
br_wtscrs$acc_t <- VGAM::probitlink(1-(sqrt(br_wtscrs$brier_t/2)))
br_wtscrs$acc_i <- VGAM::probitlink(1-(sqrt(br_wtscrs$brier_i/2)))
br_wtscrs$acc <- VGAM::probitlink(1-(sqrt(br_wtscrs$brier/2)))


## Mean daily normalized accuracy with ID
cm1b <- colMeans(br_wtscrs[c(grep("acc", names(br_wtscrs)))])

## Same as above without ID
br_wtscrs_a <- br_wtscrs




lmer_vf <- lmer(correct_prob ~  acc_std_f_e + fcasts_f_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), br_ifps_f)


lmer_ff <- lmer(correct_prob ~ hier_e_f + fcasts_f_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), br_ifps_f)

lmer_tf <- lmer(correct_prob ~ theta_train1 + fcasts_f_e + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), br_ifps_f)



lmer_if <- lmer(correct_prob ~ ns_score + bn_score + aomt_score + 
                  pk_score_percent + pk_overconf + demo_age + ed_num +
                  demo_gender_f + time_rem_log + 
                  (1 | discover_id) + (1 | user_id), br_ifps_f)




br_ifps_test <- br_ifps_s[br_ifps_s$e_l_f =="f",]


users <- unique(irt_dat[c("user_id","ns_score",
                          "bn_score", "aomt_score", "pk_score_percent",
                          "pk_overconf",
                          "demo_age", "demo_gender_f", "ed_num")])


usrs2 <- irt_dat[c(grep("user_id",names(irt_dat)),
                   grep("acc",names(irt_dat)),
                   grep("hier",names(irt_dat)),
                   grep("theta", names(irt_dat)),
                   grep("ifp_ct",names(irt_dat)),
                   grep("fcasts",names(irt_dat)))]

usrs2 <- unique(usrs2)                      

users <- left_join(users, usrs2)




testmod <- lmer(correct_prob ~ time_rem_log + (1 | user_id) + (1 | discover_id),
                br_ifps_test)


testres <- data.frame(user_id = rownames(ranef(testmod)$user_id),
                      mus = ranef(testmod)$user_id$`(Intercept)`)

users_test <- join_all(list(users, testres), type = "left")

users2 <- users_test

users2$discover_id <- 0
users2$time_rem_log <- 0
users2$user_id <- paste(users2$user_id, "outsamp")

users2$rk_v <- predict(lmer_vf, newdata = users2, allow.new.levels = TRUE)
users2$rk_f <- predict(lmer_ff, newdata = users2, allow.new.levels = TRUE)
users2$rk_t <- predict(lmer_tf, newdata = users2, allow.new.levels = TRUE)
users2$rk_i <- predict(lmer_if, newdata = users2, allow.new.levels = TRUE)

users2b <- users2[c("user_id","mus","rk_f","rk_t","rk_v","rk_i")]


## Table 11 without ID
t11b <- round(cor(users2[c("mus","rk_f","rk_t","rk_v","rk_i")],
    use = "pairwise.complete.obs"),2)

write.csv(t11b, "table 11b.csv")


test_dat <- br_ifps_test

test_dat2 <- test_dat


test_dat$user_id <- paste(test_dat$user_id, "outsamp")



#carry forward daily forecast values
d_ifps <- data.frame(date=as.numeric(min(as.Date(test_dat$date))):as.numeric(max(as.Date(test_dat$date))))
d_ifps$date <- as.Date(d_ifps$date, origin="1970-01-01")

c_ifps <- expand.grid(d_ifps$date, unique(test_dat$user_id),unique(test_dat$discover_id))
colnames(c_ifps) <- c("date","user_id","discover_id")

c_ifps <- c_ifps[order(c_ifps$discover_id,c_ifps$user_id,c_ifps$date),]


c_ifps <- left_join(c_ifps, unique(test_dat[c("discover_id","start_date","close_date")]))

c_ifps <- c_ifps[c_ifps$date >= c_ifps$start_date & c_ifps$date <= c_ifps$close_date,]

test_dat$date <- as.Date(test_dat$date)
c_ifps <- left_join(c_ifps,test_dat[c("user_id","discover_id","date",
                                      "option_1","option_2","option_3","option_4",
                                      "option_5")])


c_ifps <- c_ifps %>% group_by(discover_id, user_id) %>% 
  mutate_all(funs(na.locf(.,na.rm = FALSE))) %>% ungroup()


c_ifps <- c_ifps[!is.na(c_ifps$option_1),]

c_ifps <- left_join(c_ifps, unique(test_dat[c("discover_id","is_ordinal")]))

c_ifps <- left_join(c_ifps, users2[c("user_id","wt_i","wt_v",
                                     "wt_f","wt_t")])



c_ifps <- c_ifps[!is.na(c_ifps$wt_v),]

daily_casts <- c_ifps %>% group_by(discover_id, date) %>% 
  summarize(option_v_1 = weighted.mean(option_1, wt_v),
            option_v_2 = weighted.mean(option_2, wt_v),
            option_v_3 = weighted.mean(option_3, wt_v),
            option_v_4 = weighted.mean(option_4, wt_v),
            option_v_5 = weighted.mean(option_5, wt_v),
            option_f_1 = weighted.mean(option_1, wt_f),
            option_f_2 = weighted.mean(option_2, wt_f),
            option_f_3 = weighted.mean(option_3, wt_f),
            option_f_4 = weighted.mean(option_4, wt_f),
            option_f_5 = weighted.mean(option_5, wt_f),
            option_t_1 = weighted.mean(option_1, wt_t),
            option_t_2 = weighted.mean(option_2, wt_t),
            option_t_3 = weighted.mean(option_3, wt_t),
            option_t_4 = weighted.mean(option_4, wt_t),
            option_t_5 = weighted.mean(option_5, wt_t),
            option_i_1 = weighted.mean(option_1, wt_i),
            option_i_2 = weighted.mean(option_2, wt_i),
            option_i_3 = weighted.mean(option_3, wt_i),
            option_i_4 = weighted.mean(option_4, wt_i),
            option_i_5 = weighted.mean(option_5, wt_i),
            option_1 = mean(option_1),
            option_2 = mean(option_2),
            option_3 = mean(option_3),
            option_4 = mean(option_4),
            option_5 = mean(option_5)) %>% ungroup()


daily_casts <- left_join(daily_casts, unique(test_dat[c("discover_id","is_ordinal","resolution",
                                                        "num_options")]))

ord_ifps <- daily_casts[daily_casts$is_ordinal == "True",]
n_ord_ifps <- daily_casts[daily_casts$is_ordinal == "False",]


#brier_v score calculation for nomminal IFPs
n_ord_ifps$brier_v <- ifelse(n_ord_ifps$resolution == 1, ((1-n_ord_ifps$option_v_1)^2 + (0-n_ord_ifps$option_v_2)^2 +
                                                            (0-n_ord_ifps$option_v_3)^2 + (0-n_ord_ifps$option_v_4)^2 + (0-n_ord_ifps$option_v_5)^2),
                             ifelse(n_ord_ifps$resolution == 2, ((1-n_ord_ifps$option_v_2)^2 + (0-n_ord_ifps$option_v_1)^2 +
                                                                   (0-n_ord_ifps$option_v_3)^2 + (0-n_ord_ifps$option_v_4)^2 + (0-n_ord_ifps$option_v_5)^2),
                                    ifelse(n_ord_ifps$resolution == 3, ((1-n_ord_ifps$option_v_3)^2 + (0-n_ord_ifps$option_v_2)^2 +
                                                                          (0-n_ord_ifps$option_v_1)^2 + (0-n_ord_ifps$option_v_4)^2 + (0-n_ord_ifps$option_v_5)^2),
                                           ifelse(n_ord_ifps$resolution == 4, ((1-n_ord_ifps$option_v_4)^2 + (0-n_ord_ifps$option_v_2)^2 +
                                                                                 (0-n_ord_ifps$option_v_3)^2 + (0-n_ord_ifps$option_v_1)^2 + (0-n_ord_ifps$option_v_5)^2),
                                                  ifelse(n_ord_ifps$resolution == 5, ((1-n_ord_ifps$option_v_5)^2 + (0-n_ord_ifps$option_v_2)^2 +
                                                                                        (0-n_ord_ifps$option_v_3)^2 + (0-n_ord_ifps$option_v_4)^2 + (0-n_ord_ifps$option_v_1)^2),NA)))))


#brier_v score calculation for ordinal IFPs
ord_ifps$brier_v1 <- ifelse(ord_ifps$resolution == 1, ((1-ord_ifps$option_v_1)^2 + ((0-(1-ord_ifps$option_v_1))^2)),
                            ((0-ord_ifps$option_v_1)^2 + ((1-(1-ord_ifps$option_v_1))^2)))

ord_ifps$brier_v2 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2,
                            (1-(ord_ifps$option_v_1 + ord_ifps$option_v_2))^2 + (0-(1-(ord_ifps$option_v_1 + 
                                                                                         ord_ifps$option_v_2)))^2,
                            (0-(ord_ifps$option_v_1 + ord_ifps$option_v_2))^2 + (1-(1-(ord_ifps$option_v_1 + 
                                                                                         ord_ifps$option_v_2)))^2)

ord_ifps$brier_v3 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2 | ord_ifps$resolution == 3,
                            (0-(ord_ifps$option_v_4 + ord_ifps$option_v_5))^2 + (1-(1-(ord_ifps$option_v_4 + 
                                                                                         ord_ifps$option_v_5)))^2,
                            (1-(ord_ifps$option_v_4 + ord_ifps$option_v_5))^2 + (0-(1-(ord_ifps$option_v_4 + 
                                                                                         ord_ifps$option_v_5)))^2)

ord_ifps$brier_v4 <- ifelse(ord_ifps$resolution != 5, ((0-ord_ifps$option_v_5)^2 + ((1-(1-ord_ifps$option_v_5))^2)),
                            ((1-ord_ifps$option_v_5)^2 + ((0-(1-ord_ifps$option_v_5))^2)))

ord_ifps$brier_v <- (ord_ifps$brier_v1 + ord_ifps$brier_v2 + ord_ifps$brier_v3 + ord_ifps$brier_v4)/
  (ord_ifps$num_options - 1)


#create variables of all missing values so the nominal and ordinal IFP tables can be re-merged
n_ord_ifps$brier_v1 <- NA
n_ord_ifps$brier_v2 <- NA
n_ord_ifps$brier_v3 <- NA
n_ord_ifps$brier_v4 <- NA




#brier_f score calculation for nomminal IFPs
n_ord_ifps$brier_f <- ifelse(n_ord_ifps$resolution == 1, ((1-n_ord_ifps$option_f_1)^2 + (0-n_ord_ifps$option_f_2)^2 +
                                                            (0-n_ord_ifps$option_f_3)^2 + (0-n_ord_ifps$option_f_4)^2 + (0-n_ord_ifps$option_f_5)^2),
                             ifelse(n_ord_ifps$resolution == 2, ((1-n_ord_ifps$option_f_2)^2 + (0-n_ord_ifps$option_f_1)^2 +
                                                                   (0-n_ord_ifps$option_f_3)^2 + (0-n_ord_ifps$option_f_4)^2 + (0-n_ord_ifps$option_f_5)^2),
                                    ifelse(n_ord_ifps$resolution == 3, ((1-n_ord_ifps$option_f_3)^2 + (0-n_ord_ifps$option_f_2)^2 +
                                                                          (0-n_ord_ifps$option_f_1)^2 + (0-n_ord_ifps$option_f_4)^2 + (0-n_ord_ifps$option_f_5)^2),
                                           ifelse(n_ord_ifps$resolution == 4, ((1-n_ord_ifps$option_f_4)^2 + (0-n_ord_ifps$option_f_2)^2 +
                                                                                 (0-n_ord_ifps$option_f_3)^2 + (0-n_ord_ifps$option_f_1)^2 + (0-n_ord_ifps$option_f_5)^2),
                                                  ifelse(n_ord_ifps$resolution == 5, ((1-n_ord_ifps$option_f_5)^2 + (0-n_ord_ifps$option_f_2)^2 +
                                                                                        (0-n_ord_ifps$option_f_3)^2 + (0-n_ord_ifps$option_f_4)^2 + (0-n_ord_ifps$option_f_1)^2),NA)))))


#brier_f score calculation for ordinal IFPs
ord_ifps$brier_f1 <- ifelse(ord_ifps$resolution == 1, ((1-ord_ifps$option_f_1)^2 + ((0-(1-ord_ifps$option_f_1))^2)),
                            ((0-ord_ifps$option_f_1)^2 + ((1-(1-ord_ifps$option_f_1))^2)))

ord_ifps$brier_f2 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2,
                            (1-(ord_ifps$option_f_1 + ord_ifps$option_f_2))^2 + (0-(1-(ord_ifps$option_f_1 + 
                                                                                         ord_ifps$option_f_2)))^2,
                            (0-(ord_ifps$option_f_1 + ord_ifps$option_f_2))^2 + (1-(1-(ord_ifps$option_f_1 + 
                                                                                         ord_ifps$option_f_2)))^2)

ord_ifps$brier_f3 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2 | ord_ifps$resolution == 3,
                            (0-(ord_ifps$option_f_4 + ord_ifps$option_f_5))^2 + (1-(1-(ord_ifps$option_f_4 + 
                                                                                         ord_ifps$option_f_5)))^2,
                            (1-(ord_ifps$option_f_4 + ord_ifps$option_f_5))^2 + (0-(1-(ord_ifps$option_f_4 + 
                                                                                         ord_ifps$option_f_5)))^2)

ord_ifps$brier_f4 <- ifelse(ord_ifps$resolution != 5, ((0-ord_ifps$option_f_5)^2 + ((1-(1-ord_ifps$option_f_5))^2)),
                            ((1-ord_ifps$option_f_5)^2 + ((0-(1-ord_ifps$option_f_5))^2)))

ord_ifps$brier_f <- (ord_ifps$brier_f1 + ord_ifps$brier_f2 + ord_ifps$brier_f3 + ord_ifps$brier_f4)/
  (ord_ifps$num_options - 1)


#create variables of all missing values so the nominal and ordinal IFP tables can be re-merged
n_ord_ifps$brier_f1 <- NA
n_ord_ifps$brier_f2 <- NA
n_ord_ifps$brier_f3 <- NA
n_ord_ifps$brier_f4 <- NA



#brier_t score calculation for nomminal IFPs
n_ord_ifps$brier_t <- ifelse(n_ord_ifps$resolution == 1, ((1-n_ord_ifps$option_t_1)^2 + (0-n_ord_ifps$option_t_2)^2 +
                                                            (0-n_ord_ifps$option_t_3)^2 + (0-n_ord_ifps$option_t_4)^2 + (0-n_ord_ifps$option_t_5)^2),
                             ifelse(n_ord_ifps$resolution == 2, ((1-n_ord_ifps$option_t_2)^2 + (0-n_ord_ifps$option_t_1)^2 +
                                                                   (0-n_ord_ifps$option_t_3)^2 + (0-n_ord_ifps$option_t_4)^2 + (0-n_ord_ifps$option_t_5)^2),
                                    ifelse(n_ord_ifps$resolution == 3, ((1-n_ord_ifps$option_t_3)^2 + (0-n_ord_ifps$option_t_2)^2 +
                                                                          (0-n_ord_ifps$option_t_1)^2 + (0-n_ord_ifps$option_t_4)^2 + (0-n_ord_ifps$option_t_5)^2),
                                           ifelse(n_ord_ifps$resolution == 4, ((1-n_ord_ifps$option_t_4)^2 + (0-n_ord_ifps$option_t_2)^2 +
                                                                                 (0-n_ord_ifps$option_t_3)^2 + (0-n_ord_ifps$option_t_1)^2 + (0-n_ord_ifps$option_t_5)^2),
                                                  ifelse(n_ord_ifps$resolution == 5, ((1-n_ord_ifps$option_t_5)^2 + (0-n_ord_ifps$option_t_2)^2 +
                                                                                        (0-n_ord_ifps$option_t_3)^2 + (0-n_ord_ifps$option_t_4)^2 + (0-n_ord_ifps$option_t_1)^2),NA)))))


#brier_t score calculation for ordinal IFPs
ord_ifps$brier_t1 <- ifelse(ord_ifps$resolution == 1, ((1-ord_ifps$option_t_1)^2 + ((0-(1-ord_ifps$option_t_1))^2)),
                            ((0-ord_ifps$option_t_1)^2 + ((1-(1-ord_ifps$option_t_1))^2)))

ord_ifps$brier_t2 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2,
                            (1-(ord_ifps$option_t_1 + ord_ifps$option_t_2))^2 + (0-(1-(ord_ifps$option_t_1 + 
                                                                                         ord_ifps$option_t_2)))^2,
                            (0-(ord_ifps$option_t_1 + ord_ifps$option_t_2))^2 + (1-(1-(ord_ifps$option_t_1 + 
                                                                                         ord_ifps$option_t_2)))^2)

ord_ifps$brier_t3 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2 | ord_ifps$resolution == 3,
                            (0-(ord_ifps$option_t_4 + ord_ifps$option_t_5))^2 + (1-(1-(ord_ifps$option_t_4 + 
                                                                                         ord_ifps$option_t_5)))^2,
                            (1-(ord_ifps$option_t_4 + ord_ifps$option_t_5))^2 + (0-(1-(ord_ifps$option_t_4 + 
                                                                                         ord_ifps$option_t_5)))^2)

ord_ifps$brier_t4 <- ifelse(ord_ifps$resolution != 5, ((0-ord_ifps$option_t_5)^2 + ((1-(1-ord_ifps$option_t_5))^2)),
                            ((1-ord_ifps$option_t_5)^2 + ((0-(1-ord_ifps$option_t_5))^2)))

ord_ifps$brier_t <- (ord_ifps$brier_t1 + ord_ifps$brier_t2 + ord_ifps$brier_t3 + ord_ifps$brier_t4)/
  (ord_ifps$num_options - 1)


#create variables of all missing values so the nominal and ordinal IFP tables can be re-merged
n_ord_ifps$brier_t1 <- NA
n_ord_ifps$brier_t2 <- NA
n_ord_ifps$brier_t3 <- NA
n_ord_ifps$brier_t4 <- NA




#brier_i score calculation for nomminal IFPs
n_ord_ifps$brier_i <- ifelse(n_ord_ifps$resolution == 1, ((1-n_ord_ifps$option_i_1)^2 + (0-n_ord_ifps$option_i_2)^2 +
                                                            (0-n_ord_ifps$option_i_3)^2 + (0-n_ord_ifps$option_i_4)^2 + (0-n_ord_ifps$option_i_5)^2),
                             ifelse(n_ord_ifps$resolution == 2, ((1-n_ord_ifps$option_i_2)^2 + (0-n_ord_ifps$option_i_1)^2 +
                                                                   (0-n_ord_ifps$option_i_3)^2 + (0-n_ord_ifps$option_i_4)^2 + (0-n_ord_ifps$option_i_5)^2),
                                    ifelse(n_ord_ifps$resolution == 3, ((1-n_ord_ifps$option_i_3)^2 + (0-n_ord_ifps$option_i_2)^2 +
                                                                          (0-n_ord_ifps$option_i_1)^2 + (0-n_ord_ifps$option_i_4)^2 + (0-n_ord_ifps$option_i_5)^2),
                                           ifelse(n_ord_ifps$resolution == 4, ((1-n_ord_ifps$option_i_4)^2 + (0-n_ord_ifps$option_i_2)^2 +
                                                                                 (0-n_ord_ifps$option_i_3)^2 + (0-n_ord_ifps$option_i_1)^2 + (0-n_ord_ifps$option_i_5)^2),
                                                  ifelse(n_ord_ifps$resolution == 5, ((1-n_ord_ifps$option_i_5)^2 + (0-n_ord_ifps$option_i_2)^2 +
                                                                                        (0-n_ord_ifps$option_i_3)^2 + (0-n_ord_ifps$option_i_4)^2 + (0-n_ord_ifps$option_i_1)^2),NA)))))


#brier_i score calculation for ordinal IFPs
ord_ifps$brier_i1 <- ifelse(ord_ifps$resolution == 1, ((1-ord_ifps$option_i_1)^2 + ((0-(1-ord_ifps$option_i_1))^2)),
                            ((0-ord_ifps$option_i_1)^2 + ((1-(1-ord_ifps$option_i_1))^2)))

ord_ifps$brier_i2 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2,
                            (1-(ord_ifps$option_i_1 + ord_ifps$option_i_2))^2 + (0-(1-(ord_ifps$option_i_1 + 
                                                                                         ord_ifps$option_i_2)))^2,
                            (0-(ord_ifps$option_i_1 + ord_ifps$option_i_2))^2 + (1-(1-(ord_ifps$option_i_1 + 
                                                                                         ord_ifps$option_i_2)))^2)

ord_ifps$brier_i3 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2 | ord_ifps$resolution == 3,
                            (0-(ord_ifps$option_i_4 + ord_ifps$option_i_5))^2 + (1-(1-(ord_ifps$option_i_4 + 
                                                                                         ord_ifps$option_i_5)))^2,
                            (1-(ord_ifps$option_i_4 + ord_ifps$option_i_5))^2 + (0-(1-(ord_ifps$option_i_4 + 
                                                                                         ord_ifps$option_i_5)))^2)

ord_ifps$brier_i4 <- ifelse(ord_ifps$resolution != 5, ((0-ord_ifps$option_i_5)^2 + ((1-(1-ord_ifps$option_i_5))^2)),
                            ((1-ord_ifps$option_i_5)^2 + ((0-(1-ord_ifps$option_i_5))^2)))

ord_ifps$brier_i <- (ord_ifps$brier_i1 + ord_ifps$brier_i2 + ord_ifps$brier_i3 + ord_ifps$brier_i4)/
  (ord_ifps$num_options - 1)


#create variables of all missing values so the nominal and ordinal IFP tables can be re-merged
n_ord_ifps$brier_i1 <- NA
n_ord_ifps$brier_i2 <- NA
n_ord_ifps$brier_i3 <- NA
n_ord_ifps$brier_i4 <- NA



#brier score calculation for nomminal IFPs
n_ord_ifps$brier <- ifelse(n_ord_ifps$resolution == 1, ((1-n_ord_ifps$option_1)^2 + (0-n_ord_ifps$option_2)^2 +
                                                          (0-n_ord_ifps$option_3)^2 + (0-n_ord_ifps$option_4)^2 + (0-n_ord_ifps$option_5)^2),
                           ifelse(n_ord_ifps$resolution == 2, ((1-n_ord_ifps$option_2)^2 + (0-n_ord_ifps$option_1)^2 +
                                                                 (0-n_ord_ifps$option_3)^2 + (0-n_ord_ifps$option_4)^2 + (0-n_ord_ifps$option_5)^2),
                                  ifelse(n_ord_ifps$resolution == 3, ((1-n_ord_ifps$option_3)^2 + (0-n_ord_ifps$option_2)^2 +
                                                                        (0-n_ord_ifps$option_1)^2 + (0-n_ord_ifps$option_4)^2 + (0-n_ord_ifps$option_5)^2),
                                         ifelse(n_ord_ifps$resolution == 4, ((1-n_ord_ifps$option_4)^2 + (0-n_ord_ifps$option_2)^2 +
                                                                               (0-n_ord_ifps$option_3)^2 + (0-n_ord_ifps$option_1)^2 + (0-n_ord_ifps$option_5)^2),
                                                ifelse(n_ord_ifps$resolution == 5, ((1-n_ord_ifps$option_5)^2 + (0-n_ord_ifps$option_2)^2 +
                                                                                      (0-n_ord_ifps$option_3)^2 + (0-n_ord_ifps$option_4)^2 + (0-n_ord_ifps$option_1)^2),NA)))))


#brier score calculation for ordinal IFPs
ord_ifps$brier1 <- ifelse(ord_ifps$resolution == 1, ((1-ord_ifps$option_1)^2 + ((0-(1-ord_ifps$option_1))^2)),
                          ((0-ord_ifps$option_1)^2 + ((1-(1-ord_ifps$option_1))^2)))

ord_ifps$brier2 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2,
                          (1-(ord_ifps$option_1 + ord_ifps$option_2))^2 + (0-(1-(ord_ifps$option_1 + 
                                                                                   ord_ifps$option_2)))^2,
                          (0-(ord_ifps$option_1 + ord_ifps$option_2))^2 + (1-(1-(ord_ifps$option_1 + 
                                                                                   ord_ifps$option_2)))^2)

ord_ifps$brier3 <- ifelse(ord_ifps$resolution == 1 | ord_ifps$resolution ==2 | ord_ifps$resolution == 3,
                          (0-(ord_ifps$option_4 + ord_ifps$option_5))^2 + (1-(1-(ord_ifps$option_4 + 
                                                                                   ord_ifps$option_5)))^2,
                          (1-(ord_ifps$option_4 + ord_ifps$option_5))^2 + (0-(1-(ord_ifps$option_4 + 
                                                                                   ord_ifps$option_5)))^2)

ord_ifps$brier4 <- ifelse(ord_ifps$resolution != 5, ((0-ord_ifps$option_5)^2 + ((1-(1-ord_ifps$option_5))^2)),
                          ((1-ord_ifps$option_5)^2 + ((0-(1-ord_ifps$option_5))^2)))

ord_ifps$brier <- (ord_ifps$brier1 + ord_ifps$brier2 + ord_ifps$brier3 + ord_ifps$brier4)/
  (ord_ifps$num_options - 1)



#create variables of all missing values so the nominal and ordinal IFP tables can be re-merged
n_ord_ifps$brier1 <- NA
n_ord_ifps$brier2 <- NA
n_ord_ifps$brier3 <- NA
n_ord_ifps$brier4 <- NA


br_wtscrs <- rbind(ord_ifps, n_ord_ifps)

cm2a <- colMeans(br_wtscrs[c("brier_f","brier_v","brier_t","brier_i",
                             "brier")])



br_wtscrs$brier[br_wtscrs$brier == 0] <- .0001
br_wtscrs$brier_f[br_wtscrs$brier_f == 0] <- .0001
br_wtscrs$brier_v[br_wtscrs$brier_v == 0] <- .0001
br_wtscrs$brier_i[br_wtscrs$brier_i == 0] <- .0001
br_wtscrs$brier_t[br_wtscrs$brier_t == 0] <- .0001

br_wtscrs$acc_f <- VGAM::probitlink(1-(sqrt(br_wtscrs$brier_f/2)))
br_wtscrs$acc_v <- VGAM::probitlink(1-(sqrt(br_wtscrs$brier_v/2)))
br_wtscrs$acc_t <- VGAM::probitlink(1-(sqrt(br_wtscrs$brier_t/2)))
br_wtscrs$acc_i <- VGAM::probitlink(1-(sqrt(br_wtscrs$brier_i/2)))
br_wtscrs$acc <- VGAM::probitlink(1-(sqrt(br_wtscrs$brier/2)))

## Combine versions with ID and without ID

br_wtscrs_a <- br_wtscrs_a[c("discover_id","date","brier_v",
                             "brier_t","brier_f","brier_i","brier",
                             "acc_v","acc_t","acc_f","acc_i","acc")]

br_wtscrs <- br_wtscrs[c("discover_id","date","brier_v",
                         "brier_t","brier_f",
                         "acc_v","acc_t","acc_f")]

names(br_wtscrs_a) <- c("discover_id","date",paste(names(br_wtscrs_a)[3:ncol(br_wtscrs_a)],
                                                   "ind",sep = "_"))

br_wtscrs <- left_join(br_wtscrs, br_wtscrs_a)

## Generate Table 12

tab12 <- round(data.frame(brier = c(colMeans(br_wtscrs_a[c("brier_ind","brier_i_ind","brier_v_ind",
                                                          "brier_f_ind","brier_t_ind")]),
                                   colMeans(br_wtscrs[c("brier_v","brier_f","brier_t")])),
                         acc = c(colMeans(br_wtscrs_a[c("acc_ind","acc_i_ind","acc_v_ind",
                                                        "acc_f_ind","acc_t_ind")]),
                                 colMeans(br_wtscrs[c("acc_v","acc_f","acc_t")]))),3)


write.csv(tab12, "table12.csv")

## Fit hierarchical model for Table 13
br_wtscrs_l <- pivot_longer(br_wtscrs, 
                            cols = c("acc_f","acc_v","acc_t",
                                     paste(c("acc","acc_i","acc_f","acc_v","acc_t"),"ind",sep = "_")), names_to = "model",
                            values_to = "acc")

options(contrasts = c("contr.sum", "contr.poly"))

fin_hlm <- lmer(acc ~ model + (1 | discover_id), br_wtscrs_l)


mx1 <- afex::mixed(acc ~ model + (1 | discover_id), br_wtscrs_l,
                   method = "S")

## Pairwise comparisons for Table 13
library(emmeans)

emm1 <- emmeans(fin_hlm, "model", lmer.df = "satterthwaite",
                lmerTest.limit = 100000)

ctrst <- contrast(emm1, 'tukey') %>%
  broom::tidy()


## Get d values
ctrst_d <- effectsize::t_to_d(ctrst$statistic, ctrst$df, paired = TRUE)

ctrst_d_t <- cbind(ctrst, ctrst_d)

## Table 13 results
write.csv(ctrst_d_t, "rcta contrasts.csv")


