rm(list=ls())
setwd("~/S1") # Set working directory path
library(tidyverse)


## Load Season 1 data
br_ifps_s1 <- read.csv("season 1 forecasts.csv")

## Transform brier scores to accuracy and normalized accuracy
br_ifps_s1$correct <- 1-(sqrt(br_ifps_s1$brier/2))
br_ifps_s1$correct_trim <- ifelse(br_ifps_s1$correct == 1, .999,
                                  ifelse(br_ifps_s1$correct == 0, .001, br_ifps_s1$correct))


br_ifps_s1$correct_prob <- VGAM::probitlink(br_ifps_s1$correct_trim)


## Subset questions that are at least 12 weeks in length
br_ifps_len1 <- br_ifps_s1[br_ifps_s1$ifp_length >= 7*12,]

br_ifps_len1$date <- as.Date(br_ifps_len1$date)
br_ifps_len1$close_date <- as.Date(br_ifps_len1$close_date)

## Create week variable
br_ifps_len1 <- br_ifps_len1 %>% 
  mutate(ifp_wk = ifelse(close_date - date <= 7, 1,
                         ifelse(close_date - date <= 14, 2,
                                ifelse(close_date - date <= 21, 3,
                                       ifelse(close_date - date <= 28, 4,
                                              ifelse(close_date - date <= 35, 5,
                                                     ifelse(close_date - date <= 42, 6,
                                                            ifelse(close_date - date <= 49, 7,
                                                                   ifelse(close_date - date <= 56, 8,
                                                                          ifelse(close_date - date <= 63, 9,
                                                                                 ifelse(close_date - date <= 70, 10,
                                                                                        ifelse(close_date - date <= 77, 11,
                                                                                               ifelse(close_date - date <= 84, 12, NA)))))))))))))


## Get means and SEs
br_ifps_sumwk <- Rmisc::summarySE(br_ifps_len1, "correct_prob", groupvars = "ifp_wk")
br_ifps_sumwk <- br_ifps_sumwk[!is.na(br_ifps_sumwk$ifp_wk),]

## Create season variable
br_ifps_sumwk$Season <- 1


## Load season 2 data
setwd("~/S2") # Set working directory path
br_ifps_s2 <- read.csv("season 2 forecasts.csv")


## Transform brier scores to accuracy and normalized accuracy
br_ifps_s2$correct <- 1-(sqrt(br_ifps_s2$brier/2))
br_ifps_s2$correct_trim <- ifelse(br_ifps_s2$correct == 1, .999,
                                  ifelse(br_ifps_s2$correct == 0, .001, br_ifps_s2$correct))


br_ifps_s2$correct_prob <- VGAM::probitlink(br_ifps_s2$correct_trim)

br_ifps_len2 <- br_ifps_s2[br_ifps_s2$ifp_length >= 7*12,]

br_ifps_len2$date <- as.Date(br_ifps_len2$date)
br_ifps_len2$close_date <- as.Date(br_ifps_len2$close_date)
br_ifps_len2 <- br_ifps_len2 %>% 
  mutate(ifp_wk = ifelse(close_date - date <= 7, 1,
                         ifelse(close_date - date <= 14, 2,
                                ifelse(close_date - date <= 21, 3,
                                       ifelse(close_date - date <= 28, 4,
                                              ifelse(close_date - date <= 35, 5,
                                                     ifelse(close_date - date <= 42, 6,
                                                            ifelse(close_date - date <= 49, 7,
                                                                   ifelse(close_date - date <= 56, 8,
                                                                          ifelse(close_date - date <= 63, 9,
                                                                                 ifelse(close_date - date <= 70, 10,
                                                                                        ifelse(close_date - date <= 77, 11,
                                                                                               ifelse(close_date - date <= 84, 12, NA)))))))))))))




br_ifps_sumwk_b <- Rmisc::summarySE(br_ifps_len2, "correct_prob", groupvars = "ifp_wk")
br_ifps_sumwk_b <- br_ifps_sumwk_b[!is.na(br_ifps_sumwk_b$ifp_wk),]

br_ifps_sumwk_b$Season <- 2


## Combine seasons
br_ifps_sumwk <- rbind(br_ifps_sumwk, br_ifps_sumwk_b)

## Plot results
br_ifps_sumwk <- br_ifps_sumwk[!is.na(br_ifps_sumwk$ifp_wk),]


br_ifps_sumwk$Season <- as.factor(br_ifps_sumwk$Season)

pd = position_dodge(.5)

p3 <- ggplot(br_ifps_sumwk, 
             aes(x = ifp_wk, y = correct_prob,group=Season, color = Season, shape = Season)) + 
  geom_point(position = pd) + scale_shape_manual(values = c(17,15)) +
  geom_errorbar(aes(ymin = correct_prob - se,ymax = correct_prob + se),
                position = pd, width =.5) +
  scale_color_manual(values = c(rev(brewer.pal(4, "Blues"))[2],
                                rev(brewer.pal(4, "Reds"))[2])) +
  scale_x_continuous(n.breaks = 12, trans = "reverse") +
  scale_y_continuous(limits = c(0, 3)) + 
  xlab("Weeks Until Resolution") + 
  ylab("Average Accuracy") + theme_apa()

png("timeplot3.png", width = 8, height = 4, units = "in", res = 300)
p3
dev.off()
